--- شروع فایل README.md ---

# سرورهای MCP عالی [![عالی](https://awesome.re/badge.svg)](https://awesome.re)

[![ไทย](https://img.shields.io/badge/Thai-Click-blue)](README-th.md)
[![English](https://img.shields.io/badge/English-Click-yellow)](README.md)
[![繁體中文](https://img.shields.io/badge/繁體中文-點擊查看-orange)](README-zh_TW.md)
[![简体中文](https://img.shields.io/badge/简体中文-点击查看-orange)](README-zh.md)
[![日本語](https://img.shields.io/badge/日本語-クリック-青)](README-ja.md)
[![한국어](https://img.shields.io/badge/한국어-클릭-yellow)](README-ko.md)
[![Português Brasileiro](https://img.shields.io/badge/Português_Brasileiro-Clique-green)](README-pt_BR.md)
[![Discord](https://img.shields.io/discord/1312302100125843476?logo=discord&label=discord)](https://glama.ai/mcp/discord)
[![Subreddit subscribers](https://img.shields.io/reddit/subreddit-subscribers/mcp?style=flat&logo=reddit&label=subreddit)](https://www.reddit.com/r/mcp/)

یک لیست منتخب از سرورهای عالی Model Context Protocol (MCP).

* [MCP چیست؟](#what-is-mcp)
* [کلاینت‌ها](#clients)
* [آموزش‌ها](#tutorials)
* [جامعه](#community)
* [راهنما](#legend)
* [پیاده‌سازی‌های سرور](#server-implementations)
* [چارچوب‌ها](#frameworks)
* [نکات و ترفندها](#tips-and-tricks)

## MCP چیست؟

[MCP](https://modelcontextprotocol.io/) یک پروتکل باز است که به مدل‌های هوش مصنوعی امکان تعامل امن با منابع محلی و راه دور را از طریق پیاده‌سازی‌های سرور استاندارد شده می‌دهد. این لیست بر روی سرورهای MCP آماده برای تولید و آزمایشی تمرکز دارد که قابلیت‌های هوش مصنوعی را از طریق دسترسی به فایل، اتصالات پایگاه داده، یکپارچه‌سازی API و سایر خدمات متنی گسترش می‌دهند.

## کلاینت‌ها

[awesome-mcp-clients](https://github.com/punkpeye/awesome-mcp-clients/) و [glama.ai/mcp/clients](https://glama.ai/mcp/clients) را بررسی کنید.

> [!TIP]
> [Glama Chat](https://glama.ai/chat) یک کلاینت هوش مصنوعی چندوجهی با پشتیبانی از MCP و [دروازه هوش مصنوعی](https://glama.ai/gateway) است.

## آموزش‌ها

* [شروع سریع پروتکل زمینه مدل (MCP)](https://glama.ai/blog/2024-11-25-model-context-protocol-quickstart)
* [تنظیم برنامه دسکتاپ Claude برای استفاده از پایگاه داده SQLite](https://youtu.be/wxCCzo9dGj0)

## جامعه

* [r/mcp Reddit](https://www.reddit.com/r/mcp)
* [سرور دیسکورد](https://glama.ai/mcp/discord)

## راهنما

* 🎖️ – پیاده‌سازی رسمی
* زبان برنامه‌نویسی
  * 🐍 – کدبیس Python
  * 📇 – کدبیس TypeScript (یا JavaScript)
  * 🏎️ – کدبیس Go
  * 🦀 – کدبیس Rust
  * #️⃣ - کدبیس C#
  * ☕ - کدبیس Java
  * 🌊 – کدبیس C/C++
  * 💎 - کدبیس Ruby

* دامنه
  * ☁️ - سرویس ابری
  * 🏠 - سرویس محلی
  * 📟 - سیستم‌های تعبیه‌شده
* سیستم عامل
  * 🍎 – برای macOS
  * 🪟 – برای Windows
  * 🐧 - برای Linux

> [!NOTE]
> در مورد محلی 🏠 در مقابل ابری ☁️ گیج شده‌اید؟
> * از محلی استفاده کنید زمانی که سرور MCP با یک نرم‌افزار نصب شده محلی صحبت می‌کند، به عنوان مثال کنترل مرورگر Chrome را به دست می‌گیرد.
> * از ابری استفاده کنید زمانی که سرور MCP با APIهای راه دور صحبت می‌کند، به عنوان مثال API هواشناسی.

## پیاده‌سازی‌های سرور

> [!NOTE]
> ما اکنون یک [دایرکتوری مبتنی بر وب](https://glama.ai/mcp/servers) داریم که با مخزن همگام‌سازی شده است.

* 🔗 - [تجمیع‌کننده‌ها](#aggregators)
* 🚀 - [هوافضا و اخترپویایی](#aerospace-and-astrodynamics)
* 🎨 - [هنر و فرهنگ](#art-and-culture)
* 📐 - [معماری و طراحی](#architecture-and-design)
* 📂 - [اتوماسیون مرورگر](#browser-automation)
* 🧬 - [زیست‌شناسی، پزشکی و بیوانفورماتیک](#bio)
* ☁️ - [پلتفرم‌های ابری](#cloud-platforms)
* 👨‍💻 - [اجرای کد](#code-execution)
* 🤖 - [عامل‌های کدنویسی](#coding-agents)
* 🖥️ - [خط فرمان](#command-line)
* 💬 - [ارتباطات](#communication)
* 👤 - [پلتفرم‌های داده مشتری](#customer-data-platforms)
* 🗄️ - [پایگاه‌های داده](#databases)
* 📊 - [پلتفرم‌های داده](#data-platforms)
* 🚚 - [تحویل](#delivery)
* 🛠️ - [ابزارهای توسعه‌دهنده](#developer-tools)
* 🧮 - [ابزارهای علم داده](#data-science-tools)
* 📟 - [سیستم تعبیه‌شده](#embedded-system)
* 🌳 - [زیست بوم و طبیعت](#environment-and-nature)
* 📂 - [سیستم‌های فایل](#file-systems)
* 💰 - [مالی و فین‌تک](#finance--fintech)
* 🎮 - [بازی](#gaming)
* 🧠 - [دانش و حافظه](#knowledge--memory)
* 🗺️ - [خدمات مکانی](#location-services)
* 🎯 - [بازاریابی](#marketing)
* 📊 - [نظارت](#monitoring)
* 🎥 - [پردازش چندرسانه‌ای](#multimedia-process)
* 🔎 - [جستجو و استخراج داده](#search)
* 🔒 - [امنیت](#security)
* 🌐 - [رسانه‌های اجتماعی](#social-media)
* 🏃 - [ورزش](#sports)
* 🎧 - [پشتیبانی و مدیریت خدمات](#support-and-service-management)
* 🌎 - [خدمات ترجمه](#translation-services)
* 🎧 - [تبدیل متن به گفتار](#text-to-speech)
* 🚆 - [سفر و حمل و نقل](#travel-and-transportation)
* 🔄 - [کنترل نسخه](#version-control)
* 🏢 - [محیط کار و بهره‌وری](#workplace-and-productivity)
* 🛠️ - [سایر ابزارها و یکپارچه‌سازی‌ها](#other-tools-and-integrations)


### 🔗 <a name="aggregators"></a>تجمیع‌کننده‌ها

سرورهایی برای دسترسی به بسیاری از برنامه‌ها و ابزارها از طریق یک سرور MCP واحد.

- [1mcp/agent](https://github.com/1mcp-app/agent) 📇 ☁️ 🏠 🍎 🪟 🐧 - یک پیاده‌سازی سرور Model Context Protocol یکپارچه که چندین سرور MCP را در یک سرور تجمیع می‌کند.
- [duaraghav8/MCPJungle](https://github.com/duaraghav8/MCPJungle) 🏎️ 🏠 - رجیستری سرور MCP خودمیزبان برای عامل‌های هوش مصنوعی سازمانی
- [glenngillen/mcpmcp-server](https://github.com/glenngillen/mcpmcp-server) ☁️ 📇 🍎 🪟 🐧 - لیستی از سرورهای MCP تا بتوانید از کلاینت خود بپرسید از کدام سرورها برای بهبود گردش کار روزانه خود می‌توانید استفاده کنید.
- [hamflx/imagen3-mcp](https://github.com/hamflx/imagen3-mcp) 📇 🏠 🪟 🍎 🐧 - یک ابزار قدرتمند تولید تصویر با استفاده از API Imagen 3.0 گوگل از طریق MCP. تولید تصاویر با کیفیت بالا از طریق دستورات متنی با کنترل‌های پیشرفته عکاسی، هنری و فوتورئالیستی.
- [julien040/anyquery](https://github.com/julien040/anyquery) 🏎️ 🏠 ☁️ - بیش از ۴۰ برنامه را با یک باینری با استفاده از SQL کوئری کنید. همچنین می‌تواند به پایگاه داده سازگار با PostgreSQL، MySQL یا SQLite شما متصل شود. طراحی شده به صورت محلی-اول و خصوصی.
- [metatool-ai/metatool-app](https://github.com/metatool-ai/metatool-app) 📇 ☁️ 🏠 🍎 🪟 🐧 - MetaMCP یک سرور میان‌افزار MCP یکپارچه است که اتصالات MCP شما را با رابط کاربری گرافیکی مدیریت می‌کند.
- [mindsdb/mindsdb](https://github.com/mindsdb/mindsdb) - داده‌ها را در پلتفرم‌ها و پایگاه‌های داده مختلف با [MindsDB به عنوان یک سرور MCP واحد](https://docs.mindsdb.com/mcp/overview) متصل و یکپارچه کنید.
- [PipedreamHQ/pipedream](https://github.com/PipedreamHQ/pipedream/tree/master/modelcontextprotocol) ☁️ 🏠 - با ۲۵۰۰ API با بیش از ۸۰۰۰ ابزار از پیش ساخته شده متصل شوید و سرورها را برای کاربران خود، در برنامه خودتان مدیریت کنید.
- [sitbon/magg](https://github.com/sitbon/magg) 🍎 🪟 🐧 ☁️ 🏠 🐍 - Magg: یک سرور متا-MCP که به عنوان یک هاب جهانی عمل می‌کند و به LLMها اجازه می‌دهد تا به طور خودکار چندین سرور MCP را کشف، نصب و هماهنگ کنند - اساساً به دستیاران هوش مصنوعی این قدرت را می‌دهد که قابلیت‌های خود را در صورت تقاضا گسترش دهند.
- [SureScaleAI/openai-gpt-image-mcp](https://github.com/SureScaleAI/openai-gpt-image-mcp) 📇 ☁️ - سرور MCP تولید/ویرایش تصویر OpenAI GPT.
- [sxhxliang/mcp-access-point](https://github.com/sxhxliang/mcp-access-point) 📇 ☁️ 🏠 🍎 🪟 🐧 - یک سرویس وب را با یک کلیک و بدون هیچ گونه تغییر در کد، به یک سرور MCP تبدیل کنید.
- [TheLunarCompany/lunar#mcpx](https://github.com/TheLunarCompany/lunar/tree/main/mcpx) 📇 🏠  ☁️ 🍎 🪟 🐧 - MCPX یک دروازه منبع باز و آماده برای تولید است تا سرورهای MCP را در مقیاس بزرگ مدیریت کند—کشف ابزار، کنترل‌های دسترسی، اولویت‌بندی تماس و ردیابی استفاده را برای ساده‌سازی گردش کار عامل‌ها متمرکز کنید.
- [tigranbs/mcgravity](https://github.com/tigranbs/mcgravity) 📇 🏠 - یک ابزار پروکسی برای ترکیب چندین سرور MCP در یک نقطه پایانی یکپارچه. ابزارهای هوش مصنوعی خود را با توزیع بار درخواست‌ها در چندین سرور MCP، مشابه نحوه کار Nginx برای سرورهای وب، مقیاس‌بندی کنید.
- [VeriTeknik/pluggedin-mcp-proxy](https://github.com/VeriTeknik/pluggedin-mcp-proxy)  📇 🏠 - یک سرور پروکسی جامع که چندین سرور MCP را در یک رابط واحد با ویژگی‌های دید گسترده ترکیب می‌کند. این سرور کشف و مدیریت ابزارها، پرامپت‌ها، منابع و قالب‌ها را در سرورهای مختلف، به علاوه یک محیط آزمایشی برای اشکال‌زدایی هنگام ساخت سرورهای MCP فراهم می‌کند.
- [WayStation-ai/mcp](https://github.com/waystation-ai/mcp) ☁️ 🍎 🪟 - Claude Desktop و دیگر میزبان‌های MCP را به طور یکپارچه و امن به برنامه‌های مورد علاقه خود (Notion، Slack، Monday، Airtable، و غیره) متصل کنید. کمتر از ۹۰ ثانیه طول می‌کشد.
- [wegotdocs/open-mcp](https://github.com/wegotdocs/open-mcp) 📇 🏠 🍎 🪟 🐧 - یک API وب را در ۱۰ ثانیه به یک سرور MCP تبدیل کنید و آن را به رجیستری منبع باز اضافه کنید: https://open-mcp.org
- [Data-Everything/mcp-server-templates](https://github.com/Data-Everything/mcp-server-templates) 📇 🏠 🍎 🪟 🐧 - یک سرور. همه ابزارها. یک پلتفرم MCP یکپارچه که بسیاری از برنامه‌ها، ابزارها و خدمات را پشت یک رابط قدرتمند متصل می‌کند—ایده‌آل برای توسعه‌دهندگان محلی یا عامل‌های تولید.
- [YangLiangwei/PersonalizationMCP](https://github.com/YangLiangwei/PersonalizationMCP) 🐍 ☁️ 🏠 🍎 🪟 🐧 - سرور MCP جامع تجمیع داده‌های شخصی با یکپارچه‌سازی پلتفرم‌های Steam، YouTube، Bilibili، Spotify، Reddit و دیگر پلتفرم‌ها. دارای احراز هویت OAuth2، مدیریت خودکار توکن، و بیش از ۹۰ ابزار برای دسترسی به داده‌های بازی، موسیقی، ویدیو و پلتفرم‌های اجتماعی است.

### 🚀 <a name="aerospace-and-astrodynamics"></a>هوافضا و اخترپویایی

- [IO-Aerospace-software-community/mcp-server](https://github.com/IO-Aerospace-software-engineering/mcp-server) #️⃣ ☁️/🏠 🐧 - سرور MCP هوافضا IO: یک سرور MCP مبتنی بر NET. برای هوافضا و اخترپویایی — افمریس، تبدیل‌های مداری، ابزارهای DSS، تبدیل‌های زمانی، و ابزارهای واحد/ریاضی. از انتقال‌های STDIO و SSE پشتیبانی می‌کند؛ استقرار Docker و .NET بومی مستند شده است.

### 🎨 <a name="art-and-culture"></a>هنر و فرهنگ

دسترسی و کاوش در مجموعه‌های هنری، میراث فرهنگی و پایگاه‌های داده موزه‌ها. به مدل‌های هوش مصنوعی امکان جستجو و تحلیل محتوای هنری و فرهنگی را می‌دهد.

- [drakonkat/wizzy-mcp-tmdb](https://github.com/drakonkat/wizzy-mcp-tmdb) 📇 ☁️ - یک سرور MCP برای API پایگاه داده فیلم که به دستیاران هوش مصنوعی امکان جستجو و بازیابی اطلاعات فیلم، سریال تلویزیونی و افراد را می‌دهد.
- [8enSmith/mcp-open-library](https://github.com/8enSmith/mcp-open-library) 📇 ☁️ - یک سرور MCP برای API کتابخانه باز که به دستیاران هوش مصنوعی امکان جستجوی اطلاعات کتاب را می‌دهد.
- [abhiemj/manim-mcp-server](https://github.com/abhiemj/manim-mcp-server) 🐍 🏠 🪟 🐧 - یک سرور MCP محلی که با استفاده از Manim انیمیشن تولید می‌کند.
- [ahujasid/blender-mcp](https://github.com/ahujasid/blender-mcp) 🐍 - سرور MCP برای کار با Blender
- [aliafsahnoudeh/shahnameh-mcp-server](https://github.com/aliafsahnoudeh/shahnameh-mcp-server) 🐍 🏠 🍎 🪟 🐧 - یک ام سی پی سرور برای دسترسی به بخش ها و اشعار و توضیحات شاهنامه فردوسی حماسه بزرگ فارسی
- [burningion/video-editing-mcp](https://github.com/burningion/video-editing-mcp) 🐍 - اضافه کردن، تحلیل، جستجو و تولید ویرایش‌های ویدیویی از مجموعه Video Jungle شما
- [cantian-ai/bazi-mcp](https://github.com/cantian-ai/bazi-mcp) 📇 🏠 ☁️ 🍎 🪟 - نمودار و تحلیل جامع و دقیق Bazi (طالع‌بینی چینی) را ارائه می‌دهد
- [cswkim/discogs-mcp-server](https://github.com/cswkim/discogs-mcp-server) 📇 ☁️ - سرور MCP برای تعامل با API Discogs
- [diivi/aseprite-mcp](https://github.com/diivi/aseprite-mcp) 🐍 🏠 - سرور MCP با استفاده از API Aseprite برای ایجاد هنر پیکسلی
- [djalal/quran-mcp-server](https://github.com/djalal/quran-mcp-server) 📇 ☁️ سرور MCP برای تعامل با مجموعه متون Quran.com از طریق API رسمی REST v4.
- [raveenb/fal-mcp-server](https://github.com/raveenb/fal-mcp-server) 🐍 ☁️ - تولید تصاویر، ویدیوها و موسیقی هوش مصنوعی با استفاده از مدل‌های Fal.ai (FLUX، Stable Diffusion، MusicGen) مستقیماً در Claude Desktop
- [mikechao/metmuseum-mcp](https://github.com/mikechao/metmuseum-mcp) 📇 ☁️ - یکپارچه‌سازی با API مجموعه موزه هنر متروپولیتن برای جستجو و نمایش آثار هنری در مجموعه.
- [OctoEverywhere/mcp](https://github.com/OctoEverywhere/mcp) #️⃣ ☁️ - یک سرور MCP چاپگر سه بعدی که امکان دریافت وضعیت زنده چاپگر، عکس‌های وب‌کم و کنترل چاپگر را فراهم می‌کند.
- [omni-mcp/isaac-sim-mcp](https://github.com/omni-mcp/isaac-sim-mcp) 📇 ☁️ - یک سرور MCP و یک افزونه که کنترل زبان طبیعی NVIDIA Isaac Sim، Lab، OpenUSD و غیره را امکان‌پذیر می‌سازد.
- [PatrickPalmer/MayaMCP](https://github.com/PatrickPalmer/MayaMCP) 🐍 🏠 - سرور MCP برای Autodesk Maya
- [peek-travel/mcp-intro](https://github.com/peek-travel/mcp-intro) ☁️ 🍎 🪟 🐧 - سرور MCP راه دور برای کشف و برنامه‌ریزی تجربیات، در خانه و در تعطیلات
- [r-huijts/oorlogsbronnen-mcp](https://github.com/r-huijts/oorlogsbronnen-mcp) 📇 ☁️ - یکپارچه‌سازی با API Oorlogsbronnen (منابع جنگ) برای دسترسی به سوابق تاریخی جنگ جهانی دوم، عکس‌ها و اسناد از هلند (۱۹۴۰-۱۹۴۵)
- [r-huijts/rijksmuseum-mcp](https://github.com/r-huijts/rijksmuseum-mcp) 📇 ☁️ - یکپارچه‌سازی با API Rijksmuseum برای جستجوی آثار هنری، جزئیات و مجموعه‌ها
- [samuelgursky/davinci-resolve-mcp](https://github.com/samuelgursky/davinci-resolve-mcp) 🐍 - یکپارچه‌سازی سرور MCP برای DaVinci Resolve که ابزارهای قدرتمندی برای ویرایش ویدیو، درجه‌بندی رنگ، مدیریت رسانه و کنترل پروژه فراهم می‌کند
- [yuna0x0/anilist-mcp](https://github.com/yuna0x0/anilist-mcp) 📇 ☁️ - یک سرور MCP که API AniList را برای اطلاعات انیمه و مانگا یکپارچه می‌کند


### 📐 <a name="architecture-and-design"></a>معماری و طراحی

طراحی و تجسم معماری نرم‌افزار، نمودارهای سیستم و مستندات فنی. به مدل‌های هوش مصنوعی امکان تولید نمودارهای حرفه‌ای و مستندات معماری را می‌دهد.

- [Narasimhaponnada/mermaid-mcp](https://github.com/Narasimhaponnada/mermaid-mcp) 📇 ☁️ 🍎 🪟 🐧 - تولید نمودار Mermaid با قدرت هوش مصنوعی با بیش از ۲۲ نوع نمودار شامل فلوچارت‌ها، نمودارهای توالی، نمودارهای کلاس، نمودارهای ER، نمودارهای معماری، ماشین‌های حالت و موارد دیگر. دارای بیش از ۵۰ قالب از پیش ساخته شده، موتورهای چیدمان پیشرفته، خروجی‌های SVG/PNG/PDF، و یکپارچه‌سازی یکپارچه با GitHub Copilot، Claude، و هر کلاینت سازگار با MCP. نصب از طریق NPM: `npm install -g @narasimhaponnada/mermaid-mcp-server`

### <a name="bio"></a>زیست‌شناسی، پزشکی و بیوانفورماتیک

- [genomoncology/biomcp](https://github.com/genomoncology/biomcp) 🐍 ☁️ - سرور MCP تحقیقات زیست‌پزشکی که دسترسی به PubMed، ClinicalTrials.gov و MyVariant.info را فراهم می‌کند.
- [longevity-genie/biothings-mcp](https://github.com/longevity-genie/biothings-mcp) 🐍 🏠 ☁️ - سرور MCP برای تعامل با API BioThings، شامل ژن‌ها، واریانت‌های ژنتیکی، داروها و اطلاعات طبقه‌بندی.
- [longevity-genie/gget-mcp](https://github.com/longevity-genie/gget-mcp) 🐍 🏠 ☁️ - سرور MCP که یک جعبه ابزار قدرتمند بیوانفورماتیک برای کوئری‌ها و تحلیل‌های ژنومیک فراهم می‌کند و کتابخانه محبوب `gget` را پوشش می‌دهد.
- [longevity-genie/opengenes-mcp](https://github.com/longevity-genie/opengenes-mcp) 🎖️ 🐍 🏠 ☁️ - سرور MCP برای یک پایگاه داده قابل کوئری برای تحقیقات پیری و طول عمر از پروژه OpenGenes.
- [longevity-genie/synergy-age-mcp](https://github.com/longevity-genie/synergy-age-mcp) 🎖️ 🐍 🏠 ☁️ - سرور MCP برای پایگاه داده SynergyAge از تعاملات ژنتیکی سینرژیک و آنتاگونیستی در طول عمر.
- [the-momentum/fhir-mcp-server](https://github.com/the-momentum/fhir-mcp-server) 🐍 🏠 ☁️ - سرور MCP که عامل‌های هوش مصنوعی را به سرورهای FHIR متصل می‌کند. یک مورد استفاده نمونه، کوئری تاریخچه بیمار به زبان طبیعی است.
- [wso2/fhir-mcp-server](https://github.com/wso2/fhir-mcp-server) 🐍 🏠 ☁️ - سرور Model Context Protocol برای APIهای Fast Healthcare Interoperability Resources (FHIR). یکپارچه‌سازی یکپارچه با سرورهای FHIR را فراهم می‌کند و به دستیاران هوش مصنوعی امکان جستجو، بازیابی، ایجاد، به‌روزرسانی و تحلیل داده‌های بالینی مراقبت‌های بهداشتی با پشتیبانی از احراز هویت SMART-on-FHIR را می‌دهد.
- [JamesANZ/medical-mcp](https://github.com/JamesANZ/medical-mcp) 📇 🏠 - یک سرور MCP که دسترسی به اطلاعات پزشکی، پایگاه‌های داده دارویی و منابع مراقبت‌های بهداشتی را فراهم می‌کند. به دستیاران هوش مصنوعی امکان کوئری داده‌های پزشکی، تداخلات دارویی و دستورالعمل‌های بالینی را می‌دهد.
- [the-momentum/apple-health-mcp-server](https://github.com/the-momentum/apple-health-mcp-server) 🐍 🏠 🍎 🪟 🐧 - یک سرور MCP که دسترسی به داده‌های صادر شده از Apple Health را فراهم می‌کند. تحلیل داده‌ها نیز شامل می‌شود.
- [OHNLP/omop_mcp](https://github.com/OHNLP/omop_mcp) 🐍 🏠 ☁️ - نگاشت ترمینولوژی بالینی به مفاهیم OMOP با استفاده از LLMها برای استانداردسازی و قابلیت همکاری داده‌های مراقبت‌های بهداشتی.

### 📂 <a name="browser-automation"></a>اتوماسیون مرورگر

قابلیت‌های دسترسی و اتوماسیون محتوای وب. امکان جستجو، استخراج و پردازش محتوای وب در فرمت‌های سازگار با هوش مصنوعی را فراهم می‌کند.

- [34892002/bilibili-mcp-js](https://github.com/34892002/bilibili-mcp-js) 📇 🏠 - یک سرور MCP که از جستجوی محتوای Bilibili پشتیبانی می‌کند. نمونه‌های یکپارچه‌سازی با LangChain و اسکریپت‌های تست را ارائه می‌دهد.
- [agent-infra/mcp-server-browser](https://github.com/bytedance/UI-TARS-desktop/tree/main/packages/agent-infra/mcp-servers/browser) 📇 🏠 - قابلیت‌های اتوماسیون مرورگر با استفاده از Puppeteer، که هم از اتصال مرورگر محلی و هم از راه دور پشتیبانی می‌کند.
- [automatalabs/mcp-server-playwright](https://github.com/Automata-Labs-team/MCP-Server-Playwright) 🐍 - یک سرور MCP برای اتوماسیون مرورگر با استفاده از Playwright
- [blackwhite084/playwright-plus-python-mcp](https://github.com/blackwhite084/playwright-plus-python-mcp) 🐍 - یک سرور پایتون MCP با استفاده از Playwright برای اتوماسیون مرورگر، مناسب‌تر برای llm
- [browserbase/mcp-server-browserbase](https://github.com/browserbase/mcp-server-browserbase) 🎖️ 📇 - اتوماسیون تعاملات مرورگر در ابر (مانند پیمایش وب، استخراج داده، پر کردن فرم و موارد دیگر)
- [browsermcp/mcp](https://github.com/browsermcp/mcp) 📇 🏠 - اتوماسیون مرورگر محلی Chrome شما
- [co-browser/browser-use-mcp-server](https://github.com/co-browser/browser-use-mcp-server) 🐍 - browser-use بسته‌بندی شده به عنوان یک سرور MCP با انتقال SSE. شامل یک dockerfile برای اجرای chromium در docker + یک سرور vnc.
- [eat-pray-ai/yutu](https://github.com/eat-pray-ai/yutu) 🏎️ 🏠 🍎 🐧 🪟 - یک سرور MCP و CLI کاملاً کاربردی برای YouTube برای اتوماسیون عملیات YouTube
- [executeautomation/playwright-mcp-server](https://github.com/executeautomation/mcp-playwright) 📇 - یک سرور MCP با استفاده از Playwright برای اتوماسیون مرورگر و استخراج وب
- [eyalzh/browser-control-mcp](https://github.com/eyalzh/browser-control-mcp) 📇 🏠 - یک سرور MCP همراه با یک افزونه مرورگر که به کلاینت‌های LLM امکان کنترل مرورگر کاربر (Firefox) را می‌دهد.
- [freema/firefox-devtools-mcp](https://github.com/freema/firefox-devtools-mcp) 📇 🏠 - اتوماسیون مرورگر Firefox از طریق WebDriver BiDi برای تست، استخراج داده و کنترل مرورگر. از تعاملات مبتنی بر snapshot/UID، نظارت بر شبکه، ضبط کنسول و اسکرین‌شات پشتیبانی می‌کند.
- [fradser/mcp-server-apple-reminders](https://github.com/FradSer/mcp-server-apple-reminders) 📇 🏠 🍎 - یک سرور MCP برای تعامل با Apple Reminders در macOS
- [getrupt/ashra-mcp](https://github.com/getrupt/ashra-mcp) 📇 🏠 - استخراج داده‌های ساختاریافته از هر وب‌سایتی. فقط پرامپت کنید و JSON دریافت کنید.
- [kimtaeyoon83/mcp-server-youtube-transcript](https://github.com/kimtaeyoon83/mcp-server-youtube-transcript) 📇 ☁️ - دریافت زیرنویس‌ها و رونوشت‌های YouTube برای تحلیل هوش مصنوعی
- [kimtth/mcp-aoai-web-browsing](https://github.com/kimtth/mcp-aoai-web-browsing) 🐍 🏠 - یک پیاده‌سازی `حداقلی` سرور/کلاینت MCP با استفاده از Azure OpenAI و Playwright.
- [lightpanda-io/gomcp](https://github.com/lightpanda-io/gomcp) 🏎 🏠/☁️ 🐧/🍎 - یک سرور MCP در Go برای Lightpanda، مرورگر headless فوق‌العاده سریع که برای اتوماسیون وب طراحی شده است
- [microsoft/playwright-mcp](https://github.com/microsoft/playwright-mcp) - سرور MCP رسمی Microsoft Playwright، که به LLMها امکان تعامل با صفحات وب از طریق snapshotهای دسترسی ساختاریافته را می‌دهد
- [modelcontextprotocol/server-puppeteer](https://github.com/modelcontextprotocol/servers/tree/main/src/puppeteer) 📇 🏠 - اتوماسیون مرورگر برای استخراج و تعامل وب
- [ndthanhdev/mcp-browser-kit](https://github.com/ndthanhdev/mcp-browser-kit) 📇 🏠 - یک سرور MCP که به دستیاران هوش مصنوعی امکان تعامل با مرورگرهای محلی شما را می‌دهد.
- [operative_sh/web-eval-agent](https://github.com/Operative-Sh/web-eval-agent) 🐍 🏠 🍎 - یک سرور MCP که به طور خودکار برنامه‌های وب را با عامل‌های مرورگر browser-use اشکال‌زدایی می‌کند
- [pskill9/web-search](https://github.com/pskill9/web-search) 📇 🏠 - یک سرور MCP که جستجوی وب رایگان را با استفاده از نتایج جستجوی Google امکان‌پذیر می‌کند، بدون نیاز به کلید API.
- [PhungXuanAnh/selenium-mcp-server](https://github.com/PhungXuanAnh/selenium-mcp-server) 🐍 🏠 🍎 🪟 🐧 - یک سرور Model Context Protocol که قابلیت‌های اتوماسیون وب را از طریق Selenium WebDriver فراهم می‌کند
- [recursechat/mcp-server-apple-shortcuts](https://github.com/recursechat/mcp-server-apple-shortcuts) 📇 🏠 🍎 - یکپارچه‌سازی سرور MCP با Apple Shortcuts
- [xspadex/bilibili-mcp](https://github.com/xspadex/bilibili-mcp.git) 📇 🏠 - ابزاری مبتنی بر FastMCP که ویدیوهای پرطرفدار Bilibili را دریافت کرده و آنها را از طریق یک رابط MCP استاندارد در دسترس قرار می‌دهد.
- [imprvhub/mcp-browser-agent](https://github.com/imprvhub/mcp-browser-agent) 📇 🏠 - یکپارچه‌سازی Model Context Protocol (MCP) که به Claude Desktop قابلیت‌های اتوماسیون مرورگر خودکار را می‌دهد.

### ☁️ <a name="cloud-platforms"></a>پلتفرم‌های ابری

یکپارچه‌سازی با خدمات پلتفرم ابری. امکان مدیریت و تعامل با زیرساخت و خدمات ابری را فراهم می‌کند.

- [4everland/4everland-hosting-mcp](https://github.com/4everland/4everland-hosting-mcp) 🎖️ 📇 🏠 🍎 🐧 - یک پیاده‌سازی سرور MCP برای 4EVERLAND Hosting که استقرار فوری کد تولید شده توسط هوش مصنوعی را به شبکه‌های ذخیره‌سازی غیرمتمرکز مانند Greenfield، IPFS و Arweave امکان‌پذیر می‌کند.
- [aashari/mcp-server-aws-sso](https://github.com/aashari/mcp-server-aws-sso) 📇 ☁️ 🏠 - یکپارچه‌سازی AWS Single Sign-On (SSO) که به سیستم‌های هوش مصنوعی امکان تعامل امن با منابع AWS را با شروع ورود SSO، لیست کردن حساب‌ها/نقش‌ها و اجرای دستورات AWS CLI با استفاده از اعتبارنامه‌های موقت می‌دهد.
- [alexbakers/mcp-ipfs](https://github.com/alexbakers/mcp-ipfs) 📇 ☁️ - آپلود و دستکاری ذخیره‌سازی IPFS
- [alexei-led/aws-mcp-server](https://github.com/alexei-led/aws-mcp-server) 🐍 ☁️ - یک سرور سبک اما قدرتمند که به دستیاران هوش مصنوعی امکان اجرای دستورات AWS CLI، استفاده از pipeهای یونیکس و اعمال قالب‌های پرامپت برای وظایف رایج AWS را در یک محیط امن Docker با پشتیبانی از چند معماری می‌دهد
- [alexei-led/k8s-mcp-server](https://github.com/alexei-led/k8s-mcp-server) 🐍 - یک سرور سبک و در عین حال قوی که به دستیاران هوش مصنوعی امکان اجرای امن دستورات Kubernetes CLI (`kubectl`، `helm`، `istioctl` و `argocd`) را با استفاده از pipeهای یونیکس در یک محیط امن Docker با پشتیبانی از چند معماری می‌دهد.
- [aliyun/alibaba-cloud-ops-mcp-server](https://github.com/aliyun/alibaba-cloud-ops-mcp-server) 🎖️ 🐍 ☁️ - یک سرور MCP که به دستیاران هوش مصنوعی امکان عملیات روی منابع Alibaba Cloud را می‌دهد و از ECS، Cloud Monitor، OOS و محصولات ابری پرکاربرد پشتیبانی می‌کند.
- [awslabs/mcp](https://github.com/awslabs/mcp) 🎖️ ☁️ - سرورهای MCP AWS برای یکپارچه‌سازی یکپارچه با خدمات و منابع AWS.
- [bright8192/esxi-mcp-server](https://github.com/bright8192/esxi-mcp-server) 🐍 ☁️ - یک سرور مدیریت VMware ESXi/vCenter مبتنی بر MCP (Model Control Protocol) که رابط‌های API REST ساده برای مدیریت ماشین مجازی فراهم می‌کند.
- [cloudflare/mcp-server-cloudflare](https://github.com/cloudflare/mcp-server-cloudflare) 🎖️ 📇 ☁️ - یکپارچه‌سازی با خدمات Cloudflare شامل Workers، KV، R2 و D1
- [cyclops-ui/mcp-cyclops](https://github.com/cyclops-ui/mcp-cyclops) 🎖️ 🏎️ ☁️ - یک سرور MCP که به عامل‌های هوش مصنوعی اجازه می‌دهد منابع Kubernetes را از طریق انتزاع Cyclops مدیریت کنند
- [elementfm/mcp](https://gitlab.com/elementfm/mcp) 🎖️ 🐍 📇 🏠 ☁️ - پلتفرم میزبانی پادکست منبع باز
- [erikhoward/adls-mcp-server](https://github.com/erikhoward/adls-mcp-server) 🐍 ☁️/🏠 - سرور MCP برای Azure Data Lake Storage. می‌تواند عملیات مدیریت کانتینرها، خواندن/نوشتن/آپلود/دانلود روی فایل‌های کانتینر و مدیریت متادیتای فایل را انجام دهد.
- [espressif/esp-rainmaker-mcp](https://github.com/espressif/esp-rainmaker-mcp) 🎖️ 🐍 🏠 ☁️ 📟 - سرور MCP رسمی Espressif برای مدیریت و کنترل دستگاه‌های ESP RainMaker.
- [flux159/mcp-server-kubernetes](https://github.com/Flux159/mcp-server-kubernetes) 📇 ☁️/🏠 - پیاده‌سازی Typescript عملیات کلاستر Kubernetes برای podها، deploymentها، serviceها.
- [hardik-id/azure-resource-graph-mcp-server](https://github.com/hardik-id/azure-resource-graph-mcp-server) 📇 ☁️/🏠 - یک سرور Model Context Protocol برای کوئری و تحلیل منابع Azure در مقیاس بزرگ با استفاده از Azure Resource Graph، که به دستیاران هوش مصنوعی امکان کاوش و نظارت بر زیرساخت Azure را می‌دهد.
- [jdubois/azure-cli-mcp](https://github.com/jdubois/azure-cli-mcp) - یک پوشش دور خط فرمان Azure CLI که به شما امکان می‌دهد مستقیماً با Azure صحبت کنید
- [johnneerdael/netskope-mcp](https://github.com/johnneerdael/netskope-mcp) 🔒 ☁️ - یک MCP برای دسترسی به تمام اجزای Netskope Private Access در محیط‌های Netskope Private Access شامل اطلاعات دقیق راه‌اندازی و نمونه‌های LLM در مورد استفاده.
- [kestra-io/mcp-server-python](https://github.com/kestra-io/mcp-server-python) 🐍 ☁️ - پیاده‌سازی سرور MCP برای پلتفرم هماهنگ‌سازی گردش کار [Kestra](https://kestra.io).
- [liveblocks/liveblocks-mcp-server](https://github.com/liveblocks/liveblocks-mcp-server) 🎖️ 📇 ☁️ - ایجاد، تغییر و حذف جنبه‌های مختلف [Liveblocks](https://liveblocks.io) مانند اتاق‌ها، رشته‌ها، نظرات، اعلان‌ها و موارد دیگر. علاوه بر این، دسترسی خواندن به Storage و Yjs را دارد.
- [manusa/Kubernetes MCP Server](https://github.com/manusa/kubernetes-mcp-server) 🏎️ 🏠 A - سرور قدرتمند Kubernetes MCP با پشتیبانی اضافی برای OpenShift. علاوه بر ارائه عملیات CRUD برای **هر** منبع Kubernetes، این سرور ابزارهای تخصصی برای تعامل با کلاستر شما فراهم می‌کند.
- [Nebula-Block-Data/nebulablock-mcp-server](https://github.com/Nebula-Block-Data/nebulablock-mcp-server) 📇 🏠 - با کتابخانه fastmcp یکپارچه می‌شود تا طیف کاملی از قابلیت‌های NebulaBlock API را به عنوان ابزارهای قابل دسترس در معرض دید قرار دهد
- [nwiizo/tfmcp](https://github.com/nwiizo/tfmcp) - 🦀 🏠 - یک سرور Terraform MCP که به دستیاران هوش مصنوعی امکان مدیریت و عملیات محیط‌های Terraform را می‌دهد و خواندن پیکربندی‌ها، تحلیل planها، اعمال پیکربندی‌ها و مدیریت state Terraform را امکان‌پذیر می‌کند.
- [openstack-kr/python-openstackmcp-server](https://github.com/openstack-kr/python-openstackmcp-server) 🐍 ☁️ - سرور MCP OpenStack برای مدیریت زیرساخت ابری مبتنی بر openstacksdk.
- [pibblokto/cert-manager-mcp-server](https://github.com/pibblokto/cert-manager-mcp-server) 🐍 🍎/🐧 ☁️ - سرور mcp برای مدیریت و عیب‌یابی [cert-manager](https://github.com/cert-manager/cert-manager)
- [portainer/portainer-mcp](https://github.com/portainer/portainer-mcp) 🏎️ ☁️/🏠 - یک سرور MCP قدرتمند که به دستیاران هوش مصنوعی امکان تعامل یکپارچه با نمونه‌های Portainer را می‌دهد و دسترسی به زبان طبیعی به مدیریت کانتینر، عملیات استقرار و قابلیت‌های نظارت بر زیرساخت را فراهم می‌کند.
- [pulumi/mcp-server](https://github.com/pulumi/mcp-server) 🎖️ 📇 🏠 - سرور MCP برای تعامل با Pulumi با استفاده از Pulumi Automation API و Pulumi Cloud API. به کلاینت‌های MCP امکان انجام عملیات Pulumi مانند بازیابی اطلاعات بسته، پیش‌نمایش تغییرات، استقرار به‌روزرسانی‌ها و بازیابی خروجی‌های stack را به صورت برنامه‌ریزی شده می‌دهد.
- [pythonanywhere/pythonanywhere-mcp-server](https://github.com/pythonanywhere/pythonanywhere-mcp-server) 🐍 🏠 - پیاده‌سازی سرور MCP برای پلتفرم ابری PythonAnywhere.
- [qiniu/qiniu-mcp-server](https://github.com/qiniu/qiniu-mcp-server) 🐍 ☁️ - یک MCP ساخته شده بر روی محصولات Qiniu Cloud، که از دسترسی به Qiniu Cloud Storage، خدمات پردازش رسانه و غیره پشتیبانی می‌کند.
- [redis/mcp-redis-cloud](https://github.com/redis/mcp-redis-cloud) 📇 ☁️ - منابع Redis Cloud خود را به راحتی با استفاده از زبان طبیعی مدیریت کنید. پایگاه‌های داده ایجاد کنید، اشتراک‌ها را نظارت کنید و استقرارهای ابری را با دستورات ساده پیکربندی کنید.
- [reza-gholizade/k8s-mcp-server](https://github.com/reza-gholizade/k8s-mcp-server) 🏎️ ☁️/🏠 - یک سرور Kubernetes Model Context Protocol (MCP) که ابزارهایی برای تعامل با کلاسترهای Kubernetes از طریق یک رابط استاندارد، شامل کشف منابع API، مدیریت منابع، لاگ‌های pod، معیارها و رویدادها فراهم می‌کند.
- [rohitg00/kubectl-mcp-server](https://github.com/rohitg00/kubectl-mcp-server) 🐍 ☁️/🏠 - یک سرور Model Context Protocol (MCP) برای Kubernetes که به دستیاران هوش مصنوعی مانند Claude، Cursor و دیگران امکان تعامل با کلاسترهای Kubernetes از طریق زبان طبیعی را می‌دهد.
- [rrmistry/tilt-mcp](https://github.com/rrmistry/tilt-mcp) 🐍 🏠 🍎 🪟 🐧 - یک سرور Model Context Protocol که با Tilt یکپارچه می‌شود تا دسترسی برنامه‌ریزی شده به منابع، لاگ‌ها و عملیات مدیریتی Tilt را برای محیط‌های توسعه Kubernetes فراهم کند.
- [silenceper/mcp-k8s](https://github.com/silenceper/mcp-k8s) 🏎️ ☁️/🏠 - MCP-K8S یک ابزار مدیریت منابع Kubernetes مبتنی بر هوش مصنوعی است که به کاربران امکان می‌دهد هر منبعی را در کلاسترهای Kubernetes از طریق تعامل زبان طبیعی، از جمله منابع بومی (مانند Deployment، Service) و منابع سفارشی (CRD) مدیریت کنند. نیازی به به خاطر سپردن دستورات پیچیده نیست - فقط نیازهای خود را توصیف کنید و هوش مصنوعی عملیات مربوطه کلاستر را به دقت اجرا خواهد کرد و قابلیت استفاده از Kubernetes را به شدت افزایش می‌دهد.
- [StacklokLabs/mkp](https://github.com/StacklokLabs/mkp) 🏎️ ☁️ - MKP یک سرور Model Context Protocol (MCP) برای Kubernetes است که به برنامه‌های مبتنی بر LLM امکان تعامل با کلاسترهای Kubernetes را می‌دهد. این سرور ابزارهایی برای لیست کردن و اعمال منابع Kubernetes از طریق پروتکل MCP فراهم می‌کند.
- [StacklokLabs/ocireg-mcp](https://github.com/StacklokLabs/ocireg-mcp) 🏎️ ☁️ - یک سرور MCP مبتنی بر SSE که به برنامه‌های مبتنی بر LLM امکان تعامل با رجیستری‌های OCI را می‌دهد. این سرور ابزارهایی برای بازیابی اطلاعات در مورد تصاویر کانتینر، لیست کردن تگ‌ها و موارد دیگر فراهم می‌کند.
- [strowk/mcp-k8s-go](https://github.com/strowk/mcp-k8s-go) 🏎️ ☁️/🏠 - عملیات کلاستر Kubernetes از طریق MCP
- [thunderboltsid/mcp-nutanix](https://github.com/thunderboltsid/mcp-nutanix) 🏎️ 🏠/☁️ - سرور MCP مبتنی بر Go برای ارتباط با منابع Nutanix Prism Central.
- [trilogy-group/aws-pricing-mcp](https://github.com/trilogy-group/aws-pricing-mcp) 🏎️ ☁️/🏠 - اطلاعات به‌روز قیمت‌گذاری EC2 را با یک تماس دریافت کنید. سریع. با استفاده از یک کاتالوگ قیمت‌گذاری AWS از پیش تجزیه شده.
- [VmLia/books-mcp-server](https://github.com/VmLia/books-mcp-server) 📇 ☁️ - این یک سرور MCP است که برای کوئری کتاب‌ها استفاده می‌شود و می‌تواند در کلاینت‌های رایج MCP مانند Cherry Studio اعمال شود.
- [weibaohui/k8m](https://github.com/weibaohui/k8m) 🏎️ ☁️/🏠 - مدیریت و عملیات چند کلاستر Kubernetes MCP را فراهم می‌کند و دارای یک رابط مدیریتی، لاگ‌گیری و نزدیک به ۵۰ ابزار داخلی برای سناریوهای رایج DevOps و توسعه است. از منابع استاندارد و CRD پشتیبانی می‌کند.
- [weibaohui/kom](https://github.com/weibaohui/kom) 🏎️ ☁️/🏠 - مدیریت و عملیات چند کلاستر Kubernetes MCP را فراهم می‌کند. می‌تواند به عنوان یک SDK در پروژه شما یکپارچه شود و شامل نزدیک به ۵۰ ابزار داخلی برای سناریوهای رایج DevOps و توسعه است. از منابع استاندارد و CRD پشتیبانی می‌کند.
- [wenhuwang/mcp-k8s-eye](https://github.com/wenhuwang/mcp-k8s-eye) 🏎️ ☁️/🏠 - سرور MCP برای مدیریت kubernetes و تحلیل کلاستر و سلامت برنامه شما

### 👨‍💻 <a name="code-execution"></a>اجرای کد

سرورهای اجرای کد. به LLMها اجازه می‌دهد کد را در یک محیط امن اجرا کنند، به عنوان مثال برای عامل‌های کدنویسی.

- [alfonsograziano/node-code-sandbox-mcp](https://github.com/alfonsograziano/node-code-sandbox-mcp) 📇 🏠 – یک سرور MCP Node.js که sandboxهای ایزوله مبتنی بر Docker را برای اجرای قطعه کدهای JavaScript با نصب وابستگی‌های npm در لحظه و تخریب تمیز راه‌اندازی می‌کند
- [ckanthony/openapi-mcp](https://github.com/ckanthony/openapi-mcp) 🏎️ ☁️ - OpenAPI-MCP: سرور MCP داکرایز شده برای اجازه دادن به عامل هوش مصنوعی شما برای دسترسی به هر API با مستندات api موجود.
- [gwbischof/outsource-mcp](https://github.com/gwbischof/outsource-mcp) 🐍 ☁️ - به دستیار هوش مصنوعی خود، دستیاران هوش مصنوعی خودش را بدهید. برای مثال: "می‌توانی از openai بخواهی تصویری از یک سگ تولید کند؟"
- [hileamlakB/PRIMS](https://github.com/hileamlakB/PRIMS) 🐍 🏠 – یک سرور MCP مفسر زمان اجرای Python که کد ارسالی کاربر را در یک محیط ایزوله اجرا می‌کند.
- [ouvreboite/openapi-to-mcp](https://github.com/ouvreboite/openapi-to-mcp) #️⃣ ☁️ - سرور MCP سبک برای دسترسی به هر API با استفاده از مشخصات OpenAPI آن. از OAuth2 و پارامترهای کامل JSON schema و بدنه درخواست پشتیبانی می‌کند.
- [pydantic/pydantic-ai/mcp-run-python](https://github.com/pydantic/pydantic-ai/tree/main/mcp-run-python) 🐍 🏠 - اجرای کد Python در یک sandbox امن از طریق فراخوانی ابزار MCP
- [r33drichards/mcp-js](https://github.com/r33drichards/mcp-js) 🦀 🏠 🐧 🍎 - یک sandbox اجرای کد Javascript که از v8 برای ایزوله کردن کد برای اجرای javascript تولید شده توسط هوش مصنوعی به صورت محلی و بدون ترس استفاده می‌کند. از snapshot گرفتن از heap برای جلسات پایدار پشتیبانی می‌کند.
- [yepcode/mcp-server-js](https://github.com/yepcode/mcp-server-js) 🎖️ 📇 ☁️ - اجرای هر کد تولید شده توسط LLM در یک محیط sandbox امن و مقیاس‌پذیر و ایجاد ابزارهای MCP خود با استفاده از JavaScript یا Python، با پشتیبانی کامل از بسته‌های NPM و PyPI
- [dagger/container-use](https://github.com/dagger/container-use) 🏎️ 🏠 🐧 🍎 🪟 - محیط‌های کانتینری برای عامل‌های کدنویسی. چندین عامل می‌توانند به طور مستقل کار کنند، در کانتینرها و شاخه‌های git تازه ایزوله شده‌اند. بدون تداخل، آزمایش‌های فراوان. تاریخچه کامل اجرا، دسترسی به ترمینال به محیط‌های عامل، گردش کار git. هر پشته عامل/مدل/زیرساخت.

### 🤖 <a name="coding-agents"></a>عامل‌های کدنویسی

عامل‌های کدنویسی کامل که به LLMها امکان خواندن، ویرایش و اجرای کد و حل وظایف برنامه‌نویسی عمومی را به طور کاملاً خودکار می‌دهند.

- [doggybee/mcp-server-leetcode](https://github.com/doggybee/mcp-server-leetcode) 📇 ☁️ - یک سرور MCP که به مدل‌های هوش مصنوعی امکان جستجو، بازیابی و حل مسائل LeetCode را می‌دهد. از فیلتر کردن متادیتا، پروفایل‌های کاربری، ارسال‌ها و دسترسی به داده‌های مسابقه پشتیبانی می‌کند.
- [ezyang/codemcp](https://github.com/ezyang/codemcp) 🐍 🏠 - عامل کدنویسی با ابزارهای پایه خواندن، نوشتن و خط فرمان.
- [gabrielmaialva33/winx-code-agent](https://github.com/gabrielmaialva33/winx-code-agent) 🦀 🏠 - یک پیاده‌سازی مجدد Rust با کارایی بالا از WCGW برای عامل‌های کد، که اجرای shell و قابلیت‌های پیشرفته مدیریت فایل را برای LLMها از طریق MCP فراهم می‌کند.
- [jinzcdev/leetcode-mcp-server](https://github.com/jinzcdev/leetcode-mcp-server) 📇 ☁️ - سرور MCP که دسترسی خودکار به مسائل برنامه‌نویسی، راه‌حل‌ها، ارسال‌ها و داده‌های عمومی **LeetCode** را با احراز هویت اختیاری برای ویژگی‌های خاص کاربر (مانند یادداشت‌ها) امکان‌پذیر می‌کند و از سایت‌های `leetcode.com` (جهانی) و `leetcode.cn` (چین) پشتیبانی می‌کند.
- [juehang/vscode-mcp-server](https://github.com/juehang/vscode-mcp-server) 📇 🏠 - یک سرور MCP که به هوش مصنوعی مانند Claude اجازه می‌دهد از ساختار دایرکتوری در یک فضای کاری VS Code بخواند، مشکلاتی که توسط linter(s) و سرور زبان شناسایی شده‌اند را ببیند، فایل‌های کد را بخواند و ویرایش کند.
- [micl2e2/code-to-tree](https://github.com/micl2e2/code-to-tree) 🌊 🏠 📟 🐧 🪟 🍎 - یک سرور MCP تک-باینری که کد منبع را بدون توجه به زبان به AST تبدیل می‌کند.
- [oraios/serena](https://github.com/oraios/serena) 🐍 🏠 - یک عامل کدنویسی کاملاً مجهز که با استفاده از سرورهای زبان به عملیات کد نمادین متکی است.
- [pdavis68/RepoMapper](https://github.com.mcas.ms/pdavis68/RepoMapper) 🐧 🪟 🍎 - یک سرور MCP (و ابزار خط فرمان) برای ارائه یک نقشه پویا از فایل‌های مرتبط با چت از مخزن با پروتوتایپ‌های تابع آنها و فایل‌های مرتبط به ترتیب اهمیت. بر اساس عملکرد "Repo Map" در Aider.chat
- [rinadelph/Agent-MCP](https://github.com/rinadelph/Agent-MCP) 🐍 🏠 - چارچوبی برای ایجاد سیستم‌های چند-عاملی با استفاده از MCP برای همکاری هماهنگ هوش مصنوعی، با مدیریت وظایف، زمینه مشترک و قابلیت‌های RAG.
- [stippi/code-assistant](https://github.com/stippi/code-assistant) 🦀 🏠 - عامل کدنویسی با ابزارهای پایه list، read، replace_in_file، write، execute_command و جستجوی وب. از چندین پروژه به طور همزمان پشتیبانی می‌کند.
- [tiianhk/MaxMSP-MCP-Server](https://github.com/tiianhk/MaxMSP-MCP-Server) 🐍 🏠 🎵 🎥 - یک عامل کدنویسی برای Max (Max/MSP/Jitter)، که یک زبان برنامه‌نویسی بصری برای موسیقی و چندرسانه‌ای است.
- [nesquikm/mcp-rubber-duck](https://github.com/nesquikm/mcp-rubber-duck) 📇 🏠 ☁️ - یک سرور MCP که به چندین LLM سازگار با OpenAI متصل می‌شود - پنل اشکال‌زدایی rubber duck هوش مصنوعی شما برای توضیح مشکلات به "duck"های مختلف هوش مصنوعی و دریافت دیدگاه‌های متفاوت
- [VertexStudio/developer](https://github.com/VertexStudio/developer) 🦀 🏠 🍎 🪟 🐧 - ابزارهای جامع توسعه‌دهنده برای ویرایش فایل، اجرای دستورات shell و قابلیت‌های ضبط صفحه
- [wende/cicada](https://github.com/wende/cicada) 🐍 🏠 🍎 🪟 🐧 - هوش کد برای Elixir: جستجوی ماژول، ردیابی تابع و انتساب PR از طریق تجزیه AST tree-sitter

### 🖥️ <a name="command-line"></a>خط فرمان

اجرای دستورات، گرفتن خروجی و تعامل با shellها و ابزارهای خط فرمان.

- [automateyournetwork/pyATS_MCP](https://github.com/automateyournetwork/pyATS_MCP) - سرور Cisco pyATS که تعامل ساختاریافته و مبتنی بر مدل با دستگاه‌های شبکه را امکان‌پذیر می‌کند.
- [aymericzip/intlayer](https://github.com/aymericzip/intlayer) 📇 ☁️ 🏠 - یک سرور MCP که IDE شما را با کمک‌های مبتنی بر هوش مصنوعی برای ابزار Intlayer i18n / CMS تقویت می‌کند: دسترسی هوشمند به CLI، دسترسی به مستندات.
- [ferrislucas/iterm-mcp](https://github.com/ferrislucas/iterm-mcp) 🖥️ 🛠️ 💬 - یک سرور Model Context Protocol که دسترسی به iTerm را فراهم می‌کند. می‌توانید دستورات را اجرا کنید و در مورد آنچه در ترمینال iTerm می‌بینید سؤال بپرسید.
- [g0t4/mcp-server-commands](https://github.com/g0t4/mcp-server-commands) 📇 🏠 - اجرای هر دستوری با ابزارهای `run_command` و `run_script`.
- [maxim-saplin/mcp_safe_local_python_executor](https://github.com/maxim-saplin/mcp_safe_local_python_executor) - مفسر Python امن مبتنی بر `LocalPythonExecutor` از HF Smolagents
- [misiektoja/kill-process-mcp](https://github.com/misiektoja/kill-process-mcp) 🐍 🏠 🍎 🪟 🐧 - لیست کردن و خاتمه دادن به فرآیندهای سیستم عامل از طریق کوئری‌های زبان طبیعی
- [MladenSU/cli-mcp-server](https://github.com/MladenSU/cli-mcp-server) 🐍 🏠 - رابط خط فرمان با اجرای امن و سیاست‌های امنیتی قابل تنظیم
- [OthmaneBlial/term_mcp_deepseek](https://github.com/OthmaneBlial/term_mcp_deepseek) 🐍 🏠 - یک سرور شبیه MCP DeepSeek برای ترمینال
- [sonirico/mcp-shell](https://github.com/sonirico/mcp-shell) - 🏎️ 🏠 🍎 🪟 🐧 به هوش مصنوعی دست بدهید. سرور MCP برای اجرای امن، قابل حسابرسی و بر حسب تقاضای دستورات shell در محیط‌های ایزوله مانند docker.
- [tufantunc/ssh-mcp](https://github.com/tufantunc/ssh-mcp) 📇 🏠 🐧 🪟 - سرور MCP که کنترل SSH برای سرورهای Linux و Windows را از طریق Model Context Protocol در معرض دید قرار می‌دهد. اجرای امن دستورات shell راه دور با احراز هویت رمز عبور یا کلید SSH.
- [tumf/mcp-shell-server](https://github.com/tumf/mcp-shell-server) - یک سرور اجرای دستور shell امن که Model Context Protocol (MCP) را پیاده‌سازی می‌کند
- [wonderwhy-er/DesktopCommanderMCP](https://github.com/wonderwhy-er/DesktopCommanderMCP) 📇 🏠 🍎 🪟 🐧 - یک چاقوی سوئیسی که می‌تواند برنامه‌ها را مدیریت/اجرا کند و فایل‌های کد و متنی را بخواند/بنویسد/جستجو/ویرایش کند.

### 💬 <a name="communication"></a>ارتباطات

یکپارچه‌سازی با پلتفرم‌های ارتباطی برای مدیریت پیام و عملیات کانال. به مدل‌های هوش مصنوعی امکان تعامل با ابزارهای ارتباطی تیمی را می‌دهد.

- [AbdelStark/nostr-mcp](https://github.com/AbdelStark/nostr-mcp) ☁️ - یک سرور MCP Nostr که امکان تعامل با Nostr، ارسال یادداشت و موارد دیگر را می‌دهد.
- [adhikasp/mcp-twikit](https://github.com/adhikasp/mcp-twikit) 🐍 ☁️ - تعامل با جستجو و تایم‌لاین توییتر
- [agentmail-toolkit/mcp](https://github.com/agentmail-to/agentmail-toolkit/tree/main/mcp) 🐍 💬 - یک سرور MCP برای ایجاد صندوق‌های ورودی در لحظه برای ارسال، دریافت و انجام اقدامات روی ایمیل. ما عامل‌های هوش مصنوعی برای ایمیل نیستیم، بلکه ایمیل برای عامل‌های هوش مصنوعی هستیم.
- [areweai/tsgram-mcp](https://github.com/areweai/tsgram-mcp) - TSgram: تلگرام + Claude با دسترسی به فضای کاری محلی روی گوشی شما در typescript. در حین حرکت کد بخوانید، بنویسید و لذت ببرید!
- [arpitbatra123/mcp-googletasks](https://github.com/arpitbatra123/mcp-googletasks) 📇 ☁️ - یک سرور MCP برای ارتباط با Google Tasks API
- [Cactusinhand/mcp_server_notify](https://github.com/Cactusinhand/mcp_server_notify) 🐍 🏠 - یک سرور MCP که هنگام تکمیل وظایف عامل، اعلان‌های دسکتاپ را با جلوه صوتی ارسال می‌کند.
- [PhononX/cv-mcp-server](https://github.com/PhononX/cv-mcp-server) 🎖️ 📇 🏠 ☁️ 🍎 🪟 🐧 - سرور MCP که عامل‌های هوش مصنوعی را به [Carbon Voice](https://getcarbon.app) متصل می‌کند. ایجاد، مدیریت و تعامل با پیام‌های صوتی، مکالمات، پیام‌های مستقیم، پوشه‌ها، یادداشت‌های صوتی، اقدامات هوش مصنوعی و موارد دیگر در [Carbon Voice](https://getcarbon.app).
- [carterlasalle/mac_messages_mcp](https://github.com/carterlasalle/mac_messages_mcp) 🏠 🍎 🚀 - یک سرور MCP که به طور امن با پایگاه داده iMessage شما از طریق Model Context Protocol (MCP) ارتباط برقرار می‌کند و به LLMها امکان کوئری و تحلیل مکالمات iMessage را می‌دهد. این سرور شامل اعتبارسنجی قوی شماره تلفن، پردازش پیوست، مدیریت مخاطبین، مدیریت چت گروهی و پشتیبانی کامل از ارسال و دریافت پیام است.
- [chaindead/telegram-mcp](https://github.com/chaindead/telegram-mcp) 🏎️ 🏠 - یکپارچه‌سازی با Telegram API برای دسترسی به داده‌های کاربر، مدیریت گفتگوها (چت‌ها، کانال‌ها، گروه‌ها)، بازیابی پیام‌ها و مدیریت وضعیت خوانده شدن
- [chigwell/telegram-mcp](https://github.com/chigwell/telegram-mcp) 🐍 🏠 - یکپارچه‌سازی با Telegram API برای دسترسی به داده‌های کاربر، مدیریت گفتگوها (چت‌ها، کانال‌ها، گروه‌ها)، بازیابی پیام‌ها، ارسال پیام‌ها و مدیریت وضعیت خوانده شدن.
- [Danielpeter-99/calcom-mcp](https://github.com/Danielpeter-99/calcom-mcp) 🐍 🏠 - سرور MCP برای Calcom. مدیریت انواع رویدادها، ایجاد رزروها و دسترسی به داده‌های زمان‌بندی Cal.com از طریق LLMها.
- [elie222/inbox-zero](https://github.com/elie222/inbox-zero/tree/main/apps/mcp-server) 🐍 ☁️ - یک سرور MCP برای Inbox Zero. عملکردهایی را به Gmail اضافه می‌کند مانند پیدا کردن ایمیل‌هایی که باید به آنها پاسخ دهید یا باید آنها را پیگیری کنید.
- [gerkensm/callcenter.js-mcp](https://github.com/gerkensm/callcenter.js-mcp) 📇 ☁️ - یک سرور MCP برای برقراری تماس‌های تلفنی با استفاده از VoIP/SIP و Realtime API OpenAI و مشاهده رونوشت.
- [gitmotion/ntfy-me-mcp](https://github.com/gitmotion/ntfy-me-mcp) 📇 ☁️ 🏠 - یک سرور MCP ntfy برای ارسال/دریافت اعلان‌های ntfy به سرور ntfy خودمیزبان شما از عامل‌های هوش مصنوعی 📤 (پشتیبانی از احراز هویت توکن امن و موارد دیگر - با npx یا docker استفاده کنید!)
- [gotoolkits/wecombot](https://github.com/gotoolkits/mcp-wecombot-server.git) 🚀 ☁️ - یک برنامه سرور MCP که انواع مختلف پیام‌ها را به ربات گروه WeCom ارسال می‌کند.
- [hannesrudolph/imessage-query-fastmcp-mcp-server](https://github.com/hannesrudolph/imessage-query-fastmcp-mcp-server) 🐍 🏠 🍎 - یک سرور MCP که دسترسی ایمن به پایگاه داده iMessage شما را از طریق Model Context Protocol (MCP) فراهم می‌کند و به LLMها امکان کوئری و تحلیل مکالمات iMessage با اعتبارسنجی صحیح شماره تلفن و مدیریت پیوست را می‌دهد
- [i-am-bee/acp-mcp](https://github.com/i-am-bee/acp-mcp) 🐍 💬 - یک سرور MCP که به عنوان یک آداپتور به اکوسیستم [ACP](https://agentcommunicationprotocol.dev) عمل می‌کند. به طور یکپارچه عامل‌های ACP را به کلاینت‌های MCP در معرض دید قرار می‌دهد و شکاف ارتباطی بین دو پروتکل را پر می‌کند.
- [InditexTech/mcp-teams-server](https://github.com/InditexTech/mcp-teams-server) 🐍 ☁️ - سرور MCP که پیام‌رسانی Microsoft Teams را یکپارچه می‌کند (خواندن، ارسال، منشن کردن، لیست کردن اعضا و رشته‌ها)
- [Infobip/mcp](https://github.com/infobip/mcp) 🎖️ ☁️ - سرور MCP رسمی Infobip برای یکپارچه‌سازی پلتفرم ارتباطی ابری جهانی Infobip. این سرور عامل‌های هوش مصنوعی را به ابرقدرت‌های ارتباطی مجهز می‌کند و به آنها اجازه می‌دهد پیام‌های SMS و RCS ارسال و دریافت کنند، با WhatsApp و Viber تعامل داشته باشند، گردش‌های کاری ارتباطی را خودکار کنند و داده‌های مشتری را مدیریت کنند، همه در یک محیط آماده برای تولید.
- [jagan-shanmugam/mattermost-mcp-host](https://github.com/jagan-shanmugam/mattermost-mcp-host) 🐍 🏠 - یک سرور MCP همراه با میزبان MCP که دسترسی به تیم‌ها، کانال‌ها و پیام‌های Mattermost را فراهم می‌کند. میزبان MCP به عنوان یک ربات در Mattermost با دسترسی به سرورهای MCP که می‌توانند پیکربندی شوند، یکپارچه شده است.
- [jaipandya/producthunt-mcp-server](https://github.com/jaipandya/producthunt-mcp-server) 🐍 🏠 - سرور MCP برای Product Hunt. تعامل با پست‌های پرطرفدار، نظرات، مجموعه‌ها، کاربران و موارد دیگر.
- [joinly-ai/joinly](https://github.com/joinly-ai/joinly) 🐍☁️ - سرور MCP برای تعامل با پلتفرم‌های جلسات مبتنی بر مرورگر (Zoom، Teams، Google Meet). به عامل‌های هوش مصنوعی امکان ارسال ربات‌ها به جلسات آنلاین، جمع‌آوری رونوشت‌های زنده، صحبت کردن متن و ارسال پیام در چت جلسه را می‌دهد.
- [keturiosakys/bluesky-context-server](https://github.com/keturiosakys/bluesky-context-server) 📇 ☁️ - یکپارچه‌سازی با نمونه Bluesky برای کوئری و تعامل
- [khan2a/telephony-mcp-server](https://github.com/khan2a/telephony-mcp-server) 🐍 💬 - سرور تلفنی MCP برای اتوماسیون تماس‌های صوتی با تبدیل گفتار به متن و تشخیص گفتار برای خلاصه‌سازی مکالمات تماس. ارسال و دریافت SMS، تشخیص پست صوتی و یکپارچه‌سازی با APIهای Vonage برای گردش‌های کاری تلفنی پیشرفته.
- [korotovsky/slack-mcp-server](https://github.com/korotovsky/slack-mcp-server) 📇 ☁️ - قدرتمندترین سرور MCP برای فضاهای کاری Slack.
- [lharries/whatsapp-mcp](https://github.com/lharries/whatsapp-mcp) 🐍 🏎️ - یک سرور MCP برای جستجوی پیام‌های شخصی WhatsApp، مخاطبین و ارسال پیام به افراد یا گروه‌ها
- [line/line-bot-mcp-server](https://github.com/line/line-bot-mcp-server) 🎖 📇 ☁️ - سرور MCP برای یکپارچه‌سازی حساب رسمی LINE
- [OverQuotaAI/chatterboxio-mcp-server](https://github.com/OverQuotaAI/chatterboxio-mcp-server) 📇 ☁️ - پیاده‌سازی سرور MCP برای ChatterBox.io، که به عامل‌های هوش مصنوعی امکان ارسال ربات‌ها به جلسات آنلاین (Zoom، Google Meet) و به دست آوردن رونوشت‌ها و ضبط‌ها را می‌دهد.
- [wyattjoh/imessage-mcp](https://github.com/wyattjoh/imessage-mcp) 📇 🏠 🍎 - یک سرور Model Context Protocol برای خواندن داده‌های iMessage از macOS.
- [sawa-zen/vrchat-mcp](https://github.com/sawa-zen/vrchat-mcp) - 📇 🏠 این یک سرور MCP برای تعامل با VRChat API است. می‌توانید اطلاعات مربوط به دوستان، دنیاها، آواتارها و موارد دیگر را در VRChat بازیابی کنید.
- [softeria/ms-365-mcp-server](https://github.com/softeria/ms-365-mcp-server) 📇 ☁️ - سرور MCP که به Microsoft Office و کل مجموعه Microsoft 365 با استفاده از Graph API (شامل Outlook، ایمیل، فایل‌ها، Excel، تقویم) متصل می‌شود
- [saseq/discord-mcp](https://github.com/SaseQ/discord-mcp) ☕ 📇 🏠 💬 - یک سرور MCP برای یکپارچه‌سازی با Discord. دستیاران هوش مصنوعی خود را قادر سازید تا به طور یکپارچه با Discord تعامل داشته باشند. تجربه Discord خود را با قابلیت‌های اتوماسیون قدرتمند افزایش دهید.
- [teddyzxcv/ntfy-mcp](https://github.com/teddyzxcv/ntfy-mcp) - سرور MCP که شما را با ارسال اعلان بر روی گوشی با استفاده از ntfy مطلع نگه می‌دارد
- [userad/didlogic_mcp](https://github.com/UserAd/didlogic_mcp) 🐍 ☁️ - یک سرور MCP برای [DIDLogic](https://didlogic.com). عملکردهایی برای مدیریت نقاط پایانی SIP، شماره‌ها و مقاصد اضافه می‌کند.
- [YCloud-Developers/ycloud-whatsapp-mcp-server](https://github.com/YCloud-Developers/ycloud-whatsapp-mcp-server) 📇 🏠 - سرور MCP برای پلتفرم تجاری WhatsApp توسط YCloud.
- [zcaceres/gtasks-mcp](https://github.com/zcaceres/gtasks-mcp) 📇 ☁️ - یک سرور MCP برای مدیریت Google Tasks
- [ztxtxwd/open-feishu-mcp-server](https://github.com/ztxtxwd/open-feishu-mcp-server) 📇 ☁️ 🏠 - یک سرور Model Context Protocol (MCP) با احراز هویت Feishu OAuth داخلی، که از اتصالات راه دور پشتیبانی می‌کند و ابزارهای جامع مدیریت اسناد Feishu شامل ایجاد بلوک، به‌روزرسانی محتوا و ویژگی‌های پیشرفته را ارائه می‌دهد.


### 👤 <a name="customer-data-platforms"></a>پلتفرم‌های داده مشتری

دسترسی به پروفایل‌های مشتری در داخل پلتفرم‌های داده مشتری را فراهم می‌کند

- [antv/mcp-server-chart](https://github.com/antvis/mcp-server-chart) 🎖️ 📇 ☁️ - یک سرور Model Context Protocol برای تولید نمودارهای بصری با استفاده از [AntV](https://github.com/antvis).
- [hustcc/mcp-echarts](https://github.com/hustcc/mcp-echarts) 📇 🏠 - تولید نمودارهای بصری با استفاده از [Apache ECharts](https://echarts.apache.org) با AI MCP به صورت پویا.
- [hustcc/mcp-mermaid](https://github.com/hustcc/mcp-mermaid) 📇 🏠 - تولید نمودار و چارت [mermaid](https://mermaid.js.org/) با AI MCP به صورت پویا.
- [iaptic/mcp-server-iaptic](https://github.com/iaptic/mcp-server-iaptic) 🎖️ 📇 ☁️ - با [iaptic](https://www.iaptic.com) متصل شوید تا در مورد خریدهای مشتری، داده‌های تراکنش و آمار درآمد برنامه خود سؤال کنید.
- [OpenDataMCP/OpenDataMCP](https://github.com/OpenDataMCP/OpenDataMCP) 🐍 ☁️ - هر داده باز را به هر LLM با Model Context Protocol متصل کنید.
- [sergehuber/inoyu-mcp-unomi-server](https://github.com/sergehuber/inoyu-mcp-unomi-server) 📇 ☁️ - یک سرور MCP برای دسترسی و به‌روزرسانی پروفایل‌ها در یک سرور Apache Unomi CDP.
- [tinybirdco/mcp-tinybird](https://github.com/tinybirdco/mcp-tinybird) 🐍 ☁️ - یک سرور MCP برای تعامل با یک فضای کاری Tinybird از هر کلاینت MCP.

### 🗄️ <a name="databases"></a>پایگاه‌های داده

دسترسی امن به پایگاه داده با قابلیت‌های بازرسی schema. امکان کوئری و تحلیل داده‌ها با کنترل‌های امنیتی قابل تنظیم شامل دسترسی فقط خواندنی را فراهم می‌کند.

- [Aiven-Open/mcp-aiven](https://github.com/Aiven-Open/mcp-aiven) - 🐍 ☁️ 🎖️ - در [پروژه‌های Aiven](https://go.aiven.io/mcp-server) خود پیمایش کنید و با سرویس‌های PostgreSQL®، Apache Kafka®، ClickHouse® و OpenSearch® تعامل داشته باشید
- [alexanderzuev/supabase-mcp-server](https://github.com/alexander-zuev/supabase-mcp-server) - سرور MCP Supabase با پشتیبانی از اجرای کوئری SQL و ابزارهای کاوش پایگاه داده
- [aliyun/alibabacloud-tablestore-mcp-server](https://github.com/aliyun/alibabacloud-tablestore-mcp-server) ☕ 🐍 ☁️ - سرویس MCP برای Tablestore، ویژگی‌ها شامل اضافه کردن اسناد، جستجوی معنایی برای اسناد بر اساس بردارها و اسکالرها، سازگار با RAG، و بدون سرور است.
- [amineelkouhen/mcp-cockroachdb](https://github.com/amineelkouhen/mcp-cockroachdb) 🐍 ☁️ - یک سرور Model Context Protocol برای مدیریت، نظارت و کوئری داده‌ها در [CockroachDB](https://cockroachlabs.com).
- [benborla29/mcp-server-mysql](https://github.com/benborla/mcp-server-mysql) ☁️ 🏠 - یکپارچه‌سازی پایگاه داده MySQL در NodeJS با کنترل‌های دسترسی قابل تنظیم و بازرسی schema
- [bram2w/baserow](https://github.com/bram2w/baserow) - یکپارچه‌سازی پایگاه داده Baserow با قابلیت‌های جستجو، لیست کردن، و ایجاد، خواندن، به‌روزرسانی و حذف ردیف‌ها.
- [c4pt0r/mcp-server-tidb](https://github.com/c4pt0r/mcp-server-tidb) 🐍 ☁️ - یکپارچه‌سازی پایگاه داده TiDB با قابلیت‌های بازرسی schema و کوئری
- [Canner/wren-engine](https://github.com/Canner/wren-engine) 🐍 🦀 🏠 - موتور معنایی برای کلاینت‌های Model Context Protocol (MCP) و عامل‌های هوش مصنوعی
- [centralmind/gateway](https://github.com/centralmind/gateway) 🏎️ 🏠 🍎 🪟 - سرور MCP و MCP SSE که به طور خودکار API را بر اساس schema و داده‌های پایگاه داده تولید می‌کند. از PostgreSQL، Clickhouse، MySQL، Snowflake، BigQuery، Supabase پشتیبانی می‌کند
- [ChristianHinge/dicom-mcp](https://github.com/ChristianHinge/dicom-mcp) 🐍 ☁️ 🏠 - یکپارچه‌سازی با DICOM برای کوئری، خواندن و انتقال تصاویر و گزارش‌های پزشکی از PACS و سایر سیستم‌های سازگار با DICOM.
- [chroma-core/chroma-mcp](https://github.com/chroma-core/chroma-mcp) 🎖️ 🐍 ☁️ 🏠 - سرور MCP Chroma برای دسترسی به نمونه‌های محلی و ابری Chroma برای قابلیت‌های بازیابی
- [ClickHouse/mcp-clickhouse](https://github.com/ClickHouse/mcp-clickhouse) 🐍 ☁️ - یکپارچه‌سازی پایگاه داده ClickHouse با قابلیت‌های بازرسی schema و کوئری
- [confluentinc/mcp-confluent](https://github.com/confluentinc/mcp-confluent) 🐍 ☁️ - یکپارچه‌سازی با Confluent برای تعامل با Confluent Kafka و APIهای REST Confluent Cloud.
- [Couchbase-Ecosystem/mcp-server-couchbase](https://github.com/Couchbase-Ecosystem/mcp-server-couchbase) 🎖️ 🐍 ☁️ 🏠 - سرور MCP Couchbase دسترسی یکپارچه به هر دو کلاستر ابری Capella و خود-مدیریت شده را برای عملیات اسناد، کوئری‌های SQL++ و تحلیل داده‌های زبان طبیعی فراهم می‌کند.
- [cr7258/elasticsearch-mcp-server](https://github.com/cr7258/elasticsearch-mcp-server) 🐍 🏠 - پیاده‌سازی سرور MCP که تعامل با Elasticsearch را فراهم می‌کند
- [crystaldba/postgres-mcp](https://github.com/crystaldba/postgres-mcp) 🐍 🏠 - سرور MCP همه‌کاره برای توسعه و عملیات Postgres، با ابزارهایی برای تحلیل عملکرد، تنظیم و بررسی سلامت
- [Dataring-engineering/mcp-server-trino](https://github.com/Dataring-engineering/mcp-server-trino) 🐍 ☁️ - سرور MCP Trino برای کوئری و دسترسی به داده‌ها از کلاسترهای Trino.
- [davewind/mysql-mcp-server](https://github.com/dave-wind/mysql-mcp-server) 🏎️ 🏠 A – سرور mcp mysql فقط-خواندنی کاربرپسند برای cursor و n8n...
- [designcomputer/mysql_mcp_server](https://github.com/designcomputer/mysql_mcp_server) 🐍 🏠 - یکپارچه‌سازی پایگاه داده MySQL با کنترل‌های دسترسی قابل تنظیم، بازرسی schema و دستورالعمل‌های امنیتی جامع
- [domdomegg/airtable-mcp-server](https://github.com/domdomegg/airtable-mcp-server) 📇 🏠 - یکپارچه‌سازی پایگاه داده Airtable با بازرسی schema، قابلیت‌های خواندن و نوشتن
- [edwinbernadus/nocodb-mcp-server](https://github.com/edwinbernadus/nocodb-mcp-server) 📇 ☁️ - یکپارچه‌سازی پایگاه داده Nocodb، قابلیت‌های خواندن و نوشتن
- [ergut/mcp-bigquery-server](https://github.com/ergut/mcp-bigquery-server) 📇 ☁️ - پیاده‌سازی سرور برای یکپارچه‌سازی با Google BigQuery که دسترسی مستقیم به پایگاه داده BigQuery و قابلیت‌های کوئری را امکان‌پذیر می‌کند
- [f4ww4z/mcp-mysql-server](https://github.com/f4ww4z/mcp-mysql-server) 📇 🏠 - یکپارچه‌سازی پایگاه داده MySQL مبتنی بر Node.js که عملیات پایگاه داده MySQL امن را فراهم می‌کند
- [ferrants/memvid-mcp-server](https://github.com/ferrants/memvid-mcp-server) 🐍 🏠 - سرور HTTP قابل استریم Python که می‌توانید به صورت محلی برای تعامل با ذخیره‌سازی و جستجوی معنایی [memvid](https://github.com/Olow304/memvid) اجرا کنید.
- [fireproof-storage/mcp-database-server](https://github.com/fireproof-storage/mcp-database-server) 📇 ☁️ - پایگاه داده لجر Fireproof با همگام‌سازی چند کاربره
- [freema/mcp-gsheets](https://github.com/freema/mcp-gsheets) 📇 ☁️ - سرور MCP برای یکپارچه‌سازی با Google Sheets API با قابلیت‌های جامع خواندن، نوشتن، قالب‌بندی و مدیریت شیت.
- [FreePeak/db-mcp-server](https://github.com/FreePeak/db-mcp-server) 🏎️ 🏠 – یک سرور MCP چند-پایگاه داده با کارایی بالا ساخته شده با Golang، که از MySQL و PostgreSQL پشتیبانی می‌کند (NoSQL به زودی). شامل ابزارهای داخلی برای اجرای کوئری، مدیریت تراکنش، کاوش schema، ساخت کوئری و تحلیل عملکرد، با یکپارچه‌سازی یکپارچه Cursor برای گردش‌های کاری پیشرفته پایگاه داده.
- [furey/mongodb-lens](https://github.com/furey/mongodb-lens) 📇 🏠 - MongoDB Lens: سرور MCP کاملاً مجهز برای پایگاه‌های داده MongoDB
- [gannonh/firebase-mcp](https://github.com/gannonh/firebase-mcp) 🔥 ⛅️ - خدمات Firebase شامل Auth، Firestore و Storage.
- [get-convex/convex-backend](https://stack.convex.dev/convex-mcp-server) 📇 ☁️ - یکپارچه‌سازی پایگاه داده Convex برای بازرسی جداول، توابع و اجرای کوئری‌های یک‌باره ([منبع](https://github.com/get-convex/convex-backend/blob/main/npm-packages/convex/src/cli/mcp.ts))
- [googleapis/genai-toolbox](https://github.com/googleapis/genai-toolbox) 🏎️ ☁️ - سرور MCP منبع باز متخصص در ابزارهای آسان، سریع و امن برای پایگاه‌های داده.
- [GreptimeTeam/greptimedb-mcp-server](https://github.com/GreptimeTeam/greptimedb-mcp-server) 🐍 🏠 - سرور MCP برای کوئری GreptimeDB.
- [hannesrudolph/sqlite-explorer-fastmcp-mcp-server](https://github.com/hannesrudolph/sqlite-explorer-fastmcp-mcp-server) 🐍 🏠 - یک سرور MCP که دسترسی ایمن و فقط-خواندنی به پایگاه‌های داده SQLite را از طریق Model Context Protocol (MCP) فراهم می‌کند. این سرور با چارچوب FastMCP ساخته شده است که به LLMها امکان کاوش و کوئری پایگاه‌های داده SQLite با ویژگی‌های ایمنی داخلی و اعتبارسنجی کوئری را می‌دهد.
- [henilcalagiya/google-sheets-mcp](https://github.com/henilcalagiya/google-sheets-mcp) 🐍 🏠 - دروازه دستیار هوش مصنوعی شما به Google Sheets! ۲۵ ابزار قدرتمند برای اتوماسیون یکپارچه Google Sheets از طریق MCP.
- [hydrolix/mcp-hydrolix](https://github.com/hydrolix/mcp-hydrolix) 🎖️ 🐍 ☁️ - یکپارچه‌سازی با دریاچه داده سری زمانی Hydrolix که قابلیت‌های کاوش schema و کوئری را به گردش‌های کاری مبتنی بر LLM می‌دهد.
- [idoru/influxdb-mcp-server](https://github.com/idoru/influxdb-mcp-server) 📇 ☁️ 🏠 - اجرای کوئری‌ها در برابر InfluxDB OSS API v2.
- [InfluxData/influxdb3_mcp_server](https://github.com/influxdata/influxdb3_mcp_server) 🎖️ 📇 🏠 ☁️ - سرور MCP رسمی برای InfluxDB 3 Core/Enterprise/Cloud Dedicated
- [isaacwasserman/mcp-snowflake-server](https://github.com/isaacwasserman/mcp-snowflake-server) 🐍 ☁️ - یکپارچه‌سازی با Snowflake که عملیات خواندن و (اختیاری) نوشتن و همچنین ردیابی بینش را پیاده‌سازی می‌کند
- [iunera/druid-mcp-server](https://github.com/iunera/druid-mcp-server) ☕ ☁️ 🏠 - سرور MCP جامع برای Apache Druid که ابزارها، منابع و پرامپت‌های گسترده‌ای برای مدیریت و تحلیل کلاسترهای Druid فراهم می‌کند.
- [yannbrrd/simple_snowflake_mcp](https://github.com/YannBrrd/simple_snowflake_mcp) 🐍 ☁️ - سرور MCP ساده Snowflake که پشت یک پروکسی شرکتی کار می‌کند. عملیات خواندن و نوشتن (اختیاری)
- [joshuarileydev/supabase-mcp-server](https://github.com/joshuarileydev/supabase) - سرور MCP Supabase برای مدیریت و ایجاد پروژه‌ها و سازمان‌ها در Supabase
- [jovezhong/mcp-timeplus](https://github.com/jovezhong/mcp-timeplus) 🐍 ☁️ - سرور MCP برای Apache Kafka و Timeplus. قادر به لیست کردن تاپیک‌های Kafka، polling پیام‌های Kafka، ذخیره داده‌های Kafka به صورت محلی و کوئری داده‌های جریانی با SQL از طریق Timeplus
- [jparkerweb/mcp-sqlite](https://github.com/jparkerweb/mcp-sqlite) 📇 🏠 - سرور Model Context Protocol (MCP) که قابلیت‌های جامع تعامل با پایگاه داده SQLite را فراهم می‌کند.
- [KashiwaByte/vikingdb-mcp-server](https://github.com/KashiwaByte/vikingdb-mcp-server) 🐍 ☁️ - یکپارچه‌سازی با VikingDB با معرفی collection و index، ذخیره بردار و قابلیت‌های جستجو.
- [kiliczsh/mcp-mongo-server](https://github.com/kiliczsh/mcp-mongo-server) 📇 🏠 - یک سرور Model Context Protocol برای MongoDB
- [ktanaka101/mcp-server-duckdb](https://github.com/ktanaka101/mcp-server-duckdb) 🐍 🏠 - یکپارچه‌سازی پایگاه داده DuckDB با قابلیت‌های بازرسی schema و کوئری
- [LucasHild/mcp-server-bigquery](https://github.com/LucasHild/mcp-server-bigquery) 🐍 ☁️ - یکپارچه‌سازی پایگاه داده BigQuery با قابلیت‌های بازرسی schema و کوئری
- [memgraph/mcp-memgraph](https://github.com/memgraph/ai-toolkit/tree/main/integrations/mcp-memgraph) 🐍 🏠 - سرور MCP Memgraph - شامل یک ابزار برای اجرای کوئری در برابر Memgraph و یک منبع schema.
- [modelcontextprotocol/server-postgres](https://github.com/modelcontextprotocol/servers/tree/main/src/postgres) 📇 🏠 - یکپارچه‌سازی پایگاه داده PostgreSQL با قابلیت‌های بازرسی schema و کوئری
- [modelcontextprotocol/server-sqlite](https://github.com/modelcontextprotocol/servers/tree/main/src/sqlite) 🐍 🏠 - عملیات پایگاه داده SQLite با ویژگی‌های تحلیل داخلی
- [neo4j-contrib/mcp-neo4j](https://github.com/neo4j-contrib/mcp-neo4j) 🐍 🏠 - Model Context Protocol با Neo4j (اجرای کوئری‌ها، حافظه گراف دانش، مدیریت نمونه‌های Neo4j Aura)
- [neondatabase/mcp-server-neon](https://github.com/neondatabase/mcp-server-neon) 📇 ☁️ — یک سرور MCP برای ایجاد و مدیریت پایگاه‌های داده Postgres با استفاده از Neon Serverless Postgres
- [niledatabase/nile-mcp-server](https://github.com/niledatabase/nile-mcp-server) سرور MCP برای پلتفرم Postgres Nile - مدیریت و کوئری پایگاه‌های داده Postgres، مستأجران، کاربران، احراز هویت با استفاده از LLMها
- [openlink/mcp-server-jdbc](https://github.com/OpenLinkSoftware/mcp-jdbc-server) 🐍 🏠 - یک سرور MCP برای اتصال عمومی به سیستم مدیریت پایگاه داده (DBMS) از طریق پروتکل Java Database Connectivity (JDBC)
- [openlink/mcp-server-odbc](https://github.com/OpenLinkSoftware/mcp-odbc-server) 🐍 🏠 - یک سرور MCP برای اتصال عمومی به سیستم مدیریت پایگاه داده (DBMS) از طریق پروتکل Open Database Connectivity (ODBC)
- [openlink/mcp-server-sqlalchemy](https://github.com/OpenLinkSoftware/mcp-sqlalchemy-server) 🐍 🏠 - یک سرور MCP برای اتصال عمومی به سیستم مدیریت پایگاه داده (DBMS) از طریق SQLAlchemy با استفاده از Python ODBC (pyodbc)
- [pab1it0/adx-mcp-server](https://github.com/pab1it0/adx-mcp-server) 🐍 ☁️ - کوئری و تحلیل پایگاه‌های داده Azure Data Explorer
- [pab1it0/prometheus-mcp-server](https://github.com/pab1it0/prometheus-mcp-server) 🐍 ☁️ - کوئری و تحلیل Prometheus، سیستم نظارت منبع باز.
- [prisma/mcp](https://github.com/prisma/mcp) 📇 ☁️ 🏠 - به LLMها امکان مدیریت پایگاه‌های داده Prisma Postgres را می‌دهد (مثلاً راه‌اندازی پایگاه‌های داده جدید و اجرای migrationها یا کوئری‌ها).
- [qdrant/mcp-server-qdrant](https://github.com/qdrant/mcp-server-qdrant) 🐍 🏠 - یک سرور MCP Qdrant
- [QuantGeekDev/mongo-mcp](https://github.com/QuantGeekDev/mongo-mcp) 📇 🏠 - یکپارچه‌سازی با MongoDB که به LLMها امکان تعامل مستقیم با پایگاه‌های داده را می‌دهد.
- [quarkiverse/mcp-server-jdbc](https://github.com/quarkiverse/quarkus-mcp-servers/tree/main/jdbc) ☕ 🏠 - به هر پایگاه داده سازگار با JDBC متصل شوید و کوئری، درج، به‌روزرسانی، حذف و موارد دیگر را انجام دهید.
- [rashidazarang/airtable-mcp](https://github.com/rashidazarang/airtable-mcp) 🐍 ☁️ - ابزارهای هوش مصنوعی را مستقیماً به Airtable متصل کنید. با استفاده از زبان طبیعی رکوردها را کوئری، ایجاد، به‌روزرسانی و حذف کنید. ویژگی‌ها شامل مدیریت base، عملیات table، دستکاری schema، فیلتر کردن رکورد و انتقال داده از طریق یک رابط MCP استاندارد است.
- [redis/mcp-redis](https://github.com/redis/mcp-redis) 🐍 🏠 - سرور MCP رسمی Redis یک رابط برای مدیریت و جستجوی داده‌ها در Redis ارائه می‌دهد.
- [runekaagaard/mcp-alchemy](https://github.com/runekaagaard/mcp-alchemy) 🐍 🏠 - یکپارچه‌سازی پایگاه داده جهانی مبتنی بر SQLAlchemy که از PostgreSQL، MySQL، MariaDB، SQLite، Oracle، MS SQL Server و بسیاری پایگاه‌های داده دیگر پشتیبانی می‌کند. دارای بازرسی schema و روابط و قابلیت‌های تحلیل مجموعه داده‌های بزرگ است.
- [s2-streamstore/s2-sdk-typescript](https://github.com/s2-streamstore/s2-sdk-typescript) 🎖️ 📇 ☁️ - سرور MCP رسمی برای پلتفرم استریم بدون سرور S2.dev.
- [schemacrawler/SchemaCrawler-MCP-Server-Usage](https://github.com/schemacrawler/SchemaCrawler-MCP-Server-Usage) 🎖️ ☕ – به هر پایگاه داده رابطه‌ای متصل شوید و قادر به دریافت SQL معتبر باشید و سؤالاتی مانند اینکه یک پیشوند ستون خاص به چه معناست را بپرسید.
- [sirmews/mcp-pinecone](https://github.com/sirmews/mcp-pinecone) 🐍 ☁️ - یکپارچه‌سازی با Pinecone با قابلیت‌های جستجوی برداری
- [skysqlinc/skysql-mcp](https://github.com/skysqlinc/skysql-mcp) 🎖️ ☁️ - سرور MCP پایگاه داده ابری بدون سرور MariaDB. ابزارهایی برای راه‌اندازی، حذف، اجرای SQL و کار با عامل‌های هوش مصنوعی سطح پایگاه داده برای تبدیل متن به sql دقیق و مکالمات.
- [Snowflake-Labs/mcp](https://github.com/Snowflake-Labs/mcp) 🐍 ☁️ - سرور MCP منبع باز برای Snowflake از Snowflake-Labs رسمی از پرامپت کردن Cortex Agents، کوئری داده‌های ساختاریافته و بدون ساختار، مدیریت اشیاء، اجرای SQL، کوئری نمای معنایی و موارد دیگر پشتیبانی می‌کند. RBAC، کنترل‌های CRUD دانه‌ریز و تمام روش‌های احراز هویت پشتیبانی می‌شوند.
- [subnetmarco/pgmcp](https://github.com/subnetmarco/pgmcp) 🏎️ 🏠 - کوئری‌های PostgreSQL به زبان طبیعی با استریم خودکار، ایمنی فقط-خواندنی و سازگاری جهانی با پایگاه داده.
- [pgtuner_mcp](https://github.com/isdaniel/pgtuner_mcp) 🐍🗄️ - قابلیت‌های تنظیم عملکرد PostgreSQL مبتنی بر هوش مصنوعی را فراهم می‌کند.
- [supabase-community/supabase-mcp](https://github.com/supabase-community/supabase-mcp) 🎖️ 📇 ☁️ - سرور MCP رسمی Supabase برای اتصال دستیاران هوش مصنوعی مستقیماً به پروژه Supabase شما و اجازه دادن به آنها برای انجام وظایفی مانند مدیریت جداول، دریافت پیکربندی و کوئری داده‌ها.
- [TheRaLabs/legion-mcp](https://github.com/TheRaLabs/legion-mcp) 🐍 🏠 سرور MCP پایگاه داده جهانی که از انواع مختلف پایگاه داده از جمله PostgreSQL، Redshift، CockroachDB، MySQL، RDS MySQL، Microsoft SQL Server، BigQuery، Oracle DB و SQLite پشتیبانی می‌کند.
- [tradercjz/dolphindb-mcp-server](https://github.com/tradercjz/dolphindb-mcp-server) 🐍 ☁️ - یکپارچه‌سازی پایگاه داده TDolphinDB با قابلیت‌های بازرسی schema و کوئری
- [tuannvm/mcp-trino](https://github.com/tuannvm/mcp-trino) 🏎️ ☁️ - یک پیاده‌سازی Go از یک سرور Model Context Protocol (MCP) برای Trino
- [VictoriaMetrics-Community/mcp-victorialogs](https://github.com/VictoriaMetrics-Community/mcp-victorialogs) 🎖️ 🏎️ 🏠 - یکپارچه‌سازی جامع با [APIهای نمونه VictoriaLogs](https://docs.victoriametrics.com/victorialogs/querying/#http-api) و [مستندات](https://docs.victoriametrics.com/victorialogs/) شما برای کار با لاگ‌ها، تحقیق و اشکال‌زدایی وظایف مرتبط با نمونه‌های VictoriaLogs شما را فراهم می‌کند.
- [weaviate/mcp-server-weaviate](https://github.com/weaviate/mcp-server-weaviate) 🐍 📇 ☁️ - یک سرور MCP برای اتصال به مجموعه‌های Weaviate شما به عنوان یک پایگاه دانش و همچنین استفاده از Weaviate به عنوان یک حافظه چت.
- [wenb1n-dev/mysql_mcp_server_pro](https://github.com/wenb1n-dev/mysql_mcp_server_pro)  🐍 🏠 - از SSE، STDIO پشتیبانی می‌کند؛ نه تنها به عملکرد CRUD MySQL محدود نمی‌شود؛ همچنین شامل قابلیت‌های تحلیل استثنای پایگاه داده است؛ مجوزهای پایگاه داده را بر اساس نقش‌ها کنترل می‌کند؛ و گسترش ابزارها را برای توسعه‌دهندگان با سفارشی‌سازی آسان می‌کند
- [xexr/mcp-libsql](https://github.com/Xexr/mcp-libsql) 📇 🏠 ☁️ - سرور MCP آماده برای تولید برای پایگاه‌های داده libSQL با ابزارهای امنیتی و مدیریتی جامع.
- [XGenerationLab/xiyan_mcp_server](https://github.com/XGenerationLab/xiyan_mcp_server) 📇 ☁️ — یک سرور MCP که از دریافت داده‌ها از یک پایگاه داده با استفاده از کوئری‌های زبان طبیعی، با قدرت XiyanSQL به عنوان LLM تبدیل متن به SQL پشتیبانی می‌کند.
- [xing5/mcp-google-sheets](https://github.com/xing5/mcp-google-sheets) 🐍 ☁️ - یک سرور Model Context Protocol برای تعامل با Google Sheets. این سرور ابزارهایی برای ایجاد، خواندن، به‌روزرسانی و مدیریت صفحات گسترده از طریق Google Sheets API فراهم می‌کند.
- [ydb/ydb-mcp](https://github.com/ydb-platform/ydb-mcp) 🎖️ 🐍 ☁️ - سرور MCP برای تعامل با پایگاه‌های داده [YDB](https://ydb.tech)
- [yincongcyincong/VictoriaMetrics-mcp-server](https://github.com/yincongcyincong/VictoriaMetrics-mcp-server) 🐍 🏠 - یک سرور MCP برای تعامل با پایگاه داده VictoriaMetrics.
- [Zhwt/go-mcp-mysql](https://github.com/Zhwt/go-mcp-mysql) 🏎️ 🏠 – سرور MCP MySQL آسان برای استفاده و بدون وابستگی ساخته شده با Golang با حالت فقط-خواندنی قابل تنظیم و بازرسی schema.
- [zilliztech/mcp-server-milvus](https://github.com/zilliztech/mcp-server-milvus) 🐍 🏠 ☁️ - سرور MCP برای Milvus / Zilliz، که امکان تعامل با پایگاه داده شما را فراهم می‌کند.

### 📊 <a name="data-platforms"></a>پلتفرم‌های داده

پلتفرم‌های داده برای یکپارچه‌سازی داده، تبدیل و هماهنگ‌سازی خط لوله.

- [aywengo/kafka-schema-reg-mcp](https://github.com/aywengo/kafka-schema-reg-mcp) 🐍 ☁️ 🏠 🍎 🪟 🐧 - سرور MCP جامع Kafka Schema Registry با ۴۸ ابزار برای مدیریت چند-رجیستری، مهاجرت schema و ویژگی‌های سازمانی.
- [dbt-labs/dbt-mcp](https://github.com/dbt-labs/dbt-mcp) 🎖️ 🐍 🏠 ☁️ - سرور MCP رسمی برای [dbt (data build tool)](https://www.getdbt.com/product/what-is-dbt) که یکپارچه‌سازی با dbt Core/Cloud CLI، کشف متادیتای پروژه، اطلاعات مدل و قابلیت‌های کوئری لایه معنایی را فراهم می‌کند.
- [flowcore/mcp-flowcore-platform](https://github.com/flowcore-io/mcp-flowcore-platform) 🎖️ 📇 ☁️ 🏠 - با Flowcore تعامل داشته باشید تا اقدامات را انجام دهید، داده‌ها را وارد کنید، و هر داده‌ای را در هسته‌های داده خود یا در هسته‌های داده عمومی تحلیل، ارجاع متقابل و استفاده کنید؛ همه با زبان انسانی.
- [JordiNei/mcp-databricks-server](https://github.com/JordiNeil/mcp-databricks-server) 🐍 ☁️ - به Databricks API متصل شوید، که به LLMها امکان اجرای کوئری‌های SQL، لیست کردن jobها و دریافت وضعیت job را می‌دهد.
- [jwaxman19/qlik-mcp](https://github.com/jwaxman19/qlik-mcp) 📇 ☁️ - سرور MCP برای Qlik Cloud API که کوئری برنامه‌ها، شیت‌ها و استخراج داده از تجسم‌ها را با پشتیبانی جامع از احراز هویت و محدودیت نرخ امکان‌پذیر می‌کند.
- [keboola/keboola-mcp-server](https://github.com/keboola/keboola-mcp-server) 🐍 - با پلتفرم داده Keboola Connection تعامل داشته باشید. این سرور ابزارهایی برای لیست کردن و دسترسی به داده‌ها از Keboola Storage API فراهم می‌کند.
- [mattijsdp/dbt-docs-mcp](https://github.com/mattijsdp/dbt-docs-mcp) 🐍 🏠 - سرور MCP برای کاربران dbt-core (OSS) زیرا MCP رسمی dbt فقط از dbt Cloud پشتیبانی می‌کند. از متادیتای پروژه، lineage سطح مدل و ستون و مستندات dbt پشتیبانی می‌کند.
- [yashshingvi/databricks-genie-MCP](https://github.com/yashshingvi/databricks-genie-MCP) 🐍 ☁️ - سروری که به Databricks Genie API متصل می‌شود و به LLMها اجازه می‌دهد سؤالات زبان طبیعی بپرسند، کوئری‌های SQL اجرا کنند و با عامل‌های مکالمه‌ای Databricks تعامل داشته باشند.
- [alkemiai/alkemi-mcp](https://github.com/alkemi-ai/alkemi-mcp) 📇 ☁️ - سرور MCP برای کوئری زبان طبیعی محصولات داده Snowflake، Google BigQuery و DataBricks از طریق Alkemi.ai.
- [avisangle/method-crm-mcp](https://github.com/avisangle/method-crm-mcp) 🐍 ☁️ 🏠 🍎 🪟 🐧 - سرور MCP آماده برای تولید برای یکپارچه‌سازی Method CRM API با ۲۰ ابزار جامع برای جداول، فایل‌ها، کاربران، رویدادها و مدیریت کلید API. دارای محدودیت نرخ، منطق تلاش مجدد و پشتیبانی از انتقال دوگانه (stdio/HTTP).
- [paracetamol951/caisse-enregistreuse-mcp-server](https://github.com/paracetamol951/caisse-enregistreuse-mcp-server) 🏠 🐧 🍎 ☁️ - به شما امکان می‌دهد عملیات تجاری، ثبت فروش، نرم‌افزار POS، CRM را خودکار یا نظارت کنید.


### 💻 <a name="developer-tools"></a>ابزارهای توسعه‌دهنده

ابزارها و یکپارچه‌سازی‌هایی که گردش کار توسعه و مدیریت محیط را بهبود می‌بخشند.

- [21st-dev/Magic-MCP](https://github.com/21st-dev/magic-mcp) - اجزای UI ساخته شده با الهام از بهترین مهندسان طراحی 21st.dev را ایجاد کنید.
- [aashari/mcp-server-atlassian-bitbucket](https://github.com/aashari/mcp-server-atlassian-bitbucket) 📇 ☁️ - یکپارچه‌سازی با Atlassian Bitbucket Cloud. به سیستم‌های هوش مصنوعی امکان تعامل با مخازن، pull requestها، فضاهای کاری و کد را در زمان واقعی می‌دهد.
- [aashari/mcp-server-atlassian-confluence](https://github.com/aashari/mcp-server-atlassian-confluence) 📇 ☁️ - یکپارچه‌سازی با Atlassian Confluence Cloud. به سیستم‌های هوش مصنوعی امکان تعامل با فضاها، صفحات و محتوای Confluence با تبدیل خودکار ADF به Markdown را می‌دهد.
- [aashari/mcp-server-atlassian-jira](https://github.com/aashari/mcp-server-atlassian-jira) 📇 ☁️ - یکپارچه‌سازی با Atlassian Jira Cloud. به سیستم‌های هوش مصنوعی امکان تعامل با پروژه‌ها، issueها، نظرات و اطلاعات توسعه مرتبط Jira را در زمان واقعی می‌دهد.
- [abrinsmead/mindpilot-mcp](https://github.com/abrinsmead/mindpilot-mcp) 📇 🏠 - کد، معماری و مفاهیم دیگر را به صورت نمودارهای mermaid در یک برنامه وب میزبانی شده محلی تجسم می‌کند. فقط از عامل خود بخواهید "این را در یک نمودار به من نشان بده".
- [admica/FileScopeMCP](https://github.com/admica/FileScopeMCP) 🐍 📇 🦀 - کدبیس شما را تحلیل می‌کند و فایل‌های مهم را بر اساس روابط وابستگی شناسایی می‌کند. نمودارها و امتیازات اهمیت را تولید می‌کند و به دستیاران هوش مصنوعی در درک کدبیس کمک می‌کند.
- [agent-hanju/char-index-mcp](https://github.com/agent-hanju/char-index-mcp) 🐍 🏠 ☁️ 🍎 🪟 🐧 - نمایه‌سازی دقیق رشته در سطح کاراکتر برای LLMها. ابزارهایی برای پیدا کردن، استخراج و دستکاری متن بر اساس موقعیت دقیق کاراکتر برای حل عملیات مبتنی بر موقعیت فراهم می‌کند.
- [akramIOT/MCP_AI_SOC_Sher](https://github.com/akramIOT/MCP_AI_SOC_Sher)  🐍 ☁️ 📇 - سرور MCP برای انجام تحلیل تهدید امنیتی دینامیک AI SOC برای یک عامل هوش مصنوعی Text2SQL.
- [alimo7amed93/webhook-tester-mcp](https://github.com/alimo7amed93/webhook-tester-mcp)  🐍 ☁️ – یک سرور مبتنی بر FastMCP برای تعامل با webhook-test.com. به کاربران امکان می‌دهد وب‌هوک‌ها را به صورت محلی با استفاده از Claude ایجاد، بازیابی و حذف کنند.
- [ambar/simctl-mcp](https://github.com/ambar/simctl-mcp) 📇 🏠 🍎 یک پیاده‌سازی سرور MCP برای کنترل شبیه‌ساز iOS.
- [api7/apisix-mcp](https://github.com/api7/apisix-mcp) 🎖️ 📇 🏠 سرور MCP که از کوئری و مدیریت تمام منابع در [Apache APISIX](https://github.com/apache/apisix) پشتیبانی می‌کند.
- [ArchAI-Labs/fastmcp-sonarqube-metrics](https://github.com/ArchAI-Labs/fastmcp-sonarqube-metrics) 🐍 🏠 🪟 🐧 🍎 - یک سرور Model Context Protocol (MCP) که مجموعه‌ای از ابزارها را برای بازیابی اطلاعات در مورد پروژه‌های SonarQube مانند معیارها (فعلی و تاریخی)، issueها، وضعیت سلامت فراهم می‌کند.
- [artmann/package-registry-mcp](https://github.com/artmann/package-registry-mcp) 🏠 📇 🍎 🪟 🐧 - سرور MCP برای جستجو و دریافت اطلاعات به‌روز در مورد بسته‌های NPM، Cargo، PyPi و NuGet.
- [wyattjoh/jsr-mcp](https://github.com/wyattjoh/jsr-mcp) 📇 ☁️ - سرور Model Context Protocol برای JSR (JavaScript Registry)
- [augmnt/augments-mcp-server](https://github.com/augmnt/augments-mcp-server) 📇 ☁️ 🏠 - کد Claude را با دسترسی هوشمند و بی‌درنگ به بیش از ۹۰ منبع مستندات چارچوب متحول کنید. تولید کد دقیق و به‌روز که از بهترین شیوه‌های فعلی برای React، Next.js، Laravel، FastAPI، Tailwind CSS و موارد دیگر پیروی می‌کند، دریافت کنید.
- [automation-ai-labs/mcp-link](https://github.com/automation-ai-labs/mcp-link) 🏎️ 🏠 - هر API را با عامل‌های هوش مصنوعی (با OpenAPI Schema) به طور یکپارچه یکپارچه کنید
- [avisangle/jenkins-mcp-server](https://github.com/avisangle/jenkins-mcp-server) 🐍 🏠 🍎 🪟 🐧 - یکپارچه‌سازی Jenkins CI/CD در سطح سازمانی با کشینگ چند لایه، نظارت بر pipeline، مدیریت artifact و عملیات دسته‌ای. دارای ۲۱ ابزار MCP برای مدیریت job، ردیابی وضعیت build و مدیریت صف با محافظت CSRF و پشتیبانی 2FA.
- [axliupore/mcp-code-runner](https://github.com/axliupore/mcp-code-runner) 📇 🏠 - یک سرور MCP برای اجرای کد به صورت محلی از طریق Docker و پشتیبانی از چندین زبان برنامه‌نویسی.
- [azer/react-analyzer-mcp](https://github.com/azer/react-analyzer-mcp) 📇 🏠 - تحلیل کد React به صورت محلی، تولید مستندات / llm.txt برای کل پروژه به یکباره
- [buildkite/buildkite-mcp-server](https://github.com/buildkite/buildkite-mcp-server) 🎖️ 🏎️ 🏠 ☁️ 🍎 🪟 🐧 - سرور MCP رسمی برای Buildkite. ایجاد pipelineهای جدید، تشخیص و رفع خرابی‌ها، راه‌اندازی buildها، نظارت بر صف‌های job و موارد دیگر. 
- [Chunkydotdev/bldbl-mcp](https://github.com/chunkydotdev/bldbl-mcp) 📇 ☁️ 🍎 🪟 🐧 - سرور MCP رسمی برای پلتفرم توسعه مبتنی بر هوش مصنوعی Buildable [bldbl.dev](https://bldbl.dev). به دستیاران هوش مصنوعی امکان مدیریت وظایف، ردیابی پیشرفت، دریافت زمینه پروژه و همکاری با انسان‌ها در پروژه‌های نرم‌افزاری را می‌دهد.
- [CircleCI/mcp-server-circleci](https://github.com/CircleCI-Public/mcp-server-circleci) 📇 ☁️ به عامل‌های هوش مصنوعی امکان رفع خرابی‌های build از CircleCI را می‌دهد.
- [cjo4m06/mcp-shrimp-task-manager](https://github.com/cjo4m06/mcp-shrimp-task-manager) 📇 ☁️ 🏠 – یک سیستم مدیریت وظایف متمرکز بر برنامه‌نویسی که عامل‌های کدنویسی مانند Cursor AI را با حافظه وظایف پیشرفته، خود-بازتابی و مدیریت وابستگی تقویت می‌کند. [ShrimpTaskManager](https://cjo4m06.github.io/mcp-shrimp-task-manager)
- [ckanthony/gin-mcp](https://github.com/ckanthony/gin-mcp) 🏎️ ☁️ 📟 🪟 🐧 🍎 - یک کتابخانه Go با پیکربندی صفر برای در معرض دید قرار دادن خودکار APIهای موجود چارچوب وب Gin به عنوان ابزارهای MCP.
- [ckreiling/mcp-server-docker](https://github.com/ckreiling/mcp-server-docker) 🐍 🏠 - یکپارچه‌سازی با Docker برای مدیریت کانتینرها، ایمیج‌ها، volumeها و شبکه‌ها.
- [CodeLogicIncEngineering/codelogic-mcp-server](https://github.com/CodeLogicIncEngineering/codelogic-mcp-server) 🎖️ 🐍 ☁️ 🍎 🪟 🐧 - سرور MCP رسمی برای CodeLogic، که دسترسی به تحلیل‌های وابستگی کد، تحلیل ریسک معماری و ابزارهای ارزیابی تأثیر را فراهم می‌کند.
- [Comet-ML/Opik-MCP](https://github.com/comet-ml/opik-mcp) 🎖️ 📇 ☁️ 🏠 - از زبان طبیعی برای کاوش در قابلیت مشاهده LLM، traceها و داده‌های نظارتی که توسط Opik ثبت شده‌اند، استفاده کنید.
- [ConfigCat/mcp-server](https://github.com/configcat/mcp-server) 🎖️ 📇 ☁️ - سرور MCP برای تعامل با پلتفرم feature flag ConfigCat. از مدیریت feature flagها، configها، محیط‌ها، محصولات و سازمان‌ها پشتیبانی می‌کند.
- [cqfn/aibolit-mcp-server](https://github.com/cqfn/aibolit-mcp-server) ☕ - کمک به عامل هوش مصنوعی شما در شناسایی نقاط داغ برای Refactoring؛ کمک به هوش مصنوعی برای درک چگونگی 'بهتر کردن کد'
- [currents-dev/currents-mcp](https://github.com/currents-dev/currents-mcp) 🎖️ 📇 ☁️ به عامل‌های هوش مصنوعی امکان رفع خرابی‌های تست Playwright گزارش شده به [Currents](https://currents.dev) را می‌دهد.
- [davidan90/time-node-mcp](https://github.com/davidan90/time-node-mcp) 📇 🏠 - عملیات تاریخ و زمان آگاه از منطقه زمانی با پشتیبانی از مناطق زمانی IANA، تبدیل منطقه زمانی و مدیریت زمان صرفه‌جویی در نور روز.
- [davidlin2k/pox-mcp-server](https://github.com/davidlin2k/pox-mcp-server) 🐍 🏠 - سرور MCP برای کنترلر POX SDN که قابلیت‌های کنترل و مدیریت شبکه را فراهم می‌کند.
- [delano/postman-mcp-server](https://github.com/delano/postman-mcp-server) 📇 ☁️ - تعامل با [Postman API](https://www.postman.com/postman/postman-public-workspace/)
- [deploy-mcp/deploy-mcp](https://github.com/alexpota/deploy-mcp) 📇 ☁️ 🏠 - ردیاب استقرار جهانی برای دستیاران هوش مصنوعی با نشان‌های وضعیت زنده و نظارت بر استقرار
- [docker/hub-mcp](https://github.com/docker/hub-mcp) 🎖️ 📇 ☁️ 🏠 - سرور MCP رسمی برای تعامل با Docker Hub، که دسترسی به مخازن، جستجوی hub و Docker Hardened Images را فراهم می‌کند
- [endorhq/cli](https://github.com/endorhq/cli) 📇 ☁️ 🏠 🪟 🐧 🍎 - Endor به عامل‌های هوش مصنوعی شما اجازه می‌دهد سرویس‌هایی مانند MariaDB، Postgres، Redis، Memcached، Alpine یا Valkey را در sandboxهای ایزوله اجرا کنند. برنامه‌های از پیش پیکربندی شده‌ای دریافت کنید که در کمتر از ۵ ثانیه بوت می‌شوند.
- [etsd-tech/mcp-pointer](https://github.com/etsd-tech/mcp-pointer) 📇 🏠 🍎 🪟 🐧 - انتخابگر بصری عناصر DOM برای ابزارهای کدنویسی عامل‌محور. افزونه Chrome + پل سرور MCP برای Claude Code، Cursor، Windsurf و غیره. Option+Click برای گرفتن عناصر.
- [flipt-io/mcp-server-flipt](https://github.com/flipt-io/mcp-server-flipt) 📇 🏠 - به دستیاران هوش مصنوعی امکان تعامل با feature flagهای شما در [Flipt](https://flipt.io) را می‌دهد.
- [freema/mcp-design-system-extractor](https://github.com/freema/mcp-design-system-extractor) 📇 🏠 - اطلاعات کامپوننت را از سیستم‌های طراحی Storybook استخراج می‌کند. HTML، استایل‌ها، propها، وابستگی‌ها، توکن‌های تم و متادیتای کامپوننت را برای تحلیل سیستم طراحی مبتنی بر هوش مصنوعی فراهم می‌کند.
- [gitkraken/gk-cli](https://github.com/gitkraken/gk-cli) 🎖️ 🏎️ 🏠 ☁️ 🍎 🪟 🐧 - یک CLI برای تعامل با APIهای GitKraken. شامل یک سرور MCP از طریق `gk mcp` است که نه تنها APIهای GitKraken را پوشش می‌دهد، بلکه Jira، GitHub، GitLab و موارد دیگر را نیز پوشش می‌دهد. با ابزارهای محلی و خدمات راه دور کار می‌کند.
- [GLips/Figma-Context-MCP](https://github.com/GLips/Figma-Context-MCP) 📇 🏠 - به عامل‌های کدنویسی دسترسی مستقیم به داده‌های Figma را می‌دهد تا به آنها در پیاده‌سازی طراحی یک-شات کمک کند.
- [gofireflyio/firefly-mcp](https://github.com/gofireflyio/firefly-mcp) 🎖️ 📇 ☁️ - منابع ابری را با [Firefly](https://firefly.ai) یکپارچه، کشف، مدیریت و کدگذاری می‌کند.
- [gorosun/unified-diff-mcp](https://github.com/gorosun/unified-diff-mcp) 📇 🏠 - تولید و تجسم مقایسه‌های unified diff با خروجی زیبای HTML/PNG، با پشتیبانی از نماهای side-by-side و line-by-line برای یکپارچه‌سازی dry-run سیستم فایل
- [Govcraft/rust-docs-mcp-server](https://github.com/Govcraft/rust-docs-mcp-server) 🦀 🏠 - زمینه مستندات به‌روز را برای یک crate خاص Rust به LLMها از طریق یک ابزار MCP، با استفاده از جستجوی معنایی (embeddings) و خلاصه‌سازی LLM فراهم می‌کند.
- [PromptExecution/cratedocs-mcp](https://github.com/promptexecution/cratedocs-mcp) 🦀 🏠 - خروجی traitهای مشتق شده، رابط‌ها و غیره یک crate Rust به فرم کوتاه از AST (از همان api rust-analyzer استفاده می‌کند)، محدودیت‌های خروجی (تخمین توکن) و مستندات crate با حذف regex.
- [HainanZhao/mcp-gitlab-jira](https://github.com/HainanZhao/mcp-gitlab-jira) 📇 ☁️ 🏠 - سرور MCP یکپارچه برای GitLab و Jira: مدیریت پروژه‌ها، merge requestها، فایل‌ها، releaseها و تیکت‌ها با عامل‌های هوش مصنوعی.
- [haris-musa/excel-mcp-server](https://github.com/haris-musa/excel-mcp-server) 🐍 🏠 - یک سرور دستکاری Excel که ایجاد workbook، عملیات داده، قالب‌بندی و ویژگی‌های پیشرفته (نمودارها، جداول محوری، فرمول‌ها) را فراهم می‌کند.
- [higress-group/higress-ops-mcp-server](https://github.com/higress-group/higress-ops-mcp-server) 🐍 🏠 - سرور MCP که ابزارهای جامعی برای مدیریت پیکربندی‌ها و عملیات دروازه [Higress](https://github.com/alibaba/higress) فراهم می‌کند.
- [hijaz/postmancer](https://github.com/hijaz/postmancer) 📇 🏠 - یک سرور MCP برای جایگزینی کلاینت‌های Rest مانند Postman/Insomnia، با اجازه دادن به LLM شما برای نگهداری و استفاده از مجموعه‌های api.
- [hloiseaufcms/mcp-gopls](https://github.com/hloiseaufcms/mcp-gopls) 🏎️ 🏠 - یک سرور MCP برای تعامل با [Go's Language Server Protocol (gopls)](https://github.com/golang/tools/tree/master/gopls) و بهره‌مندی از ویژگی‌های پیشرفته تحلیل کد Go.
- [hungthai1401/bruno-mcp](https://github.com/hungthai1401/bruno-mcp) 📇 🏠 - یک سرور MCP برای تعامل با [Bruno API Client](https://www.usebruno.com/).
- [hyperb1iss/droidmind](https://github.com/hyperb1iss/droidmind) 🐍 🏠 - کنترل دستگاه‌های Android با هوش مصنوعی از طریق MCP، که کنترل دستگاه، اشکال‌زدایی، تحلیل سیستم و اتوماسیون UI را با یک چارچوب امنیتی جامع امکان‌پذیر می‌کند.
- [Hypersequent/qasphere-mcp](https://github.com/Hypersequent/qasphere-mcp) 🎖️ 📇 ☁️ - یکپارچه‌سازی با سیستم مدیریت تست [QA Sphere](https://qasphere.com/)، که به LLMها امکان کشف، خلاصه‌سازی و تعامل با موارد تست را مستقیماً از IDEهای مبتنی بر هوش مصنوعی می‌دهد
- [idosal/git-mcp](https://github.com/idosal/git-mcp) 📇 ☁️ - [gitmcp.io](https://gitmcp.io/) یک سرور MCP راه دور عمومی برای اتصال به هر مخزن یا پروژه [GitHub](https://www.github.com) برای مستندات است
- [IlyaGulya/gradle-mcp-server](https://github.com/IlyaGulya/gradle-mcp-server) 🏠 - یکپارچه‌سازی با Gradle با استفاده از Gradle Tooling API برای بازرسی پروژه‌ها، اجرای وظایف و اجرای تست‌ها با گزارش نتیجه برای هر تست
- [promptexecution/just-mcp](https://github.com/promptexecution/just-mcp) 🦀 🏠 - یکپارچه‌سازی با Justfile که به LLMها امکان اجرای امن و آسان هر دستور CLI یا اسکریپت با پارامترها را می‌دهد، با پشتیبانی از متغیرهای محیطی و تست جامع.
- [InditexTech/mcp-server-simulator-ios-idb](https://github.com/InditexTech/mcp-server-simulator-ios-idb) 📇 🏠 🍎 - یک سرور Model Context Protocol (MCP) که به LLMها امکان تعامل با شبیه‌سازهای iOS (iPhone، iPad و غیره) را از طریق دستورات زبان طبیعی می‌دهد.
- [InhiblabCore/mcp-image-compression](https://github.com/InhiblabCore/mcp-image-compression) 🐍 🏠 - سرور MCP برای فشرده‌سازی محلی فرمت‌های مختلف تصویر.
- [InsForge/insforge-mcp](https://github.com/InsForge/insforge-mcp) 📇 ☁️ - پلتفرم backend-as-a-service بومی هوش مصنوعی که به عامل‌های هوش مصنوعی امکان ساخت و مدیریت برنامه‌های full-stack را می‌دهد. Auth، Database (PostgreSQL)، Storage و Functions را به عنوان زیرساخت آماده برای تولید فراهم می‌کند و زمان توسعه MVP را از هفته‌ها به ساعت‌ها کاهش می‌دهد.
- [Inspizzz/jetbrains-datalore-mcp](https://github.com/inspizzz/jetbrains-datalore-mcp) 🐍 ☁️ - سرور MCP برای تعامل با استقرارهای ابری پلتفرم Jetbrains Datalore. API کامل Datalore را در بر می‌گیرد (اجرا، اجرای تعاملی، دریافت داده‌های اجرا، دریافت فایل‌ها)
- [ios-simulator-mcp](https://github.com/joshuayoes/ios-simulator-mcp) 📇 🏠 🍎 - یک سرور Model Context Protocol (MCP) برای تعامل با شبیه‌سازهای iOS. این سرور به شما امکان می‌دهد با شبیه‌سازهای iOS از طریق دریافت اطلاعات در مورد آنها، کنترل تعاملات UI و بازرسی عناصر UI تعامل داشته باشید.
- [isaacphi/mcp-language-server](https://github.com/isaacphi/mcp-language-server) 🏎️ 🏠 - MCP Language Server به کلاینت‌های فعال MCP کمک می‌کند تا با دسترسی به ابزارهای معنایی مانند get definition، references، rename و diagnostics، کدبیس‌ها را راحت‌تر پیمایش کنند.
- [IvanAmador/vercel-ai-docs-mcp](https://github.com/IvanAmador/vercel-ai-docs-mcp) 📇 🏠 - یک سرور Model Context Protocol (MCP) که قابلیت‌های جستجو و کوئری مبتنی بر هوش مصنوعی را برای مستندات Vercel AI SDK فراهم می‌کند.
- [j4c0bs/mcp-server-sql-analyzer](https://github.com/j4c0bs/mcp-server-sql-analyzer) 🐍 - سرور MCP که تحلیل، linting و تبدیل گویش SQL را با استفاده از [SQLGlot](https://github.com/tobymao/sqlglot) فراهم می‌کند
- [janreges/ai-distiller-mcp](https://github.com/janreges/ai-distiller) 🏎️ 🏠 - ساختار کد ضروری را از کدبیس‌های بزرگ به فرمت قابل هضم برای هوش مصنوعی استخراج می‌کند و به عامل‌های هوش مصنوعی کمک می‌کند کدی بنویسند که به درستی از APIهای موجود در اولین تلاش استفاده کند.
- [jasonjmcghee/claude-debugs-for-you](https://github.com/jasonjmcghee/claude-debugs-for-you) 📇 🏠 - یک سرور MCP و افزونه VS Code که اشکال‌زدایی خودکار (مستقل از زبان) را از طریق breakpointها و ارزیابی عبارت امکان‌پذیر می‌کند.
- [jetbrains/mcpProxy](https://github.com/JetBrains/mcpProxy) 🎖️ 📇 🏠 - اتصال به JetBrains IDE
- [Jktfe/serveMyAPI](https://github.com/Jktfe/serveMyAPI) 📇 🏠 🍎 - یک سرور MCP (Model Context Protocol) شخصی برای ذخیره و دسترسی امن به کلیدهای API در پروژه‌ها با استفاده از macOS Keychain.
- [jordandalton/restcsv-mcp-server](https://github.com/JordanDalton/RestCsvMcpServer) 📇 ☁️ - یک سرور MCP برای فایل‌های CSV.
- [joshuarileydev/app-store-connect-mcp-server](https://github.com/JoshuaRileyDev/app-store-connect-mcp-server) 📇 🏠 - یک سرور MCP برای ارتباط با App Store Connect API برای توسعه‌دهندگان iOS
- [joshuarileydev/simulator-mcp-server](https://github.com/JoshuaRileyDev/simulator-mcp-server) 📇 🏠 - یک سرور MCP برای کنترل شبیه‌سازهای iOS
- [Jpisnice/shadcn-ui-mcp-server](https://github.com/Jpisnice/shadcn-ui-mcp-server) 📇 🏠 - سرور MCP که به دستیاران هوش مصنوعی دسترسی یکپارچه به کامپوننت‌ها، بلوک‌ها، دموها و متادیتای shadcn/ui v4 را می‌دهد.
- [jsdelivr/globalping-mcp-server](https://github.com/jsdelivr/globalping-mcp-server) 🎖️ 📇 ☁️ - سرور MCP Globalping به کاربران و LLMها دسترسی می‌دهد تا ابزارهای شبکه مانند ping، traceroute، mtr، HTTP و DNS resolve را از هزاران مکان در سراسر جهان اجرا کنند.
- [kadykov/mcp-openapi-schema-explorer](https://github.com/kadykov/mcp-openapi-schema-explorer) 📇 ☁️ 🏠 - دسترسی بهینه از نظر توکن به مشخصات OpenAPI/Swagger از طریق منابع MCP.
- [lamemind/mcp-server-multiverse](https://github.com/lamemind/mcp-server-multiverse) 📇 🏠 🛠️ - یک سرور میان‌افزار که به چندین نمونه ایزوله از یک سرور MCP اجازه می‌دهد تا به طور مستقل با فضاهای نام و پیکربندی‌های منحصر به فرد همزیستی کنند.
- [langfuse/mcp-server-langfuse](https://github.com/langfuse/mcp-server-langfuse) 🐍 🏠 - سرور MCP برای دسترسی و مدیریت پرامپت‌های برنامه LLM ایجاد شده با مدیریت پرامپت [Langfuse]([https://langfuse.com/](https://langfuse.com/docs/prompts/get-started)).
- [linw1995/nvim-mcp](https://github.com/linw1995/nvim-mcp) 🦀 🏠 🍎 🪟 🐧  - یک سرور MCP برای تعامل با Neovim
- [lpigeon/ros-mcp-server](https://github.com/lpigeon/ros-mcp-server) 🐍 🏠 🍎 🪟 🐧 - سرور ROS MCP از کنترل ربات با تبدیل دستورات زبان طبیعی صادر شده توسط کاربر به دستورات کنترل ROS یا ROS2 پشتیبانی می‌کند.
- [lpigeon/unitree-go2-mcp-server](https://github.com/lpigeon/unitree-go2-mcp-server) 🐍 🏠 🐧 - سرور Unitree Go2 MCP یک سرور ساخته شده بر روی MCP است که به کاربران امکان می‌دهد ربات Unitree Go2 را با استفاده از دستورات زبان طبیعی که توسط یک LLM تفسیر می‌شود، کنترل کنند.
- [ukkit/memcord](https://github.com/ukkit/memcord) 🐍 🏠 🐧 🍎 - یک سرور MCP که تاریخچه چت شما را سازماندهی و قابل جستجو نگه می‌دارد—با خلاصه‌های مبتنی بر هوش مصنوعی، حافظه امن و کنترل کامل.
- [mattjegan/swarmia-mcp](https://github.com/mattjegan/swarmia-mcp) 🐍 🏠 🍎 🐧 - سرور MCP فقط-خواندنی برای کمک به جمع‌آوری معیارها از [Swarmia](swarmia.com) برای گزارش‌دهی سریع.
- [mobile-next/mobile-mcp](https://github.com/mobile-next/mobile-mcp) 📇 🏠 🐧 🍎 - سرور MCP برای اتوماسیون، توسعه و استخراج داده از برنامه‌ها و دستگاه‌های Android/iOS. شبیه‌ساز/امولاتور/دستگاه‌های فیزیکی مانند iPhone، Google Pixel، Samsung پشتیبانی می‌شوند.
- [mrexodia/user-feedback-mcp](https://github.com/mrexodia/user-feedback-mcp) 🐍 🏠 - سرور MCP ساده برای فعال کردن یک گردش کار انسان-در-حلقه در ابزارهایی مانند Cline و Cursor.
- [mumez/pharo-smalltalk-interop-mcp-server](https://github.com/mumez/pharo-smalltalk-interop-mcp-server) 🐍 🏠 - یکپارچه‌سازی با Pharo Smalltalk که ارزیابی کد، بازرسی کلاس/متد، مدیریت بسته، اجرای تست و نصب پروژه را برای توسعه تعاملی با ایمیج‌های Pharo امکان‌پذیر می‌کند.
- [narumiruna/gitingest-mcp](https://github.com/narumiruna/gitingest-mcp) 🐍 🏠 - یک سرور MCP که از [gitingest](https://github.com/cyclotruc/gitingest) برای تبدیل هر مخزن Git به یک خلاصه متنی ساده از کدبیس آن استفاده می‌کند.
- [neilberkman/editorconfig_mcp](https://github.com/neilberkman/editorconfig_mcp) 📇 🏠 - فایل‌ها را با استفاده از قوانین `.editorconfig` قالب‌بندی می‌کند و به عنوان یک نگهبان قالب‌بندی فعال عمل می‌کند تا اطمینان حاصل شود که کد تولید شده توسط هوش مصنوعی از ابتدا به استانداردهای قالب‌بندی خاص پروژه پایبند است.
- [OctoMind-dev/octomind-mcp](https://github.com/OctoMind-dev/octomind-mcp) 📇 ☁️ - به عامل هوش مصنوعی مورد علاقه شما اجازه می‌دهد تست‌های end-to-end کاملاً مدیریت شده [Octomind](https://www.octomind.dev/) را از کدبیس شما یا سایر منابع داده مانند Jira، Slack یا TestRail ایجاد و اجرا کند.
- [OpenZeppelin/contracts-wizard](https://github.com/OpenZeppelin/contracts-wizard/tree/master/packages/mcp) - یک سرور Model Context Protocol (MCP) که به عامل‌های هوش مصنوعی اجازه می‌دهد قراردادهای هوشمند امن را در چندین زبان بر اساس [قالب‌های OpenZeppelin Wizard](https://wizard.openzeppelin.com/) تولید کنند.
- [bgauryy/octocode-mcp](https://github.com/bgauryy/octocode-mcp) ☁️ 📇 🍎 🪟 🐧 - دستیار توسعه‌دهنده مبتنی بر هوش مصنوعی که تحقیق، تحلیل و کشف پیشرفته را در قلمروهای GitHub و NPM به صورت بی‌درنگ امکان‌پذیر می‌کند.
- [opslevel/opslevel-mcp](https://github.com/opslevel/opslevel-mcp) 🎖️ 🏎️ ☁️ 🪟 🍎 🐧 - سرور MCP رسمی برای [OpsLevel](https://www.opslevel.com)
- [ooples/token-optimizer-mcp](https://github.com/ooples/token-optimizer-mcp) 📇 🏠 ☁️ 🍎 🪟 🐧 - بهینه‌سازی هوشمند توکن با کاهش بیش از ۹۵٪ از طریق کشینگ، فشرده‌سازی و بیش از ۸۰ ابزار هوشمند برای بهینه‌سازی API، تحلیل کد و نظارت بی‌درنگ.
- [picahq/mcp](https://github.com/picahq/mcp) 🎖️ 🦀 📇 ☁️ - یک MCP برای تمام یکپارچه‌سازی‌های شما — با قدرت [Pica](https://www.picaos.com)، زیرساخت برای عامل‌های هوشمند و همکار.
- [posthog/mcp](https://github.com/posthog/mcp) 🎖️ 📇 ☁️ - یک سرور MCP برای تعامل با تحلیل‌های PostHog، feature flagها، ردیابی خطا و موارد دیگر.
- [Pratyay/mac-monitor-mcp](https://github.com/Pratyay/mac-monitor-mcp) 🐍 🏠 🍎 - فرآیندهای پرمصرف منابع را در macOS شناسایی می‌کند و پیشنهاداتی برای بهبود عملکرد ارائه می‌دهد.
- [pskill9/website-downloader](https://github.com/pskill9/website-downloader) 🗄️ 🚀 - این سرور MCP ابزاری برای دانلود کل وب‌سایت‌ها با استفاده از wget فراهم می‌کند. ساختار وب‌سایت را حفظ کرده و لینک‌ها را برای کار به صورت محلی تبدیل می‌کند.
- [qainsights/jmeter-mcp-server](https://github.com/QAInsights/jmeter-mcp-server) 🐍 🏠 - سرور MCP JMeter برای تست عملکرد
- [qainsights/k6-mcp-server](https://github.com/QAInsights/k6-mcp-server) 🐍 🏠 - سرور MCP Grafana k6 برای تست عملکرد
- [qainsights/locust-mcp-server](https://github.com/QAInsights/locust-mcp-server) 🐍 🏠 - سرور MCP Locust برای تست عملکرد
- [QuantGeekDev/docker-mcp](https://github.com/QuantGeekDev/docker-mcp) 🏎️ 🏠 - مدیریت و عملیات کانتینر Docker از طریق MCP
- [r-huijts/xcode-mcp-server](https://github.com/r-huijts/xcode-mcp-server) 📇 🏠 🍎 - یکپارچه‌سازی با Xcode برای مدیریت پروژه، عملیات فایل و اتوماسیون build
- [ReAPI-com/mcp-openapi](https://github.com/ReAPI-com/mcp-openapi) 📇 🏠 - سرور MCP که به LLMها اجازه می‌دهد همه چیز را در مورد مشخصات OpenAPI شما بدانند تا کد/داده‌های mock را کشف، توضیح و تولید کنند
- [reflagcom/mcp](https://github.com/reflagcom/javascript/tree/main/packages/cli#model-context-protocol) 🎖️ 📇 ☁️ - ویژگی‌ها را مستقیماً از چت در IDE خود با [Reflag](https://reflag.com) پرچم‌گذاری کنید.
- [Rootly-AI-Labs/Rootly-MCP-server](https://github.com/Rootly-AI-Labs/Rootly-MCP-server) 🎖️ 🐍 ☁️ 🍎 - سرور MCP برای پلتفرم مدیریت حوادث [Rootly](https://rootly.com/).
- [ryan0204/github-repo-mcp](https://github.com/Ryan0204/github-repo-mcp) 📇 ☁️ 🪟 🐧 🍎 - GitHub Repo MCP به دستیاران هوش مصنوعی شما اجازه می‌دهد مخازن GitHub را مرور کنند، دایرکتوری‌ها را کاوش کنند و محتویات فایل را مشاهده کنند.
- [sammcj/mcp-package-version](https://github.com/sammcj/mcp-package-version) 📇 🏠 - یک سرور MCP برای کمک به LLMها در پیشنهاد آخرین نسخه‌های پایدار بسته هنگام نوشتن کد.
- [sapientpants/sonarqube-mcp-server](https://github.com/sapientpants/sonarqube-mcp-server) 🦀 ☁️ 🏠 - یک سرور Model Context Protocol (MCP) که با SonarQube یکپارچه می‌شود تا به دستیاران هوش مصنوعی دسترسی به معیارهای کیفیت کد، issueها و وضعیت‌های quality gate را بدهد
- [SDGLBL/mcp-claude-code](https://github.com/SDGLBL/mcp-claude-code) 🐍 🏠 - پیاده‌سازی قابلیت‌های Claude Code با استفاده از MCP، که درک، تغییر و تحلیل پروژه کد هوش مصنوعی را با پشتیبانی جامع ابزار امکان‌پذیر می‌کند.
- [sequa-ai/sequa-mcp](https://github.com/sequa-ai/sequa-mcp) 📇 ☁️ 🐧 🍎 🪟 - از چسباندن زمینه برای Copilot و Cursor دست بردارید. با Sequa MCP، ابزارهای هوش مصنوعی شما کل کدبیس و مستندات شما را از ابتدا می‌شناسند.
- [snaggle-ai/openapi-mcp-server](https://github.com/snaggle-ai/openapi-mcp-server) 🏎️ 🏠 - اتصال هر سرور API HTTP/REST با استفاده از مشخصات Open API (v3)
- [spacecode-ai/SpaceBridge-MCP](https://github.com/spacecode-ai/SpaceBridge-MCP) 🐍 🏠 🍎 🐧 - با ردیابی خودکار issueها، ساختار را به کدنویسی vibe بیاورید و زمینه را حفظ کنید.
- [st3v3nmw/sourcerer-mcp](https://github.com/st3v3nmw/sourcerer-mcp) 🏎️ ☁️ - MCP برای جستجو و پیمایش کد معنایی که ضایعات توکن را کاهش می‌دهد
- [stass/lldb-mcp](https://github.com/stass/lldb-mcp) 🐍 🏠 🐧 🍎 - یک سرور MCP برای LLDB که تحلیل باینری و فایل core هوش مصنوعی، اشکال‌زدایی و دیس‌اسمبلی را امکان‌پذیر می‌کند.
- [storybookjs/addon-mcp](https://github.com/storybookjs/addon-mcp) 📇 🏠 - به عامل‌ها کمک کنید تا به طور خودکار storyهایی را برای کامپوننت‌های UI شما بنویسند و تست کنند.
- [TencentEdgeOne/edgeone-pages-mcp](https://github.com/TencentEdgeOne/edgeone-pages-mcp) 📇 ☁️ - یک سرویس MCP برای استقرار محتوای HTML در EdgeOne Pages و به دست آوردن یک URL قابل دسترسی عمومی.
- [tgeselle/bugsnag-mcp](https://github.com/tgeselle/bugsnag-mcp) 📇 ☁️ - یک سرور MCP برای تعامل با [Bugsnag](https://www.bugsnag.com/)
- [Tommertom/awesome-ionic-mcp](https://github.com/Tommertom/awesome-ionic-mcp) 📇 🏠 - رفیق کدنویسی Ionic شما که از طریق MCP فعال شده است – برنامه‌های موبایل عالی با استفاده از React/Angular/Vue یا حتی Vanilla JS بسازید!
- [tipdotmd/tip-md-x402-mcp-server](https://github.com/tipdotmd/tip-md-x402-mcp-server) 📇 ☁️ - سرور MCP برای انعام دادن ارز دیجیتال از طریق رابط‌های هوش مصنوعی با استفاده از پروتکل پرداخت x402 و CDP Wallet.
- [tumf/mcp-text-editor](https://github.com/tumf/mcp-text-editor) 🐍 🏠 - یک ویرایشگر فایل متنی خط-گرا. برای ابزارهای LLM با دسترسی بهینه به بخش‌هایی از فایل برای به حداقل رساندن استفاده از توکن، بهینه‌سازی شده است.
- [utensils/mcp-nixos](https://github.com/utensils/mcp-nixos) 🐍 🏠 - سرور MCP که اطلاعات دقیقی در مورد بسته‌های NixOS، گزینه‌های سیستم، پیکربندی‌های Home Manager و تنظیمات nix-darwin macOS برای جلوگیری از توهمات هوش مصنوعی فراهم می‌کند.
- [vasayxtx/mcp-prompt-engine](https://github.com/vasayxtx/mcp-prompt-engine) 🏎️ 🏠 🪟️ 🐧 🍎 - سرور MCP برای مدیریت و ارائه قالب‌های پرامپت پویا با استفاده از موتور قالب متن زیبا و قدرتمند.
- [vivekvells/mcp-pandoc](https://github.com/vivekVells/mcp-pandoc) 🗄️ 🚀 - سرور MCP برای تبدیل یکپارچه فرمت اسناد با استفاده از Pandoc، که از Markdown، HTML، PDF، DOCX (.docx)، csv و موارد دیگر پشتیبانی می‌کند.
- [VSCode Devtools](https://github.com/biegehydra/BifrostMCP) 📇 - به VSCode ide متصل شوید و از ابزارهای معنایی مانند `find_usages` استفاده کنید
- [Webvizio/mcp](https://github.com/Webvizio/mcp) 🎖️ 📇 - به طور خودکار بازخوردها و گزارش‌های باگ از وب‌سایت‌ها و برنامه‌های وب را به وظایف توسعه‌دهنده قابل اجرا و غنی از زمینه تبدیل می‌کند. سرور Webvizio MCP که مستقیماً به ابزارهای کدنویسی هوش مصنوعی شما تحویل داده می‌شود، اطمینان می‌دهد که عامل هوش مصنوعی شما تمام داده‌های مورد نیاز برای حل وظایف با سرعت و دقت را دارد.
- [WiseVision/mcp_server_ros_2](https://github.com/wise-vision/mcp_server_ros_2) 🐍 🤖 - سرور MCP برای ROS2 که برنامه‌ها و خدمات رباتیک مبتنی بر هوش مصنوعی را امکان‌پذیر می‌کند.
- [Wooonster/hocr_mcp_server](https://github.com/Wooonster/hocr_mcp_server) 🐍 🏠 – یک سرور FastMCP مبتنی بر fastAPI با یک frontend Vue که تصاویر آپلود شده را از طریق MCP به VLM ارسال می‌کند تا به سرعت فرمول‌های ریاضی دست‌نویس را به عنوان کد LaTeX تمیز استخراج کند.
- [xcodebuild](https://github.com/ShenghaiWang/xcodebuild) 🍎 ساخت فضای کاری/پروژه iOS Xcode و بازخورد خطاها به llm.
- [XixianLiang/HarmonyOS-mcp-server](https://github.com/XixianLiang/HarmonyOS-mcp-server) 🐍 🏠 - کنترل دستگاه‌های HarmonyOS-next با هوش مصنوعی از طریق MCP. پشتیبانی از کنترل دستگاه و اتوماسیون UI.
- [xzq.xu/jvm-mcp-server](https://github.com/xzq-xu/jvm-mcp-server) 📇 🏠  - یک پروژه پیاده‌سازی از یک سرور MCP (Model Context Protocol) مبتنی بر JVM.
- [yangkyeongmo@/mcp-server-apache-airflow](https://github.com/yangkyeongmo/mcp-server-apache-airflow) 🐍 🏠 - سرور MCP که با استفاده از کلاینت رسمی به [Apache Airflow](https://airflow.apache.org/) متصل می‌شود.
- [yikakia/godoc-mcp-server](https://github.com/yikakia/godoc-mcp-server) 🏎️ ☁️ 🪟 🐧 🍎 - کوئری اطلاعات بسته Go در pkg.go.dev
- [yiwenlu66/PiloTY](https://github.com/yiwenlu66/PiloTY) 🐍 🏠 - پایلوت هوش مصنوعی برای عملیات PTY که به عامل‌ها امکان کنترل ترمینال‌های تعاملی با جلسات stateful، اتصالات SSH و مدیریت فرآیندهای پس‌زمینه را می‌دهد
- [YuChenSSR/mindmap-mcp-server](https://github.com/YuChenSSR/mindmap-mcp-server) 🐍 🏠 - یک سرور Model Context Protocol (MCP) برای تولید یک نقشه ذهنی تعاملی زیبا.
- [YuChenSSR/multi-ai-advisor](https://github.com/YuChenSSR/multi-ai-advisor-mcp) 📇 🏠 - یک سرور Model Context Protocol (MCP) که از چندین مدل Ollama کوئری می‌کند و پاسخ‌های آنها را ترکیب می‌کند و دیدگاه‌های متنوع هوش مصنوعی را در مورد یک سؤال واحد ارائه می‌دهد.
- [Yutarop/ros-mcp](https://github.com/Yutarop/ros-mcp) 🐍 🏠 🐧 - سرور MCP که از ارتباطات تاپیک‌ها، سرویس‌ها و اکشن‌های ROS2 پشتیبانی می‌کند و ربات‌ها را با استفاده از زبان طبیعی کنترل می‌کند.
- [yWorks/mcp-typescribe](https://github.com/yWorks/mcp-typescribe) 📇 🏠 - سرور MCP که اطلاعات Typescript API را به طور موثر به عامل ارائه می‌دهد تا به آن امکان کار با APIهای آموزش ندیده را بدهد
- [zaizaizhao/mcp-swagger-server](https://github.com/zaizaizhao/mcp-swagger-server) 📇 ☁️ 🏠 - یک سرور Model Context Protocol (MCP) که مشخصات OpenAPI/Swagger را به فرمت MCP تبدیل می‌کند و به دستیاران هوش مصنوعی امکان تعامل با APIهای REST از طریق پروتکل استاندارد را می‌دهد.
- [zcaceres/fetch-mcp](https://github.com/zcaceres/fetch-mcp) 📇 🏠 - یک سرور MCP برای دریافت انعطاف‌پذیر داده‌های JSON، متن و HTML
- [zenml-io/mcp-zenml](https://github.com/zenml-io/mcp-zenml) 🐍 🏠 ☁️ - یک سرور MCP برای اتصال با pipelineهای MLOps و LLMOps [ZenML](https://www.zenml.io) شما
- [zillow/auto-mobile](https://github.com/zillow/auto-mobile) 📇 🏠 🐧  - مجموعه ابزاری که حول یک سرور MCP برای اتوماسیون Android برای گردش کار توسعه‌دهنده و تست ساخته شده است
- [paracetamol951/P-Link-MCP](https://github.com/paracetamol951/P-Link-MCP) 🏠 🐧 🍎 ☁️ - پیاده‌سازی HTTP 402 (کد http نیاز به پرداخت) با تکیه بر Solana

### 🔒 <a name="delivery"></a>تحویل

- [https://github.com/jordandalton/doordash-mcp-server](https://github.com/JordanDalton/DoorDash-MCP-Server) 🐍 – تحویل DoorDash (غیر رسمی)

### 🧮 <a name="data-science-tools"></a>ابزارهای علم داده

یکپارچه‌سازی‌ها و ابزارهایی که برای ساده‌سازی کاوش داده، تحلیل و بهبود گردش کار علم داده طراحی شده‌اند.

- [arrismo/kaggle-mcp](https://github.com/arrismo/kaggle-mcp) 🐍 ☁️ - به Kaggle متصل می‌شود، قابلیت دانلود و تحلیل مجموعه داده‌ها را دارد.
- [avisangle/calculator-server](https://github.com/avisangle/calculator-server) 🏎️ 🏠 - یک سرور MCP جامع مبتنی بر Go برای محاسبات ریاضی، که ۱۳ ابزار ریاضی را در محاسبات پایه، توابع پیشرفته، تحلیل آماری، تبدیل واحدها و محاسبات مالی پیاده‌سازی می‌کند.
- [ChronulusAI/chronulus-mcp](https://github.com/ChronulusAI/chronulus-mcp) 🐍 ☁️ - هر چیزی را با عامل‌های پیش‌بینی و پیش‌بینی Chronulus AI پیش‌بینی کنید.
- [DataEval/dingo](https://github.com/DataEval/dingo) 🎖️ 🐍 🏠 🍎 🪟 🐧 - سرور MCP برای Dingo: یک ابزار جامع ارزیابی کیفیت داده. سرور امکان تعامل با قابلیت‌های ارزیابی مبتنی بر قانون و LLM Dingo و لیست کردن قوانین و پرامپت‌ها را فراهم می‌کند.
- [datalayer/jupyter-mcp-server](https://github.com/datalayer/jupyter-mcp-server) 🐍 🏠 - سرور Model Context Protocol (MCP) برای Jupyter.
- [growthbook/growthbook-mcp](https://github.com/growthbook/growthbook-mcp) 🎖️ 📇 🏠 🪟 🐧 🍎 — ابزارهایی برای ایجاد و تعامل با feature flagها و آزمایش‌های GrowthBook.
- [HumanSignal/label-studio-mcp-server](https://github.com/HumanSignal/label-studio-mcp-server) 🎖️ 🐍 ☁️ 🪟 🐧 🍎 - ایجاد، مدیریت و اتوماسیون پروژه‌ها، وظایف و پیش‌بینی‌های Label Studio برای گردش‌های کاری برچسب‌گذاری داده.
- [jjsantos01/jupyter-notebook-mcp](https://github.com/jjsantos01/jupyter-notebook-mcp) 🐍 🏠 - Jupyter Notebook را به Claude AI متصل می‌کند و به Claude اجازه می‌دهد مستقیماً با Jupyter Notebookها تعامل و کنترل داشته باشد.
- [kdqed/zaturn](https://github.com/kdqed/zaturn) 🐍 🏠 🪟 🐧 🍎 - چندین منبع داده (SQL، CSV، Parquet و غیره) را پیوند دهید و از هوش مصنوعی بخواهید داده‌ها را برای بینش و تجسم تحلیل کند.
- [mckinsey/vizro-mcp](https://github.com/mckinsey/vizro/tree/main/vizro-mcp) 🎖️ 🐍 🏠 - ابزارها و قالب‌هایی برای ایجاد نمودارها و داشبوردهای داده معتبر و قابل نگهداری.
- [optuna/optuna-mcp](https://github.com/optuna/optuna-mcp) 🎖️ 🐍 🏠 🐧 🍎 - سرور MCP رسمی که هماهنگ‌سازی یکپارچه جستجوی هایپرپارامتر و سایر وظایف بهینه‌سازی را با [Optuna](https://optuna.org/) امکان‌پذیر می‌کند.
- [phisanti/MCPR](https://github.com/phisanti/MCPR) 🏠 🍎 🪟 🐧 - Model Context Protocol برای R: به عامل‌های هوش مصنوعی امکان مشارکت در جلسات زنده تعاملی R را می‌دهد.
- [reading-plus-ai/mcp-server-data-exploration](https://github.com/reading-plus-ai/mcp-server-data-exploration) 🐍 ☁️ - کاوش داده خودکار را بر روی مجموعه داده‌های مبتنی بر csv. امکان‌پذیر می‌کند و بینش‌های هوشمند را با حداقل تلاش فراهم می‌کند.
- [subelsky/bundler_mcp](https://github.com/subelsky/bundler_mcp) 💎 🏠 - به عامل‌ها امکان می‌دهد اطلاعات محلی در مورد وابستگی‌ها را در `Gemfile` یک پروژه Ruby کوئری کنند.
- [Bright-L01/networkx-mcp-server](https://github.com/Bright-L01/networkx-mcp-server) 🐍 🏠 - اولین یکپارچه‌سازی NetworkX برای Model Context Protocol، که تحلیل و تجسم گراف را مستقیماً در مکالمات هوش مصنوعی امکان‌پذیر می‌کند. از ۱۳ عملیات شامل الگوریتم‌های مرکزیت، تشخیص جامعه، PageRank و تجسم گراف پشتیبانی می‌کند.
- [zcaceres/markdownify-mcp](https://github.com/zcaceres/markdownify-mcp) 📇 🏠 - یک سرور MCP برای تبدیل تقریباً هر فایل یا محتوای وب به Markdown

### 📟 <a name="embedded-system"></a>سیستم تعبیه‌شده

دسترسی به مستندات و میانبرها را برای کار بر روی دستگاه‌های تعبیه‌شده فراهم می‌کند.

- [horw/esp-mcp](https://github.com/horw/esp-mcp) 📟 - گردش کار برای رفع مشکلات build در تراشه‌های سری ESP32 با استفاده از ESP-IDF.
- [kukapay/modbus-mcp](https://github.com/kukapay/modbus-mcp) 🐍 📟 - یک سرور MCP که داده‌های صنعتی Modbus را استانداردسازی و متنی می‌کند.
- [kukapay/opcua-mcp](https://github.com/kukapay/opcua-mcp) 🐍 📟 - یک سرور MCP که به سیستم‌های صنعتی فعال OPC UA متصل می‌شود.
- [stack-chan/stack-chan](https://github.com/stack-chan/stack-chan) 📇 📟 - یک ربات فوق‌العاده-کاوایی تعبیه‌شده M5Stack مبتنی بر JavaScript با عملکرد سرور MCP برای تعاملات و احساسات کنترل شده توسط هوش مصنوعی.
- [yoelbassin/gnuradioMCP](https://github.com/yoelbassin/gnuradioMCP) 🐍 📟 🏠 - یک سرور MCP برای GNU Radio که به LLMها امکان ایجاد و تغییر خودکار فلوچارت‌های RF `.grc` را می‌دهد.

### 🌳 <a name="environment-and-nature"></a>زیست بوم و طبیعت

دسترسی به داده‌های محیطی و ابزارها، خدمات و اطلاعات مرتبط با طبیعت را فراهم می‌کند.

- [aliafsahnoudeh/wildfire-mcp-server](https://github.com/aliafsahnoudeh/wildfire-mcp-server) 🐍 ☁️ 🍎 🪟 🐧 - ،یک ام سی پی سرور برای شناسایی، نظارت و تحلیل آتش‌سوزی‌های احتمالی در سراسر جهان با استفاده از منابع داده متعدد از جمله NASA FIRMS، OpenWeatherMap و Google Earth Engine.

### 📂 <a name="file-systems"></a>سیستم‌های فایل

دسترسی مستقیم به سیستم‌های فایل محلی با مجوزهای قابل تنظیم را فراهم می‌کند. به مدل‌های هوش مصنوعی امکان خواندن، نوشتن و مدیریت فایل‌ها در دایرکتوری‌های مشخص شده را می‌دهد.

- [8b-is/smart-tree](https://github.com/8b-is/smart-tree) 🦀 🏠 🍎 🪟 🐧 - تجسم دایرکتوری بومی هوش مصنوعی با تحلیل معنایی، فرمت‌های فوق فشرده برای مصرف هوش مصنوعی و کاهش ۱۰ برابری توکن. از حالت کوانتومی-معنایی با دسته‌بندی هوشمند فایل پشتیبانی می‌کند.
- [box/mcp-server-box-remote](https://github.com/box/mcp-server-box-remote/) 🎖️ ☁️ - سرور Box MCP به عامل‌های هوش مصنوعی شخص ثالث اجازه می‌دهد به طور امن و یکپارچه به محتوای Box دسترسی داشته باشند و از ابزارهایی مانند جستجو، پرسیدن سؤال از فایل‌ها و پوشه‌ها و استخراج داده استفاده کنند.
- [cyberchitta/llm-context.py](https://github.com/cyberchitta/llm-context.py) 🐍 🏠 - به اشتراک گذاشتن زمینه کد با LLMها از طریق MCP یا کلیپ‌بورد
- [exoticknight/mcp-file-merger](https://github.com/exoticknight/mcp-file-merger) 🏎️ 🏠 - ابزار ادغام فایل، مناسب برای محدودیت‌های طول چت هوش مصنوعی.
- [filesystem@quarkiverse/quarkus-mcp-servers](https://github.com/quarkiverse/quarkus-mcp-servers/tree/main/filesystem) ☕ 🏠 - یک سیستم فایل که امکان مرور و ویرایش فایل‌ها را دارد که در Java با استفاده از Quarkus پیاده‌سازی شده است. به صورت jar یا ایمیج بومی در دسترس است.
- [hmk/box-mcp-server](https://github.com/hmk/box-mcp-server) 📇 ☁️ - یکپارچه‌سازی با Box برای لیست کردن، خواندن و جستجوی فایل‌ها
- [isaacphi/mcp-gdrive](https://github.com/isaacphi/mcp-gdrive) 📇 ☁️ - سرور Model Context Protocol (MCP) برای خواندن از Google Drive و ویرایش Google Sheets.
- [jeannier/homebrew-mcp](https://github.com/jeannier/homebrew-mcp) 🐍 🏠 🍎 - راه‌اندازی Homebrew macOS خود را با استفاده از زبان طبیعی از طریق این سرور MCP کنترل کنید. به سادگی بسته‌های خود را مدیریت کنید، یا پیشنهاد بخواهید، مشکلات brew را عیب‌یابی کنید و غیره.
- [mamertofabian/mcp-everything-search](https://github.com/mamertofabian/mcp-everything-search) 🐍 🏠 🪟 - جستجوی سریع فایل در Windows با استفاده از Everything SDK
- [mark3labs/mcp-filesystem-server](https://github.com/mark3labs/mcp-filesystem-server) 🏎️ 🏠 - پیاده‌سازی Golang برای دسترسی به سیستم فایل محلی.
- [mickaelkerjean/filestash](https://github.com/mickael-kerjean/filestash/tree/master/server/plugin/plg_handler_mcp) 🏎️ ☁️ - دسترسی به ذخیره‌سازی راه دور: SFTP، S3، FTP، SMB، NFS، WebDAV، GIT، FTPS، gcloud، azure blob، sharepoint و غیره.
- [microsoft/markitdown](https://github.com/microsoft/markitdown/tree/main/packages/markitdown-mcp) 🎖️ 🐍 🏠 - دسترسی ابزار MCP به MarkItDown -- کتابخانه‌ای که بسیاری از فرمت‌های فایل (محلی یا راه دور) را برای مصرف LLM به Markdown تبدیل می‌کند.
- [modelcontextprotocol/server-filesystem](https://github.com/modelcontextprotocol/servers/tree/main/src/filesystem) 📇 🏠 - دسترسی مستقیم به سیستم فایل محلی.
- [Xuanwo/mcp-server-opendal](https://github.com/Xuanwo/mcp-server-opendal) 🐍 🏠 ☁️ - دسترسی به هر ذخیره‌سازی با Apache OpenDAL™

### 💰 <a name="finance--fintech"></a>مالی و فین‌تک

- [Regenerating-World/pix-mcp](https://github.com/Regenerating-World/pix-mcp) 📇 ☁️ - تولید کدهای QR Pix و رشته‌های copy-paste با بازگشت به عقب در چندین ارائه‌دهنده (Efí، Cielo، و غیره) برای پرداخت‌های فوری برزیل.
- [aaronjmars/web3-research-mcp](https://github.com/aaronjmars/web3-research-mcp) 📇 ☁️ - تحقیق عمیق برای کریپتو - رایگان و کاملاً محلی
- [ahnlabio/bicscan-mcp](https://github.com/ahnlabio/bicscan-mcp) 🎖️ 🐍 ☁️ - امتیاز ریسک / دارایی‌های آدرس بلاکچین EVM (EOA، CA، ENS) و حتی نام‌های دامنه.
- [getAlby/mcp](https://github.com/getAlby/mcp) 🎖️ 📇 ☁️ 🏠 - هر کیف پول bitcoin lightning را به عامل خود متصل کنید تا پرداخت‌های فوری را به صورت جهانی ارسال و دریافت کنید.
- [alchemy/alchemy-mcp-server](https://github.com/alchemyplatform/alchemy-mcp-server) 🎖️ 📇 ☁️ - به عامل‌های هوش مصنوعی اجازه دهید با APIهای بلاکچین Alchemy تعامل داشته باشند.
- [anjor/coinmarket-mcp-server](https://github.com/anjor/coinmarket-mcp-server) 🐍 ☁️ - یکپارچه‌سازی با Coinmarket API برای دریافت لیست‌ها و قیمت‌های ارزهای دیجیتال
- [araa47/jupiter-mcp](https://github.com/araa47/jupiter-mcp) 🐍 ☁️ - دسترسی به Jupiter API (به هوش مصنوعی اجازه می‌دهد توکن‌ها را در Solana معامله کند + به موجودی‌ها دسترسی پیدا کند + توکن‌ها را جستجو کند + سفارشات محدود ایجاد کند)
- [ariadng/metatrader-mcp-server](https://github.com/ariadng/metatrader-mcp-server) 🐍 🏠 🪟 - به LLMهای هوش مصنوعی امکان اجرای معاملات را با استفاده از پلتفرم MetaTrader 5 می‌دهد
- [armorwallet/armor-crypto-mcp](https://github.com/armorwallet/armor-crypto-mcp) 🐍 ☁️ - MCP برای ارتباط با چندین بلاکچین، استیکینگ، DeFi، سواپ، بریجینگ، مدیریت کیف پول، DCA، سفارشات محدود، جستجوی کوین، ردیابی و موارد دیگر.
- [bankless/onchain-mcp](https://github.com/Bankless/onchain-mcp/) 📇 ☁️ - Bankless Onchain API برای تعامل با قراردادهای هوشمند، کوئری اطلاعات تراکنش و توکن
- [base/base-mcp](https://github.com/base/base-mcp) 🎖️ 📇 ☁️ - یکپارچه‌سازی با Base Network برای ابزارهای onchain، که امکان تعامل با Base Network و Coinbase API را برای مدیریت کیف پول، انتقال وجه، قراردادهای هوشمند و عملیات DeFi می‌دهد
- [berlinbra/alpha-vantage-mcp](https://github.com/berlinbra/alpha-vantage-mcp) 🐍 ☁️ - یکپارچه‌سازی با Alpha Vantage API برای دریافت اطلاعات سهام و ارزهای دیجیتال
- [bitteprotocol/mcp](https://github.com/BitteProtocol/mcp) 📇 - یکپارچه‌سازی با Bitte Protocol برای اجرای عامل‌های هوش مصنوعی بر روی چندین بلاکچین.
- [carsol/monarch-mcp-server](https://github.com/carsol/monarch-mcp-server) 🐍 ☁️ - سرور MCP که دسترسی فقط-خواندنی به داده‌های مالی Monarch Money را فراهم می‌کند و به دستیاران هوش مصنوعی امکان تحلیل تراکنش‌ها، بودجه‌ها، حساب‌ها و داده‌های جریان نقدی را با پشتیبانی از MFA می‌دهد.
- [chargebee/mcp](https://github.com/chargebee/agentkit/tree/main/modelcontextprotocol) 🎖️ 📇 ☁️ - سرور MCP که عامل‌های هوش مصنوعی را به [پلتفرم Chargebee](https://www.chargebee.com/) متصل می‌کند.
- [codex-data/codex-mcp](https://github.com/Codex-Data/codex-mcp) 🎖️ 📇 ☁️ - یکپارچه‌سازی با [Codex API](https://www.codex.io) برای داده‌های بلاکچین و بازار غنی‌شده بی‌درنگ در بیش از ۶۰ شبکه
- [coinpaprika/dexpaprika-mcp](https://github.com/coinpaprika/dexpaprika-mcp) 🎖️ 📇 ☁️ 🍎 🪟 🐧 - سرور DexPaprika MCP Coinpaprika [DexPaprika API](https://docs.dexpaprika.com) با کارایی بالا را در معرض دید قرار می‌دهد که بیش از ۲۰ زنجیره و بیش از ۵ میلیون توکن را با قیمت‌گذاری بی‌درنگ، داده‌های استخر نقدینگی و داده‌های تاریخی OHLCV پوشش می‌دهد و به عامل‌های هوش مصنوعی دسترسی استاندارد به داده‌های جامع بازار از طریق Model Context Protocol را می‌دهد.
- [doggybee/mcp-server-ccxt](https://github.com/doggybee/mcp-server-ccxt) 📇 ☁️ - یک سرور MCP برای دسترسی به داده‌های بازار کریپتو بی‌درنگ و معامله از طریق بیش از ۲۰ صرافی با استفاده از کتابخانه CCXT. از spot، futures، OHLCV، موجودی‌ها، سفارشات و موارد دیگر پشتیبانی می‌کند.
- [ferdousbhai/investor-agent](https://github.com/ferdousbhai/investor-agent) 🐍 ☁️ - یکپارچه‌سازی با Yahoo Finance برای دریافت داده‌های بازار سهام شامل توصیه‌های آپشن‌ها
- [ferdousbhai/tasty-agent](https://github.com/ferdousbhai/tasty-agent) 🐍 ☁️ - یکپارچه‌سازی با Tastyworks API برای مدیریت فعالیت‌های معاملاتی در Tastytrade
- [ferdousbhai/wsb-analyst-mcp](https://github.com/ferdousbhai/wsb-analyst-mcp) 🐍 ☁️ - یکپارچه‌سازی با Reddit برای تحلیل محتوا در جامعه WallStreetBets
- [getalby/nwc-mcp-server](https://github.com/getalby/nwc-mcp-server) 📇 🏠 - یکپارچه‌سازی کیف پول Bitcoin Lightning با قدرت Nostr Wallet Connect
- [glaksmono/finbud-data-mcp](https://github.com/glaksmono/finbud-data-mcp/tree/main/packages/mcp-server) 📇 ☁️ 🏠 - دسترسی به داده‌های مالی جامع و بی‌درنگ (سهام، آپشن‌ها، کریپتو، فارکس) از طریق APIهای توسعه‌دهنده-پسند و بومی هوش مصنوعی که ارزش بی‌نظیری ارائه می‌دهند.
- [heurist-network/heurist-mesh-mcp-server](https://github.com/heurist-network/heurist-mesh-mcp-server) 🎖️ ⛅️ 🏠 🐍 - دسترسی به عامل‌های هوش مصنوعی web3 تخصصی برای تحلیل بلاکچین، ممیزی امنیتی قراردادهای هوشمند، ارزیابی معیارهای توکن و تعاملات on-chain از طریق شبکه Heurist Mesh. ابزارهای جامعی برای تحلیل DeFi، ارزش‌گذاری NFT و نظارت بر تراکنش‌ها در چندین بلاکچین فراهم می‌کند
- [hoqqun/stooq-mcp](https://github.com/hoqqun/stooq-mcp) 🦀 ☁️ - دریافت قیمت‌های لحظه‌ای سهام از Stooq بدون نیاز به کلید API. پشتیبانی از بازارهای جهانی (آمریکا، ژاپن، انگلستان، آلمان).
- [HuggingAGI/mcp-baostock-server](https://github.com/HuggingAGI/mcp-baostock-server) 🐍 ☁️ - سرور MCP مبتنی بر baostock، که قابلیت‌های دسترسی و تحلیل داده‌های بازار سهام چین را فراهم می‌کند.
- [intentos-labs/beeper-mcp](https://github.com/intentos-labs/beeper-mcp) 🐍 - Beeper تراکنش‌ها را در BSC فراهم می‌کند، شامل انتقال موجودی/توکن، سواپ توکن در Pancakeswap و ادعای پاداش beeper.
- [janswist/mcp-dexscreener](https://github.com/janswist/mcp-dexscreener) 📇 ☁️ - قیمت‌های بازار on-chain بی‌درنگ با استفاده از API باز و رایگان Dexscreener
- [jjlabsio/korea-stock-mcp](https://github.com/jjlabsio/korea-stock-mcp) 📇 ☁️ - یک سرور MCP برای تحلیل سهام کره با استفاده از OPEN DART API و KRX API
- [kukapay/binance-alpha-mcp](https://github.com/kukapay/binance-alpha-mcp) 🐍 ☁️ - یک سرور MCP برای ردیابی معاملات Binance Alpha، که به عامل‌های هوش مصنوعی در بهینه‌سازی جمع‌آوری امتیاز آلفا کمک می‌کند.
- [kukapay/blockbeats-mcp](https://github.com/kukapay/blockbeats-mcp) 🐍 ☁️ - یک سرور MCP که اخبار بلاکچین و مقالات عمیق از BlockBeats را برای عامل‌های هوش مصنوعی ارائه می‌دهد.
- [kukapay/blocknative-mcp](https://github.com/kukapay/blocknative-mcp) 🐍 ☁️ - ارائه پیش‌بینی‌های بی‌درنگ قیمت گاز در چندین بلاکچین، با قدرت Blocknative.
- [kukapay/bridge-rates-mcp](https://github.com/kukapay/bridge-rates-mcp) 📇 ☁️ - ارائه نرخ‌های بریج بین-زنجیره‌ای بی‌درنگ و مسیرهای انتقال بهینه به عامل‌های هوش مصنوعی onchain.
- [kukapay/chainlink-feeds-mcp](https://github.com/kukapay/chainlink-feeds-mcp) 📇 ☁️ - ارائه دسترسی بی‌درنگ به فیدهای قیمت on-chain غیرمتمرکز Chainlink.
- [kukapay/chainlist-mcp](https://github.com/kukapay/chainlist-mcp) 📇 ☁️ - یک سرور MCP که به عامل‌های هوش مصنوعی دسترسی سریع به اطلاعات زنجیره EVM تأیید شده، شامل URLهای RPC، شناسه‌های زنجیره، کاوشگرها و توکن‌های بومی را می‌دهد.
- [kukapay/cointelegraph-mcp](https://github.com/kukapay/cointelegraph-mcp) 🐍 ☁️ - ارائه دسترسی بی‌درنگ به آخرین اخبار از Cointelegraph.
- [kukapay/crypto-feargreed-mcp](https://github.com/kukapay/crypto-feargreed-mcp) 🐍 ☁️ - ارائه داده‌های شاخص ترس و طمع کریپتو بی‌درنگ و تاریخی.
- [kukapay/crypto-indicators-mcp](https://github.com/kukapay/crypto-indicators-mcp) 🐍 ☁️ - یک سرور MCP که طیفی از شاخص‌ها و استراتژی‌های تحلیل فنی ارزهای دیجیتال را فراهم می‌کند.
- [kukapay/crypto-liquidations-mcp](https://github.com/kukapay/crypto-liquidations-mcp) 🐍 ☁️ - رویدادهای لیکوئیدیشن ارزهای دیجیتال بی‌درنگ را از Binance استریم می‌کند.
- [kukapay/crypto-news-mcp](https://github.com/kukapay/crypto-news-mcp) 🐍 ☁️ - یک سرور MCP که اخبار ارزهای دیجیتال بی‌درنگ را از NewsData برای عامل‌های هوش مصنوعی فراهم می‌کند.
- [kukapay/crypto-orderbook-mcp](https://github.com/kukapay/crypto-orderbook-mcp) 🐍 ☁️ - تحلیل عمق و عدم تعادل دفتر سفارش در صرافی‌های بزرگ کریپتو.
- [kukapay/crypto-pegmon-mcp](https://github.com/kukapay/crypto-pegmon-mcp) 🐍 ☁️ - ردیابی یکپارچگی peg استیبل‌کوین‌ها در چندین بلاکچین.
- [kukapay/crypto-portfolio-mcp](https://github.com/kukapay/crypto-portfolio-mcp) 🐍 ☁️ - یک سرور MCP برای ردیابی و مدیریت تخصیص‌های پرتفوی ارزهای دیجیتال.
- [kukapay/crypto-projects-mcp](https://github.com/kukapay/crypto-projects-mcp) 🐍 ☁️ - ارائه داده‌های پروژه ارزهای دیجیتال از Mobula.io به عامل‌های هوش مصنوعی.
- [kukapay/crypto-rss-mcp](https://github.com/kukapay/crypto-rss-mcp) 🐍 ☁️ - یک سرور MCP که اخبار ارزهای دیجیتال بی‌درنگ را از چندین فید RSS جمع‌آوری می‌کند.
- [kukapay/crypto-sentiment-mcp](https://github.com/kukapay/crypto-sentiment-mcp) 🐍 ☁️ - یک سرور MCP که تحلیل احساسات ارزهای دیجیتال را به عامل‌های هوش مصنوعی ارائه می‌دهد.
- [kukapay/crypto-trending-mcp](https://github.com/kukapay/crypto-trending-mcp) 🐍 ☁️ - ردیابی آخرین توکن‌های پرطرفدار در CoinGecko.
- [kukapay/crypto-whitepapers-mcp](https://github.com/kukapay/crypto-whitepapers-mcp) 🐍 ☁️ - به عنوان یک پایگاه دانش ساختاریافته از وایت‌پیپرهای کریپتو عمل می‌کند.
- [kukapay/cryptopanic-mcp-server](https://github.com/kukapay/cryptopanic-mcp-server) 🐍 ☁️ - ارائه آخرین اخبار ارزهای دیجیتال به عامل‌های هوش مصنوعی، با قدرت CryptoPanic.
- [kukapay/dao-proposals-mcp](https://github.com/kukapay/dao-proposals-mcp) 🐍 ☁️ - یک سرور MCP که پیشنهادات حاکمیتی زنده را از DAOهای بزرگ جمع‌آوری می‌کند.
- [kukapay/defi-yields-mcp](https://github.com/kukapay/defi-yields-mcp) 🐍 ☁️ - یک سرور MCP برای عامل‌های هوش مصنوعی برای کاوش فرصت‌های بازدهی DeFi.
- [kukapay/dune-analytics-mcp](https://github.com/kukapay/dune-analytics-mcp) 🐍 ☁️ - یک سرور mcp که داده‌های Dune Analytics را به عامل‌های هوش مصنوعی متصل می‌کند.
- [kukapay/etf-flow-mcp](https://github.com/kukapay/etf-flow-mcp) 🐍 ☁️ - ارائه داده‌های جریان ETF کریپتو برای قدرت بخشیدن به تصمیم‌گیری عامل‌های هوش مصنوعی.
- [kukapay/freqtrade-mcp](https://github.com/kukapay/freqtrade-mcp) 🐍 ☁️ - یک سرور MCP که با ربات معامله‌گر ارز دیجیتال Freqtrade یکپارچه می‌شود.
- [kukapay/funding-rates-mcp](https://github.com/kukapay/funding-rates-mcp) 🐍 ☁️ - ارائه داده‌های نرخ تأمین مالی بی‌درنگ در صرافی‌های بزرگ کریپتو.
- [kukapay/hyperliquid-info-mcp](https://github.com/kukapay/hyperliquid-info-mcp) 🐍 ☁️ - یک سرور MCP که داده‌ها و بینش‌های بی‌درنگ را از DEX perp Hyperliquid برای استفاده در ربات‌ها، داشبوردها و تحلیل‌ها فراهم می‌کند.
- [kukapay/hyperliquid-whalealert-mcp](https://github.com/kukapay/hyperliquid-whalealert-mcp) 🐍 ☁️ - یک سرور MCP که هشدارهای نهنگ بی‌درنگ را در Hyperliquid ارائه می‌دهد و موقعیت‌هایی با ارزش اسمی بیش از ۱ میلیون دلار را پرچم‌گذاری می‌کند.
- [kukapay/jupiter-mcp](https://github.com/kukapay/jupiter-mcp) 🐍 ☁️ - یک سرور MCP برای اجرای سواپ‌های توکن در بلاکچین Solana با استفاده از Ultra API جدید Jupiter.
- [kukapay/pancakeswap-poolspy-mcp](https://github.com/kukapay/pancakeswap-poolspy-mcp) 🐍 ☁️ - یک سرور MCP که استخرهای تازه ایجاد شده در Pancake Swap را ردیابی می‌کند.
- [kukapay/pumpswap-mcp](https://github.com/kukapay/pumpswap-mcp) 🐍 ☁️ - به عامل‌های هوش مصنوعی امکان تعامل با PumpSwap را برای سواپ‌های توکن بی‌درنگ و معاملات خودکار on-chain می‌دهد.
- [kukapay/raydium-launchlab-mcp](https://github.com/kukapay/raydium-launchlab-mcp) 🐍 ☁️ - یک سرور MCP که به عامل‌های هوش مصنوعی امکان راه‌اندازی، خرید و فروش توکن‌ها را در Raydium Launchpad (معروف به LaunchLab) می‌دهد.
- [kukapay/rug-check-mcp](https://github.com/kukapay/rug-check-mcp) 🐍 ☁️ - یک سرور MCP که ریسک‌های بالقوه در توکن‌های meme Solana را شناسایی می‌کند.
- [kukapay/sui-trader-mcp](https://github.com/kukapay/sui-trader-mcp) 📇 ☁️ - یک سرور MCP طراحی شده برای عامل‌های هوش مصنوعی برای انجام سواپ‌های توکن بهینه در بلاکچین Sui.
- [kukapay/thegraph-mcp](https://github.com/kukapay/thegraph-mcp) 🐍 ☁️ - یک سرور MCP که عامل‌های هوش مصنوعی را با داده‌های بلاکچین نمایه‌سازی شده از The Graph قدرت می‌بخشد.
- [kukapay/token-minter-mcp](https://github.com/kukapay/token-minter-mcp) 🐍 ☁️ - یک سرور MCP که ابزارهایی برای عامل‌های هوش مصنوعی برای مینت توکن‌های ERC-20 در چندین بلاکچین فراهم می‌کند.
- [kukapay/token-revoke-mcp](https://github.com/kukapay/token-revoke-mcp) 🐍 ☁️ - یک سرور MCP برای بررسی و لغو مجوزهای توکن ERC-20 در چندین بلاکچین.
- [kukapay/twitter-username-changes-mcp](https://github.com/kukapay/twitter-username-changes-mcp) 🐍 ☁️ - یک سرور MCP که تغییرات تاریخی نام‌های کاربری توییتر را ردیابی می‌کند.
- [kukapay/uniswap-poolspy-mcp](https://github.com/kukapay/uniswap-poolspy-mcp) 🐍 ☁️ - یک سرور MCP که استخرهای نقدینگی تازه ایجاد شده در Uniswap را در چندین بلاکچین ردیابی می‌کند.
- [kukapay/uniswap-price-mcp](https://github.com/kukapay/uniswap-price-mcp) 📇 ☁️ - یک سرور MCP که استخرهای نقدینگی تازه ایجاد شده در Uniswap را در چندین بلاکچین ردیابی می‌کند.
- [kukapay/uniswap-trader-mcp](https://github.com/kukapay/uniswap-trader-mcp) 🐍 ☁️ - یک سرور MCP که قیمت‌های توکن بی‌درنگ را از Uniswap V3 در چندین زنجیره ارائه می‌دهد.
- [kukapay/wallet-inspector-mcp](https://github.com/kukapay/wallet-inspector-mcp) 🐍 ☁️ - یک سرور MCP که به عامل‌های هوش مصنوعی قدرت می‌دهد تا موجودی و فعالیت onchain هر کیف پولی را در زنجیره‌های اصلی EVM و زنجیره Solana بازرسی کنند.
- [kukapay/web3-jobs-mcp](https://github.com/kukapay/web3-jobs-mcp) 🐍 ☁️ - یک سرور MCP که به عامل‌های هوش مصنوعی دسترسی بی‌درنگ به مشاغل Web3 منتخب را می‌دهد.
- [kukapay/whale-tracker-mcp](https://github.com/kukapay/whale-tracker-mcp) 🐍 ☁️ - یک سرور mcp برای ردیابی تراکنش‌های نهنگ‌های ارز دیجیتال.
- [laukikk/alpaca-mcp](https://github.com/laukikk/alpaca-mcp) 🐍 ☁️ - یک سرور MCP برای API معاملاتی Alpaca برای مدیریت پرتفوی‌های سهام و کریپتو، قرار دادن معاملات و دسترسی به داده‌های بازار.
- [logotype/fixparser](https://gitlab.com/logotype/fixparser) 🎖 📇 ☁️ 🏠 📟  - پروتکل FIX (ارسال سفارشات، داده‌های بازار و غیره) نوشته شده در TypeScript.
- [longportapp/openapi](https://github.com/longportapp/openapi/tree/main/mcp) - 🐍 ☁️ - LongPort OpenAPI داده‌های بی‌درنگ بازار سهام را فراهم می‌کند، به هوش مصنوعی قابلیت‌های تحلیل و معامله را از طریق MCP می‌دهد.
- [mcpdotdirect/evm-mcp-server](https://github.com/mcpdotdirect/evm-mcp-server) 📇 ☁️ - خدمات جامع بلاکچین برای بیش از ۳۰ شبکه EVM، که از توکن‌های بومی، ERC20، NFTها، قراردادهای هوشمند، تراکنش‌ها و وضوح ENS پشتیبانی می‌کند.
- [mcpdotdirect/starknet-mcp-server](https://github.com/mcpdotdirect/starknet-mcp-server) 📇 ☁️ - یکپارچه‌سازی جامع بلاکچین Starknet با پشتیبانی از توکن‌های بومی (ETH، STRK)، قراردادهای هوشمند، وضوح StarknetID و انتقال توکن.
- [minhyeoky/mcp-server-ledger](https://github.com/minhyeoky/mcp-server-ledger) 🐍 🏠 - یکپارچه‌سازی با ledger-cli برای مدیریت تراکنش‌های مالی و تولید گزارش‌ها.
- [narumiruna/yfinance-mcp](https://github.com/narumiruna/yfinance-mcp) 🐍 ☁️ - یک سرور MCP که از yfinance برای به دست آوردن اطلاعات از Yahoo Finance استفاده می‌کند.
- [OctagonAI/octagon-mcp-server](https://github.com/OctagonAI/octagon-mcp-server) 🐍 ☁️ - عامل‌های هوش مصنوعی Octagon برای یکپارچه‌سازی داده‌های بازار خصوصی و عمومی
- [openMF/mcp-mifosx](https://github.com/openMF/mcp-mifosx) ☁️ 🏠 - یکپارچه‌سازی با بانکداری مرکزی برای مدیریت مشتریان، وام‌ها، پس‌اندازها، سهام، تراکنش‌های مالی و تولید گزارش‌های مالی.
- [polygon-io/mcp_polygon)](https://github.com/polygon-io/mcp_polygon)) 🐍 ☁️ - یک سرور MCP که دسترسی به APIهای داده‌های بازار مالی [Polygon.io](https://polygon.io/) را برای سهام، شاخص‌ها، فارکس، آپشن‌ها و موارد دیگر فراهم می‌کند.
- [pwh-pwh/coin-mcp-server](https://github.com/pwh-pwh/coin-mcp-server) 🐍 ☁️ - Bitget API برای دریافت قیمت ارزهای دیجیتال.
- [QuantConnect/mcp-server](https://github.com/QuantConnect/mcp-server) 🐍 ☁️ – یک سرور MCP Python داکرایز شده که هوش مصنوعی محلی شما (مانند Claude Desktop و غیره) را به QuantConnect API متصل می‌کند—و به شما قدرت می‌دهد تا پروژه‌ها را ایجاد کنید، استراتژی‌ها را بک‌تست کنید، همکاران را مدیریت کنید و گردش‌های کاری معاملات زنده را مستقیماً از طریق پرامپت‌های زبان طبیعی مستقر کنید.
- [QuantGeekDev/coincap-mcp](https://github.com/QuantGeekDev/coincap-mcp) 📇 ☁️ - یکپارچه‌سازی داده‌های بازار ارزهای دیجیتال بی‌درنگ با استفاده از API عمومی CoinCap، که دسترسی به قیمت‌های کریپتو و اطلاعات بازار را بدون کلید API فراهم می‌کند
- [QuentinCody/braintree-mcp-server](https://github.com/QuentinCody/braintree-mcp-server) 🐍 - سرور MCP غیر رسمی دروازه پرداخت PayPal Braintree برای عامل‌های هوش مصنوعی برای پردازش پرداخت‌ها، مدیریت مشتریان و مدیریت امن تراکنش‌ها.
- [RomThpt/xrpl-mcp-server](https://github.com/RomThpt/mcp-xrpl) 📇 ☁️ - سرور MCP برای XRP Ledger که دسترسی به اطلاعات حساب، تاریخچه تراکنش و داده‌های شبکه را فراهم می‌کند. امکان کوئری اشیاء لجر، ارسال تراکنش‌ها و نظارت بر شبکه XRPL را می‌دهد.
- [SaintDoresh/Crypto-Trader-MCP-ClaudeDesktop](https://github.com/SaintDoresh/Crypto-Trader-MCP-ClaudeDesktop.git) 🐍 ☁️ - یک ابزار MCP که داده‌های بازار ارزهای دیجیتال را با استفاده از CoinGecko API فراهم می‌کند.
- [SaintDoresh/YFinance-Trader-MCP-ClaudeDesktop](https://github.com/SaintDoresh/YFinance-Trader-MCP-ClaudeDesktop.git) 🐍 ☁️ - یک ابزار MCP که داده‌ها و تحلیل بازار سهام را با استفاده از Yahoo Finance API فراهم می‌کند.
- [shareseer/shareseer-mcp-server](https://github.com/shareseer/shareseer-mcp-server) 🏎️ ☁️ - MCP برای دسترسی به پرونده‌های SEC، اطلاعات مالی و داده‌های معاملات داخلی به صورت بی‌درنگ با استفاده از [ShareSeer](https://shareseer.com)
- [tatumio/blockchain-mcp](https://github.com/tatumio/blockchain-mcp) ☁️ - سرور MCP برای داده‌های بلاکچین. دسترسی به API بلاکچین Tatum را در بیش از ۱۳۰ شبکه با ابزارهایی شامل RPC Gateway و بینش‌های داده بلاکچین فراهم می‌کند.
- [ThomasMarches/substrate-mcp-rs](https://github.com/ThomasMarches/substrate-mcp-rs) 🦀 🏠 - یک پیاده‌سازی سرور MCP برای تعامل با بلاکچین‌های مبتنی بر Substrate. ساخته شده با Rust و ارتباط با crate [subxt](https://github.com/paritytech/subxt).
- [tooyipjee/yahoofinance-mcp](https://github.com/tooyipjee/yahoofinance-mcp.git) 📇 ☁️ - نسخه TS از yahoo finance mcp.
- [Trade-Agent/trade-agent-mcp](https://github.com/Trade-Agent/trade-agent-mcp.git) 🎖️ ☁️ - سهام و کریپتو را در کارگزاری‌های رایج (Robinhood، E*Trade، Coinbase، Kraken) از طریق سرور MCP Trade Agent معامله کنید.
- [twelvedata/mcp](https://github.com/twelvedata/mcp) 🐍 ☁️ - با APIهای [Twelve Data](https://twelvedata.com) تعامل داشته باشید تا به داده‌های بازار مالی بی‌درنگ و تاریخی برای عامل‌های هوش مصنوعی خود دسترسی پیدا کنید.
- [wowinter13/solscan-mcp](https://github.com/wowinter13/solscan-mcp) 🦀 🏠 - یک ابزار MCP برای کوئری تراکنش‌های Solana با استفاده از زبان طبیعی با Solscan API.
- [Wuye-AI/mcp-server-wuye-ai](https://github.com/wuye-ai/mcp-server-wuye-ai) 🎖️ 📇 ☁️ - یک سرور MCP که با قابلیت‌های پلتفرم CRIC Wuye AI، یک دستیار هوشمند ویژه برای صنعت مدیریت املاک، تعامل دارد.
- [XeroAPI/xero-mcp-server](https://github.com/XeroAPI/xero-mcp-server) 📇 ☁️ – یک سرور MCP که با API Xero یکپارچه می‌شود و امکان دسترسی استاندارد به ویژگی‌های حسابداری و تجاری Xero را فراهم می‌کند.
- [zlinzzzz/finData-mcp-server](https://github.com/zlinzzzz/finData-mcp-server) 🐍 ☁️ - یک سرور MCP برای دسترسی به داده‌های مالی حرفه‌ای، که از چندین ارائه‌دهنده داده مانند Tushare پشتیبانی می‌کند.
- [zolo-ryan/MarketAuxMcpServer](https://github.com/Zolo-Ryan/MarketAuxMcpServer) 📇 ☁️ - سرور MCP برای جستجوی جامع اخبار بازار و مالی با فیلترهای پیشرفته بر اساس نمادها، صنایع، کشورها و بازه‌های زمانی.
- [JamesANZ/evm-mcp](https://github.com/JamesANZ/evm-mcp) 📇 ☁️ - یک سرور MCP که دسترسی کامل به متدهای JSON-RPC ماشین مجازی اتریوم (EVM) را فراهم می‌کند. با هر ارائه‌دهنده نود سازگار با EVM از جمله Infura، Alchemy، QuickNode، نودهای محلی و موارد دیگر کار می‌کند.
- [JamesANZ/prediction-market-mcp](https://github.com/JamesANZ/prediction-market-mcp) 📇 ☁️ - یک سرور MCP که داده‌های بازار پیش‌بینی بی‌درنگ را از چندین پلتفرم از جمله Polymarket، PredictIt و Kalshi فراهم می‌کند. به دستیاران هوش مصنوعی امکان کوئری شانس‌ها، قیمت‌ها و اطلاعات بازار فعلی را از طریق یک رابط یکپارچه می‌دهد.
- [JamesANZ/bitcoin-mcp](https://github.com/JamesANZ/bitcoin-mcp) 📇 🏠 - یک سرور MCP که به مدل‌های هوش مصنوعی امکان کوئری بلاکچین Bitcoin را می‌دهد.
- [hive-intel/hive-crypto-mcp](https://github.com/hive-intel/hive-crypto-mcp) 📇 ☁️ 🏠 - Hive Intelligence: MCP نهایی ارزهای دیجیتال برای دستیاران هوش مصنوعی با دسترسی یکپارچه به تحلیل‌های کریپتو، DeFi و Web3

### 🎮 <a name="gaming"></a>بازی

یکپارچه‌سازی با داده‌های مرتبط با بازی، موتورهای بازی و خدمات

- [CoderGamester/mcp-unity](https://github.com/CoderGamester/mcp-unity) #️⃣ 🏠 - سرور MCP برای یکپارچه‌سازی با موتور بازی Unity3d برای توسعه بازی
- [Coding-Solo/godot-mcp](https://github.com/Coding-Solo/godot-mcp) 📇 🏠 - یک سرور MCP برای تعامل با موتور بازی Godot، که ابزارهایی برای ویرایش، اجرا، اشکال‌زدایی و مدیریت صحنه‌ها در پروژه‌های Godot فراهم می‌کند.
- [ddsky/gamebrain-api-clients](https://github.com/ddsky/gamebrain-api-clients) ☁️ - صدها هزار بازی ویدیویی را در هر پلتفرمی از طریق [GameBrain API](https://gamebrain.co/api) جستجو و کشف کنید.
- [IvanMurzak/Unity-MCP](https://github.com/IvanMurzak/Unity-MCP) #️⃣ 🏠 🍎 🪟 🐧 - سرور MCP برای ویرایشگر Unity و برای یک بازی ساخته شده با Unity
- [jiayao/mcp-chess](https://github.com/jiayao/mcp-chess) 🐍 🏠 - یک سرور MCP که در برابر LLMها شطرنج بازی می‌کند.
- [kkjdaniel/bgg-mcp](https://github.com/kkjdaniel/bgg-mcp) 🏎️ ☁️ - یک سرور MCP که تعامل با داده‌های مرتبط با بازی‌های رومیزی را از طریق BoardGameGeek API (XML API2) امکان‌پذیر می‌کند.
- [opgginc/opgg-mcp](https://github.com/opgginc/opgg-mcp) 📇 ☁️ - به داده‌های بازی بی‌درنگ در عناوین محبوبی مانند League of Legends، TFT و Valorant دسترسی پیدا کنید و تحلیل‌های قهرمانان، برنامه‌های eSports، ترکیب‌های متا و آمار شخصیت‌ها را ارائه می‌دهد.
- [pab1ito/chess-mcp](https://github.com/pab1it0/chess-mcp) 🐍 ☁️ - به داده‌های بازیکن Chess.com، سوابق بازی و سایر اطلاعات عمومی از طریق رابط‌های استاندارد MCP دسترسی پیدا کنید و به دستیاران هوش مصنوعی امکان جستجو و تحلیل اطلاعات شطرنج را می‌دهد.
- [rishijatia/fantasy-pl-mcp](https://github.com/rishijatia/fantasy-pl-mcp/) 🐍 ☁️ - یک سرور MCP برای داده‌های بی‌درنگ Fantasy Premier League و ابزارهای تحلیل.
- [sonirico/mpc-stockfish](https://github.com/sonirico/mcp-stockfish) - 🏎️ 🏠 🍎 🪟 🐧️ سرور MCP که سیستم‌های هوش مصنوعی را به موتور شطرنج Stockfish متصل می‌کند.
- [stefan-xyz/mcp-server-runescape](https://github.com/stefan-xyz/mcp-server-runescape) 📇 - یک سرور MCP با ابزارهایی برای تعامل با داده‌های RuneScape (RS) و Old School RuneScape (OSRS)، شامل قیمت آیتم‌ها، امتیازات بازیکنان و موارد دیگر.
- [tomholford/mcp-tic-tac-toe](https://github.com/tomholford/mcp-tic-tac-toe) 🏎️ 🏠 - با استفاده از این سرور MCP در برابر یک حریف هوش مصنوعی Tic Tac Toe بازی کنید.

### 🧠 <a name="knowledge--memory"></a>دانش و حافظه

ذخیره‌سازی حافظه پایدار با استفاده از ساختارهای گراف دانش. به مدل‌های هوش مصنوعی امکان نگهداری و کوئری اطلاعات ساختاریافته در طول جلسات را می‌دهد.


- [0xshellming/mcp-summarizer](https://github.com/0xshellming/mcp-summarizer) 📕 ☁️ - سرور MCP خلاصه‌سازی هوش مصنوعی، پشتیبانی از انواع مختلف محتوا: متن ساده، صفحات وب، اسناد PDF، کتاب‌های EPUB، محتوای HTML
- [apecloud/ApeRAG](https://github.com/apecloud/ApeRAG) 🐍 ☁️ 🏠 - پلتفرم RAG آماده برای تولید که Graph RAG، جستجوی برداری و جستجوی متن کامل را ترکیب می‌کند. بهترین انتخاب برای ساخت گراف دانش خود و برای مهندسی زمینه
- [chatmcp/mcp-server-chatsum](https://github.com/chatmcp/mcp-server-chatsum) - پیام‌های چت خود را با پرامپت‌های هوش مصنوعی کوئری و خلاصه کنید.
- [cameronrye/openzim-mcp](https://github.com/cameronrye/openzim-mcp) 🐍 🏠 - سرور MCP مدرن و امن برای دسترسی آفلاین به پایگاه‌های دانش با فرمت ZIM. به مدل‌های هوش مصنوعی امکان جستجو و پیمایش ویکی‌پدیا، محتوای آموزشی و سایر آرشیوهای دانش فشرده را با بازیابی هوشمند، کشینگ و API جامع می‌دهد.
- [CheMiguel23/MemoryMesh](https://github.com/CheMiguel23/MemoryMesh) 📇 🏠 - حافظه مبتنی بر گراف پیشرفته با تمرکز بر نقش‌آفرینی هوش مصنوعی و تولید داستان
- [entanglr/zettelkasten-mcp](https://github.com/entanglr/zettelkasten-mcp) 🐍 🏠 - یک سرور Model Context Protocol (MCP) که روش مدیریت دانش Zettelkasten را پیاده‌سازی می‌کند و به شما امکان می‌دهد یادداشت‌های اتمی را از طریق Claude و سایر کلاینت‌های سازگار با MCP ایجاد، پیوند و جستجو کنید.
- [GistPad-MCP](https://github.com/lostintangent/gistpad-mcp) 📇 🏠 - از GitHub Gists برای مدیریت و دسترسی به دانش شخصی، یادداشت‌های روزانه و پرامپت‌های قابل استفاده مجدد خود استفاده کنید. این به عنوان یک همراه برای https://gistpad.dev و [افزونه GistPad VS Code](https://aka.ms/gistpad) عمل می‌کند.
- [graphlit-mcp-server](https://github.com/graphlit/graphlit-mcp-server) 📇 ☁️ - هر چیزی را از Slack، Discord، وب‌سایت‌ها، Google Drive، Linear یا GitHub به یک پروژه Graphlit وارد کنید - و سپس دانش مرتبط را در یک کلاینت MCP مانند Cursor، Windsurf یا Cline جستجو و بازیابی کنید.
- [hannesrudolph/mcp-ragdocs](https://github.com/hannesrudolph/mcp-ragdocs) 🐍 🏠 - یک پیاده‌سازی سرور MCP که ابزارهایی برای بازیابی و پردازش مستندات از طریق جستجوی برداری فراهم می‌کند و به دستیاران هوش مصنوعی امکان می‌دهد پاسخ‌های خود را با زمینه مستندات مرتبط تقویت کنند
- [jinzcdev/markmap-mcp-server](https://github.com/jinzcdev/markmap-mcp-server) 📇 🏠 - یک سرور MCP ساخته شده بر روی [markmap](https://github.com/markmap/markmap) که **Markdown** را به **نقشه‌های ذهنی** تعاملی تبدیل می‌کند. از خروجی‌های چند فرمتی (PNG/JPG/SVG)، پیش‌نمایش زنده در مرورگر، کپی Markdown با یک کلیک و ویژگی‌های تجسم پویا پشتیبانی می‌کند.
- [kaliaboi/mcp-zotero](https://github.com/kaliaboi/mcp-zotero) 📇 ☁️ - یک اتصال‌دهنده برای LLMها برای کار با مجموعه‌ها و منابع در Zotero Cloud شما
- [mem0ai/mem0-mcp](https://github.com/mem0ai/mem0-mcp) 🐍 🏠 - یک سرور Model Context Protocol برای Mem0 که به مدیریت ترجیحات و الگوهای کدنویسی کمک می‌کند و ابزارهایی برای ذخیره، بازیابی و مدیریت معنایی پیاده‌سازی‌های کد، بهترین شیوه‌ها و مستندات فنی در IDEهایی مانند Cursor و Windsurf فراهم می‌کند
- [modelcontextprotocol/server-memory](https://github.com/modelcontextprotocol/servers/tree/main/src/memory) 📇 🏠 - سیستم حافظه پایدار مبتنی بر گراف دانش برای حفظ زمینه
- [MWGMorningwood/Central-Memory-MCP](https://github.com/MWGMorningwood/Central-Memory-MCP) 📇 ☁️ - یک سرور MCP قابل میزبانی در Azure PaaS که یک گراف دانش مبتنی بر فضای کاری را برای چندین توسعه‌دهنده با استفاده از تریگرهای MCP Azure Functions و Table storage فراهم می‌کند.
- [pi22by7/In-Memoria](https://github.com/pi22by7/In-Memoria) 📇 🦀 🏠 🍎 🐧 🪟 - زیرساخت هوش پایدار برای توسعه عامل‌محور که به دستیاران کدنویسی هوش مصنوعی حافظه تجمعی و یادگیری الگو می‌دهد. پیاده‌سازی ترکیبی TypeScript/Rust با ذخیره‌سازی محلی-اول با استفاده از SQLite + SurrealDB برای تحلیل معنایی و درک تدریجی کدبیس.
- [pinecone-io/assistant-mcp](https://github.com/pinecone-io/assistant-mcp) 🎖️ 🦀 ☁️ - به دستیار Pinecone شما متصل می‌شود و به عامل زمینه را از موتور دانش آن می‌دهد.
- [ragieai/mcp-server](https://github.com/ragieai/ragie-mcp-server) 📇 ☁️ - زمینه را از پایگاه دانش [Ragie](https://www.ragie.ai) (RAG) خود که به یکپارچه‌سازی‌هایی مانند Google Drive، Notion، JIRA و موارد دیگر متصل است، بازیابی کنید.
- [shinpr/mcp-local-rag](https://github.com/shinpr/mcp-local-rag) 📇 🏠 - سرور جستجوی اسناد با اولویت حریم خصوصی که کاملاً به صورت محلی اجرا می‌شود. از جستجوی معنایی بر روی فایل‌های PDF، DOCX، TXT و Markdown با ذخیره‌سازی برداری LanceDB و embeddingهای محلی پشتیبانی می‌کند - بدون نیاز به کلید API یا خدمات ابری.
- [TechDocsStudio/biel-mcp](https://github.com/TechDocsStudio/biel-mcp) 📇 ☁️ - به ابزارهای هوش مصنوعی مانند Cursor، VS Code یا Claude Desktop اجازه دهید با استفاده از مستندات محصول شما به سؤالات پاسخ دهند. Biel.ai سیستم RAG و سرور MCP را فراهم می‌کند.
- [topoteretes/cognee](https://github.com/topoteretes/cognee/tree/dev/cognee-mcp) 📇 🏠 - مدیر حافظه برای برنامه‌ها و عامل‌های هوش مصنوعی با استفاده از ذخیره‌سازی‌های مختلف گراف و برداری و اجازه ورود داده از بیش از ۳۰ منبع داده
- [unibaseio/membase-mcp](https://github.com/unibaseio/membase-mcp) 📇 ☁️ - حافظه عامل خود را به صورت توزیع شده توسط Membase ذخیره و کوئری کنید
- [upstash/context7](https://github.com/upstash/context7) 📇 ☁️ - مستندات کد به‌روز برای LLMها و ویرایشگرهای کد هوش مصنوعی.
- [JamesANZ/memory-mcp](https://github.com/JamesANZ/memory-mcp) 📇 🏠 - یک سرور MCP که خاطرات را از چندین LLM با استفاده از MongoDB ذخیره و بازیابی می‌کند. ابزارهایی برای ذخیره، بازیابی، اضافه کردن و پاک کردن خاطرات مکالمه با برچسب‌های زمانی و شناسایی LLM فراهم می‌کند.
- [JamesANZ/cross-llm-mcp](https://github.com/JamesANZ/cross-llm-mcp) 📇 🏠 - یک سرور MCP که ارتباط بین-LLM و به اشتراک‌گذاری حافظه را امکان‌پذیر می‌کند و به مدل‌های مختلف هوش مصنوعی اجازه می‌دهد در مکالمات همکاری و زمینه را به اشتراک بگذارند.

### 🗺️ <a name="location-services"></a>خدمات مکانی

خدمات مبتنی بر مکان و ابزارهای نقشه‌برداری. به مدل‌های هوش مصنوعی امکان کار با داده‌های جغرافیایی، اطلاعات هواشناسی و تحلیل‌های مبتنی بر مکان را می‌دهد.

- [briandconnelly/mcp-server-ipinfo](https://github.com/briandconnelly/mcp-server-ipinfo) 🐍 ☁️  - موقعیت جغرافیایی آدرس IP و اطلاعات شبکه با استفاده از IPInfo API
- [cqtrinv/trinvmcp](https://github.com/cqtrinv/trinvmcp) 📇 ☁️ - کاوش کمون‌ها و قطعات کاداستر فرانسه بر اساس نام و سطح
- [devilcoder01/weather-mcp-server](https://github.com/devilcoder01/weather-mcp-server) 🐍 ☁️ - دسترسی به داده‌های هواشناسی بی‌درنگ برای هر مکان با استفاده از WeatherAPI.com API، که پیش‌بینی‌های دقیق و شرایط فعلی را فراهم می‌کند.
- [ip2location/mcp-ip2location-io](https://github.com/ip2location/mcp-ip2location-io) 🐍 ☁️  - سرور MCP رسمی IP2Location.io برای به دست آوردن موقعیت جغرافیایی، پراکسی و اطلاعات شبکه یک آدرس IP با استفاده از IP2Location.io API.
- [isdaniel/mcp_weather_server](https://github.com/isdaniel/mcp_weather_server) 🐍 ☁️ - دریافت اطلاعات هواشناسی از https://api.open-meteo.com API.
- [ipfind/ipfind-mcp-server](https://github.com/ipfind/ipfind-mcp-server) 🐍 ☁️ - سرویس مکان آدرس IP با استفاده از [IP Find](https://ipfind.com) API
- [ipfred/aiwen-mcp-server-geoip](https://github.com/ipfred/aiwen-mcp-server-geoip) 🐍 📇 ☁️ – سرور MCP برای Aiwen IP Location، دریافت مکان IP شبکه کاربر، دریافت جزئیات IP (کشور، استان، شهر، lat، lon، ISP، مالک و غیره)
- [iplocate/mcp-server-iplocate](https://github.com/iplocate/mcp-server-iplocate) 🎖️ 📇 🏠  - جستجوی موقعیت جغرافیایی آدرس IP، اطلاعات شبکه، شناسایی پراکسی‌ها و VPNها و یافتن جزئیات تماس برای سوءاستفاده با استفاده از IPLocate.io
- [jagan-shanmugam/open-streetmap-mcp](https://github.com/jagan-shanmugam/open-streetmap-mcp) 🐍 🏠 - یک سرور MCP OpenStreetMap با خدمات مبتنی بر مکان و داده‌های مکانی.
- [kukapay/nearby-search-mcp](https://github.com/kukapay/nearby-search-mcp) 🐍 ☁️ - یک سرور MCP برای جستجوی مکان‌های نزدیک با تشخیص مکان مبتنی بر IP.
- [mahdin75/geoserver-mcp](https://github.com/mahdin75/geoserver-mcp) 🏠 – یک پیاده‌سازی سرور Model Context Protocol (MCP) که LLMها را به GeoServer REST API متصل می‌کند و به دستیاران هوش مصنوعی امکان تعامل با داده‌ها و خدمات مکانی را می‌دهد.
- [mahdin75/gis-mcp](https://github.com/mahdin75/gis-mcp) 🏠 – یک پیاده‌سازی سرور Model Context Protocol (MCP) که مدل‌های زبان بزرگ (LLMها) را با استفاده از کتابخانه‌های GIS به عملیات GIS متصل می‌کند و به دستیاران هوش مصنوعی امکان انجام عملیات و تبدیلات مکانی دقیق را می‌دهد.
- [modelcontextprotocol/server-google-maps](https://github.com/modelcontextprotocol/servers-archived/tree/main/src/google-maps) 📇 ☁️ - یکپارچه‌سازی با Google Maps برای خدمات مکان، مسیریابی و جزئیات مکان
- [QGIS MCP](https://github.com/jjsantos01/qgis_mcp) - QGIS Desktop را از طریق MCP به Claude AI متصل می‌کند. این یکپارچه‌سازی ایجاد پروژه، بارگذاری لایه، اجرای کد و موارد دیگر را با کمک پرامپت امکان‌پذیر می‌کند.
- [rossshannon/Weekly-Weather-mcp](https://github.com/rossshannon/weekly-weather-mcp.git) 🐍 ☁️ - سرور MCP Weekly Weather که پیش‌بینی‌های هواشناسی دقیق ۷ روز کامل را در هر کجای جهان برمی‌گرداند.
- [SaintDoresh/Weather-MCP-ClaudeDesktop](https://github.com/SaintDoresh/Weather-MCP-ClaudeDesktop.git) 🐍 ☁️ - یک ابزار MCP که داده‌های هواشناسی بی‌درنگ، پیش‌بینی‌ها و اطلاعات تاریخی هواشناسی را با استفاده از OpenWeatherMap API فراهم می‌کند.
- [SecretiveShell/MCP-timeserver](https://github.com/SecretiveShell/MCP-timeserver) 🐍 🏠 - دسترسی به زمان در هر منطقه زمانی و دریافت زمان محلی فعلی
- [stadiamaps/stadiamaps-mcp-server-ts](https://github.com/stadiamaps/stadiamaps-mcp-server-ts) 📇 ☁️ - یک سرور MCP برای APIهای مکان Stadia Maps - جستجوی آدرس‌ها، مکان‌ها با geocoding، یافتن مناطق زمانی، ایجاد مسیرها و نقشه‌های استاتیک
- [TimLukaHorstmann/mcp-weather](https://github.com/TimLukaHorstmann/mcp-weather) 📇 ☁️  - پیش‌بینی‌های دقیق هواشناسی از طریق AccuWeather API (سطح رایگان در دسترس است).
- [trackmage/trackmage-mcp-server](https://github.com/trackmage/trackmage-mcp-server) 📇 - API ردیابی محموله و قابلیت‌های مدیریت لجستیک از طریق [TrackMage API] (https://trackmage.com/)
- [webcoderz/MCP-Geo](https://github.com/webcoderz/MCP-Geo) 🐍 🏠 - سرور MCP Geocoding برای nominatim، ArcGIS، Bing

### 🎯 <a name="marketing"></a>بازاریابی

ابزارهایی برای ایجاد و ویرایش محتوای بازاریابی، کار با متادیتا وب، موقعیت‌یابی محصول و راهنماهای ویرایش.

- [gomarble-ai/facebook-ads-mcp-server](https://github.com/gomarble-ai/facebook-ads-mcp-server) 🐍 ☁️ - سرور MCP که به عنوان یک رابط برای Facebook Ads عمل می‌کند و دسترسی برنامه‌ریزی شده به داده‌ها و ویژگی‌های مدیریت Facebook Ads را امکان‌پذیر می‌کند.
- [gomarble-ai/google-ads-mcp-server](https://github.com/gomarble-ai/google-ads-mcp-server) 🐍 ☁️ - سرور MCP که به عنوان یک رابط برای Google Ads عمل می‌کند و دسترسی برنامه‌ریزی شده به داده‌ها و ویژگی‌های مدیریت Google Ads را امکان‌پذیر می‌کند.
- [marketplaceadpros/amazon-ads-mcp-server](https://github.com/MarketplaceAdPros/amazon-ads-mcp-server) 📇 ☁️  - به ابزارها امکان تعامل با Amazon Advertising، تحلیل معیارهای کمپین و پیکربندی‌ها را می‌دهد.
- [open-strategy-partners/osp_marketing_tools](https://github.com/open-strategy-partners/osp_marketing_tools) 🐍 🏠 - مجموعه‌ای از ابزارهای بازاریابی از Open Strategy Partners شامل سبک نگارش، کدهای ویرایش و ایجاد نقشه ارزش بازاریابی محصول.
- [pipeboard-co/meta-ads-mcp](https://github.com/pipeboard-co/meta-ads-mcp) 🐍 ☁️ 🏠 - اتوماسیون Meta Ads که فقط کار می‌کند. مورد اعتماد بیش از ۱۰۰۰۰ کسب و کار برای تحلیل عملکرد، تست خلاقیت‌ها، بهینه‌سازی هزینه‌ها و مقیاس‌بندی نتایج — به سادگی و با اطمینان.
- [stape-io/stape-mcp-server](https://github.com/stape-io/stape-mcp-server) 📇 ☁️ – این پروژه یک سرور MCP (Model Context Protocol) برای پلتفرم Stape پیاده‌سازی می‌کند. این سرور امکان تعامل با Stape API را با استفاده از دستیاران هوش مصنوعی مانند Claude یا IDEهای مبتنی بر هوش مصنوعی مانند Cursor فراهم می‌کند.
- [stape-io/google-tag-manager-mcp-server](https://github.com/stape-io/google-tag-manager-mcp-server) 📇 ☁️ – این سرور از اتصالات MCP راه دور پشتیبانی می‌کند، شامل Google OAuth داخلی است و یک رابط به Google Tag Manager API فراهم می‌کند.


### 📊 <a name="monitoring"></a>نظارت

دسترسی و تحلیل داده‌های نظارت بر برنامه. به مدل‌های هوش مصنوعی امکان بررسی گزارش‌های خطا و معیارهای عملکرد را می‌دهد.

- [edgedelta/edgedelta-mcp-server](https://github.com/edgedelta/edgedelta-mcp-server) 🎖️ 🏎️ ☁️ – با ناهنجاری‌های Edge Delta تعامل داشته باشید، لاگ‌ها / الگوها / رویدادها را کوئری کنید و علل ریشه‌ای را شناسایی و pipelineهای خود را بهینه کنید.
- [grafana/mcp-grafana](https://github.com/grafana/mcp-grafana) 🎖️ 🐍 🏠 ☁️ - جستجوی داشبوردها، بررسی حوادث و کوئری منابع داده در نمونه Grafana شما
- [hyperb1iss/lucidity-mcp](https://github.com/hyperb1iss/lucidity-mcp) 🐍 🏠 - کیفیت کد تولید شده توسط هوش مصنوعی را از طریق تحلیل هوشمند و مبتنی بر پرامپت در ۱۰ بعد حیاتی از پیچیدگی تا آسیب‌پذیری‌های امنیتی افزایش دهید
- [inventer-dev/mcp-internet-speed-test](https://github.com/inventer-dev/mcp-internet-speed-test) 🐍 ☁️ - تست سرعت اینترنت با معیارهای عملکرد شبکه شامل سرعت دانلود/آپلود، تأخیر، تحلیل jitter و تشخیص سرور CDN با نقشه‌برداری جغرافیایی
- [last9/last9-mcp-server](https://github.com/last9/last9-mcp-server) - زمینه تولید بی‌درنگ—لاگ‌ها، معیارها و traceها—را به طور یکپارچه به محیط محلی خود بیاورید تا کد را سریع‌تر خودکار-رفع کنید
- [metoro-io/metoro-mcp-server](https://github.com/metoro-io/metoro-mcp-server) 🎖️ 🏎️ ☁️ - کوئری و تعامل با محیط‌های kubernetes که توسط Metoro نظارت می‌شوند
- [MindscapeHQ/server-raygun](https://github.com/MindscapeHQ/mcp-server-raygun) 📇 ☁️ - یکپارچه‌سازی با Raygun API V3 برای گزارش‌دهی crash و نظارت بر کاربر واقعی
- [getsentry/sentry-mcp](https://github.com/getsentry/sentry-mcp) 🐍 ☁️ - یکپارچه‌سازی با Sentry.io برای ردیابی خطا و نظارت بر عملکرد
- [mpeirone/zabbix-mcp-server](https://github.com/mpeirone/zabbix-mcp-server) 🐍 ☁️ 🐧 🪟 🍎 - یکپارچه‌سازی با Zabbix برای میزبان‌ها، آیتم‌ها، تریگرها، قالب‌ها، مشکلات، داده‌ها و موارد دیگر.
- [netdata/netdata#Netdata](https://github.com/netdata/netdata/blob/master/src/web/mcp/README.md) 🎖️ 🏠 ☁️ 📟 🍎 🪟 🐧 - کشف، کاوش، گزارش‌دهی و تحلیل علت ریشه‌ای با استفاده از تمام داده‌های قابلیت مشاهده، شامل معیارها، لاگ‌ها، سیستم‌ها، کانتینرها، فرآیندها و اتصالات شبکه
- [pydantic/logfire-mcp](https://github.com/pydantic/logfire-mcp) 🎖️ 🐍 ☁️ - دسترسی به traceها و معیارهای OpenTelemetry را از طریق Logfire فراهم می‌کند
- [seekrays/mcp-monitor](https://github.com/seekrays/mcp-monitor) 🏎️ 🏠 - یک ابزار نظارت بر سیستم که معیارهای سیستم را از طریق Model Context Protocol (MCP) در معرض دید قرار می‌دهد. این ابزار به LLMها اجازه می‌دهد اطلاعات سیستم را به صورت بی‌درنگ از طریق یک رابط سازگار با MCP بازیابی کنند. (پشتیبانی از CPU، حافظه، دیسک، شبکه، میزبان، فرآیند)
- [tumf/grafana-loki-mcp](https://github.com/tumf/grafana-loki-mcp) 🐍 🏠 - یک سرور MCP که امکان کوئری لاگ‌های Loki را از طریق Grafana API می‌دهد.
- [VictoriaMetrics-Community/mcp-victoriametrics](https://github.com/VictoriaMetrics-Community/mcp-victoriametrics) 🎖️ 🏎️ 🏠 - یکپارچه‌سازی جامع با [APIهای نمونه VictoriaMetrics](https://docs.victoriametrics.com/victoriametrics/url-examples/) و [مستندات](https://docs.victoriametrics.com/) شما برای نظارت، قابلیت مشاهده و وظایف اشکال‌زدایی مرتبط با نمونه‌های VictoriaMetrics شما را فراهم می‌کند
- [imprvhub/mcp-status-observer](https://github.com/imprvhub/mcp-status-observer) 📇 ☁️ - سرور Model Context Protocol برای نظارت بر وضعیت عملیاتی پلتفرم‌های دیجیتال بزرگ در Claude Desktop.
- [inspektor-gadget/ig-mcp-server](https://github.com/inspektor-gadget/ig-mcp-server) 🏎️ ☁️ 🏠 🐧 🪟 🍎 - بارهای کاری Container و Kubernetes خود را با یک رابط هوش مصنوعی مبتنی بر eBPF اشکال‌زدایی کنید.
- [yshngg/pmcp](https://github.com/yshngg/pmcp) 🏎️ ☁️ 🏠 🍎 🪟 🐧 - یک سرور Prometheus Model Context Protocol.

### 🎥 <a name="multimedia-process"></a>پردازش چندرسانه‌ای

قابلیت مدیریت چندرسانه‌ای مانند ویرایش صدا و ویدیو، پخش، تبدیل فرمت را فراهم می‌کند، همچنین شامل فیلترهای ویدیویی، بهبودها و غیره می‌شود

- [ananddtyagi/gif-creator-mcp](https://github.com/ananddtyagi/gif-creator-mcp/tree/main) 📇 🏠 - یک سرور MCP برای ایجاد GIF از ویدیوهای شما.
- [bogdan01m/zapcap-mcp-server](https://github.com/bogdan01m/zapcap-mcp-server) 🐍 ☁️ - سرور MCP برای ZapCap API که تولید زیرنویس ویدیو و B-roll را از طریق زبان طبیعی فراهم می‌کند
- [stass/exif-mcp](https://github.com/stass/exif-mcp) 📇 🏠 🐧 🍎 🪟 - یک سرور MCP که به فرد امکان می‌دهد متادیتای تصویر مانند EXIF، XMP، JFIF و GPS را بررسی کند. این پایه و اساس را برای جستجو و تحلیل کتابخانه‌های عکس و مجموعه‌های تصویر مبتنی بر LLM فراهم می‌کند.
- [Tommertom/sonos-ts-mcp](https://github.com/Tommertom/sonos-ts-mcp) 📇 🏠 🍎 🪟 🐧 - کنترل جامع سیستم صوتی Sonos از طریق پیاده‌سازی خالص TypeScript. دارای کشف کامل دستگاه، مدیریت پخش چند-اتاقه، کنترل صف، مرور کتابخانه موسیقی، مدیریت آلارم، اشتراک رویداد بی‌درنگ و تنظیمات EQ صوتی است. شامل بیش از ۵۰ ابزار برای اتوماسیون یکپارچه صوتی خانه هوشمند از طریق پروتکل‌های UPnP/SOAP است.
- [sunriseapps/imagesorcery-mcp](https://github.com/sunriseapps/imagesorcery-mcp) 🐍 🏠 🐧 🍎 🪟 - جادوی 🪄 مبتنی بر ComputerVision از ابزارهای تشخیص و ویرایش تصویر برای دستیاران هوش مصنوعی.
- [video-creator/ffmpeg-mcp](https://github.com/video-creator/ffmpeg-mcp.git) 🎥 🔊 - استفاده از خط فرمان ffmpeg برای دستیابی به یک سرور mcp، می‌تواند بسیار راحت باشد، از طریق گفتگو برای دستیابی به جستجوی ویدیوی محلی، برش، چسباندن، پخش و سایر توابع

### 🔎 <a name="RAG"></a>پلتفرم‌های RAG سرتاسری

- [vectara/vectara-mcp](https://github.com/vectara/vectara-mcp) 🐍 🏠 ☁️ - یک سرور MCP برای دسترسی به پلتفرم RAG-as-a-service مورد اعتماد Vectara.

### 🔎 <a name="search"></a>جستجو و استخراج داده

- [0xdaef0f/job-searchoor](https://github.com/0xDAEF0F/job-searchoor) 📇 🏠 - یک سرور MCP برای جستجوی آگهی‌های شغلی با فیلترهایی برای تاریخ، کلمات کلیدی، گزینه‌های کار از راه دور و موارد دیگر.
- [Aas-ee/open-webSearch](https://github.com/Aas-ee/open-webSearch) 🐍 📇 ☁️ - جستجوی وب با استفاده از جستجوی چند-موتوره رایگان (بدون نیاز به کلید API) — از Bing، Baidu، DuckDuckGo، Brave، Exa و CSDN پشتیبانی می‌کند.
- [ac3xx/mcp-servers-kagi](https://github.com/ac3xx/mcp-servers-kagi) 📇 ☁️ - یکپارچه‌سازی با Kagi search API
- [adawalli/nexus](https://github.com/adawalli/nexus) 📇 ☁️ - سرور جستجوی وب مبتنی بر هوش مصنوعی با استفاده از مدل‌های Perplexity Sonar با استناد به منابع. راه‌اندازی بدون نصب از طریق NPX.
- [ananddtyagi/webpage-screenshot-mcp](https://github.com/ananddtyagi/webpage-screenshot-mcp) 📇 🏠 - یک سرور MCP برای گرفتن اسکرین‌شات از صفحات وب برای استفاده به عنوان بازخورد در طول توسعه UI.
- [urlbox/urlbox-mcp-server](https://github.com/urlbox/urlbox-mcp-server/) - 📇 🏠 یک سرور MCP قابل اعتماد برای تولید و مدیریت اسکرین‌شات‌ها، PDFها و ویدیوها، انجام تحلیل اسکرین‌شات مبتنی بر هوش مصنوعی و استخراج محتوای وب (Markdown، متادیتا و HTML) از طریق [Urlbox](https://urlbox.com) API.
- [andybrandt/mcp-simple-arxiv](https://github.com/andybrandt/mcp-simple-arxiv) - 🐍 ☁️  MCP برای LLM برای جستجو و خواندن مقالات از arXiv
- [andybrandt/mcp-simple-pubmed](https://github.com/andybrandt/mcp-simple-pubmed) - 🐍 ☁️  MCP برای جستجو و خواندن مقالات پزشکی / علوم زیستی از PubMed.
- [angheljf/nyt](https://github.com/angheljf/nyt) 📇 ☁️ - جستجوی مقالات با استفاده از NYTimes API
- [apify/mcp-server-rag-web-browser](https://github.com/apify/mcp-server-rag-web-browser) 📇 ☁️ - یک سرور MCP برای RAG Web Browser Actor منبع باز Apify برای انجام جستجوهای وب، استخراج URLها و برگرداندن محتوا در Markdown.
- [Bigsy/Clojars-MCP-Server](https://github.com/Bigsy/Clojars-MCP-Server) 📇 ☁️ - سرور MCP Clojars برای اطلاعات به‌روز وابستگی کتابخانه‌های Clojure
- [blazickjp/arxiv-mcp-server](https://github.com/blazickjp/arxiv-mcp-server) ☁️ 🐍 - جستجوی مقالات تحقیقاتی ArXiv
- [chanmeng/google-news-mcp-server](https://github.com/ChanMeng666/server-google-news) 📇 ☁️ - یکپارچه‌سازی با Google News با دسته‌بندی خودکار موضوعات، پشتیبانی از چند زبان و قابلیت‌های جستجوی جامع شامل عناوین، داستان‌ها و موضوعات مرتبط از طریق [SerpAPI](https://serpapi.com/).
- [cameronrye/gopher-mcp](https://github.com/cameronrye/gopher-mcp) 🐍 🏠 - سرور MCP مدرن و چند پلتفرمی که به دستیاران هوش مصنوعی امکان مرور و تعامل با منابع پروتکل Gopher و Gemini را به صورت ایمن و کارآمد می‌دهد. دارای پشتیبانی از پروتکل دوگانه، امنیت TLS و استخراج محتوای ساختاریافته است.
- [ConechoAI/openai-websearch-mcp](https://github.com/ConechoAI/openai-websearch-mcp/) 🐍 🏠 ☁️ - این یک سرور MCP مبتنی بر Python است که ابزار داخلی `web_search` OpenAI را فراهم می‌کند.
- [DappierAI/dappier-mcp](https://github.com/DappierAI/dappier-mcp) 🐍 ☁️ - جستجوی وب بی‌درنگ سریع و رایگان و دسترسی به داده‌های برتر از برندهای رسانه‌ای معتبر—اخبار، بازارهای مالی، ورزش، سرگرمی، هواشناسی و موارد دیگر را فعال کنید. عامل‌های هوش مصنوعی قدرتمند با Dappier بسازید.
- [deadletterq/mcp-opennutrition](https://github.com/deadletterq/mcp-opennutrition) 📇 🏠 - سرور MCP محلی برای جستجوی بیش از ۳۰۰,۰۰۰ غذا، اطلاعات تغذیه‌ای و بارکد از پایگاه داده OpenNutrition.
- [dealx/mcp-server](https://github.com/DealExpress/mcp-server) ☁️ - سرور MCP برای پلتفرم DealX
- [devflowinc/trieve](https://github.com/devflowinc/trieve/tree/main/clients/mcp-server) 🎖️ 📇 ☁️ 🏠 - خزیدن، embedding، chunk کردن، جستجو و بازیابی اطلاعات از مجموعه داده‌ها از طریق [Trieve](https://trieve.ai)
- [Dumpling-AI/mcp-server-dumplingai](https://github.com/Dumpling-AI/mcp-server-dumplingai) 🎖️ 📇 ☁️ - دسترسی به داده‌ها، استخراج وب و APIهای تبدیل اسناد توسط [Dumpling AI](https://www.dumplingai.com/)
- [emicklei/melrose-mcp](https://github.com/emicklei/melrose-mcp) 🏎️ 🏠 - عبارات موسیقی [Melrōse](https://melrōse.org) را به عنوان MIDI پخش می‌کند
- [erithwik/mcp-hn](https://github.com/erithwik/mcp-hn) 🐍 ☁️ - یک سرور MCP برای جستجوی Hacker News، دریافت داستان‌های برتر و موارد دیگر.
- [exa-labs/exa-mcp-server](https://github.com/exa-labs/exa-mcp-server) 🎖️ 📇 ☁️ – یک سرور Model Context Protocol (MCP) که به دستیاران هوش مصنوعی مانند Claude اجازه می‌دهد از Exa AI Search API برای جستجوهای وب استفاده کنند. این راه‌اندازی به مدل‌های هوش مصنوعی امکان می‌دهد اطلاعات وب بی‌درنگ را به روشی امن و کنترل شده دریافت کنند.
- [fatwang2/search1api-mcp](https://github.com/fatwang2/search1api-mcp) 📇 ☁️ - جستجو از طریق search1api (نیاز به کلید API پولی دارد)
- [format37/youtube_mcp](https://github.com/format37/youtube_mcp) 🐍 ☁️ – سرور MCP که ویدیوهای YouTube را به متن رونویسی می‌کند. از yt-dlp برای دانلود صدا و Whisper-1 OpenAI برای رونویسی دقیق‌تر از زیرنویس‌های youtube استفاده می‌کند. یک URL YouTube ارائه دهید و رونوشت کامل را که برای ویدیوهای طولانی به تکه‌ها تقسیم شده است، دریافت کنید.
- [genomoncology/biomcp](https://github.com/genomoncology/biomcp) 🐍 ☁️ - سرور تحقیقات زیست‌پزشکی که دسترسی به PubMed، ClinicalTrials.gov و MyVariant.info را فراهم می‌کند.
- [hbg/mcp-paperswithcode](https://github.com/hbg/mcp-paperswithcode) - 🐍 ☁️ MCP برای جستجو از طریق PapersWithCode API
- [hellokaton/unsplash-mcp-server](https://github.com/hellokaton/unsplash-mcp-server)) 🐍 ☁️ - یک سرور MCP برای جستجوی تصویر Unsplash.
- [Himalayas-App/himalayas-mcp](https://github.com/Himalayas-App/himalayas-mcp) 📇 ☁️ - به ده‌ها هزار آگهی شغلی از راه دور و اطلاعات شرکت دسترسی پیدا کنید. این سرور MCP عمومی دسترسی بی‌درنگ به پایگاه داده مشاغل از راه دور Himalayas را فراهم می‌کند.
- [Ihor-Sokoliuk/MCP-SearXNG](https://github.com/ihor-sokoliuk/mcp-searxng) 📇 🏠/☁️ - یک سرور Model Context Protocol برای [SearXNG](https://docs.searxng.org)
- [isnow890/naver-search-mcp](https://github.com/isnow890/naver-search-mcp) 📇 ☁️ - سرور MCP برای یکپارچه‌سازی با Naver Search API، که از جستجوی وبلاگ، اخبار، خرید و ویژگی‌های تحلیلی DataLab پشتیبانی می‌کند.
- [jae-jae/fetcher-mcp](https://github.com/jae-jae/fetcher-mcp) 📇 🏠 - سرور MCP برای دریافت محتوای صفحه وب با استفاده از مرورگر headless Playwright، که از رندر Javascript و استخراج هوشمند محتوا پشتیبانی می‌کند و خروجی Markdown یا HTML را ارائه می‌دهد.
- [jae-jae/g-search-mcp](https://github.com/jae-jae/g-search-mcp) 📇 🏠 - یک سرور MCP قدرتمند برای جستجوی Google که جستجوی موازی با چندین کلمه کلیدی را به طور همزمان امکان‌پذیر می‌کند.
- [joelio/stocky](https://github.com/joelio/stocky) 🐍 ☁️ 🏠 - یک سرور MCP برای جستجو و دانلود عکس‌های استوک بدون حق امتیاز از Pexels و Unsplash. دارای جستجوی چند-ارائه‌دهنده، متادیتای غنی، پشتیبانی از صفحه‌بندی و عملکرد async برای دستیاران هوش مصنوعی برای یافتن و دسترسی به تصاویر با کیفیت بالا.
- [just-every/mcp-read-website-fast](https://github.com/just-every/mcp-read-website-fast) 📇 🏠 - استخراج سریع و بهینه از نظر توکن محتوای وب برای عامل‌های هوش مصنوعی - وب‌سایت‌ها را به Markdown تمیز تبدیل می‌کند در حالی که لینک‌ها را حفظ می‌کند. دارای Mozilla Readability، کشینگ هوشمند، خزش مودبانه با پشتیبانی از robots.txt و دریافت همزمان است.
- [just-every/mcp-screenshot-website-fast](https://github.com/just-every/mcp-screenshot-website-fast) 📇 🏠 - ابزار گرفتن اسکرین‌شات سریع بهینه‌سازی شده برای Claude Vision API. به طور خودکار صفحات کامل را به تکه‌های 1072x1072 برای پردازش بهینه هوش مصنوعی با viewportهای قابل تنظیم و استراتژی‌های انتظار برای محتوای پویا تقسیم می‌کند.
- [kagisearch/kagimcp](https://github.com/kagisearch/kagimcp) ☁️ 📇 – سرور MCP رسمی Kagi Search
- [kehvinbehvin/json-mcp-filter](https://github.com/kehvinbehvin/json-mcp-filter) ️🏠 📇 – از پر کردن زمینه LLM خود دست بردارید. فقط آنچه را که از فایل‌های JSON خود نیاز دارید، کوئری و استخراج کنید.
- [Crawleo/Crawleo-MCP](https://github.com/Crawleo/Crawleo-MCP) ☁️ 🐍 – Crawleo Search & Crawl API
- [kshern/mcp-tavily](https://github.com/kshern/mcp-tavily.git) ☁️ 📇 – Tavily AI search API
- [leehanchung/bing-search-mcp](https://github.com/leehanchung/bing-search-mcp) 📇 ☁️ - قابلیت‌های جستجوی وب با استفاده از Microsoft Bing Search API
- [lfnovo/content-core](https://github.com/lfnovo/content-core) 🐍 🏠 - استخراج محتوا از URLها، اسناد، ویدیوها و فایل‌های صوتی با استفاده از انتخاب خودکار هوشمند موتور. از صفحات وب، PDFها، اسناد Word، رونوشت‌های YouTube و موارد دیگر با پاسخ‌های JSON ساختاریافته پشتیبانی می‌کند.
- [Linked-API/linkedapi-mcp](https://github.com/Linked-API/linkedapi-mcp) 🎖️ 📇 ☁️ - سرور MCP که به دستیاران هوش مصنوعی اجازه می‌دهد حساب‌های LinkedIn را کنترل کنند و داده‌های بی‌درنگ را بازیابی کنند.
- [luminati-io/brightdata-mcp](https://github.com/luminati-io/brightdata-mcp) 📇 ☁️ - کشف، استخراج و تعامل با وب - یک رابط که دسترسی خودکار را در سراسر اینترنت عمومی قدرت می‌بخشد.
- [mikechao/brave-search-mcp](https://github.com/mikechao/brave-search-mcp) 📇 ☁️ - قابلیت‌های جستجوی وب، تصویر، اخبار، ویدیو و نقاط مورد علاقه محلی با استفاده از Brave's Search API
- [brave/brave-search-mcp-server](https://github.com/brave/brave-search-mcp-server) 📇 ☁️ - قابلیت‌های جستجوی وب با استفاده از Brave's Search API
- [modelcontextprotocol/server-fetch](https://github.com/modelcontextprotocol/servers/tree/main/src/fetch) 🐍 🏠 ☁️ - دریافت و پردازش کارآمد محتوای وب برای مصرف هوش مصنوعی
- [mzxrai/mcp-webresearch](https://github.com/mzxrai/mcp-webresearch) 🔍 📚 - جستجوی Google و انجام تحقیقات عمیق وب در مورد هر موضوعی
- [nickclyde/duckduckgo-mcp-server](https://github.com/nickclyde/duckduckgo-mcp-server) 🐍 ☁️ - جستجوی وب با استفاده از DuckDuckGo
- [nkapila6/mcp-local-rag](https://github.com/nkapila6/mcp-local-rag) 🏠 🐍 - سرور model context protocol (MCP) جستجوی وب شبیه RAG "ابتدایی" که به صورت محلی اجرا می‌شود. نیازی به API نیست.
- [nyxn-ai/NyxDocs](https://github.com/nyxn-ai/NyxDocs) 🐍 ☁️ 🏠 - سرور MCP تخصصی برای مدیریت مستندات پروژه ارزهای دیجیتال با پشتیبانی از چند بلاکچین (Ethereum، BSC، Polygon، Solana).
- [OctagonAI/octagon-deep-research-mcp](https://github.com/OctagonAI/octagon-deep-research-mcp) 🎖️ 📇 ☁️ 🏠 - عامل تحقیق عمیق با سرعت بالا و دقت بالا
- [parallel-web/search-mcp](https://github.com/parallel-web/search-mcp) ☁️ 🔎 - جستجوی وب با بالاترین دقت برای هوش مصنوعی
- [parallel-web/task-mcp](https://github.com/parallel-web/task-mcp) ☁️ 🔎 - تحقیق عمیق و وظایف دسته‌ای MCP با بالاترین دقت
- [pragmar/mcp-server-webcrawl](https://github.com/pragmar/mcp-server-webcrawl) 🐍 🏠 - جستجو و بازیابی پیشرفته برای داده‌های خزشگر وب. از خزشگرهای WARC، wget، Katana، SiteOne و InterroBot پشتیبانی می‌کند.
- [QuentinCody/catalysishub-mcp-server](https://github.com/QuentinCody/catalysishub-mcp-server) 🐍 - سرور MCP غیر رسمی برای جستجو و بازیابی داده‌های علمی از پایگاه داده Catalysis Hub، که دسترسی به تحقیقات کاتالیز محاسباتی و داده‌های واکنش سطحی را فراهم می‌کند.
- [r-huijts/opentk-mcp](https://github.com/r-huijts/opentk-mcp) 📇 ☁️ - دسترسی به اطلاعات پارلمان هلند (Tweede Kamer) شامل اسناد، مناظرات، فعالیت‌ها و موارد قانونی از طریق قابلیت‌های جستجوی ساختاریافته (بر اساس پروژه opentk توسط Bert Hubert)
- [reading-plus-ai/mcp-server-deep-research](https://github.com/reading-plus-ai/mcp-server-deep-research) 📇 ☁️ - سرور MCP که تحقیق عمیق خودکار شبیه OpenAI/Perplexity، تشریح کوئری ساختاریافته و گزارش‌دهی مختصر را فراهم می‌کند.
- [ricocf/mcp-wolframalpha](https://github.com/ricocf/mcp-wolframalpha) 🐍 🏠 ☁️ - یک سرور MCP که به دستیاران هوش مصنوعی اجازه می‌دهد از Wolfram Alpha API برای دسترسی بی‌درنگ به دانش و داده‌های محاسباتی استفاده کنند.
- [sascharo/gxtract](https://github.com/sascharo/gxtract) 🐍 ☁️ 🪟 🐧 🍎 - GXtract یک سرور MCP است که برای یکپارچه‌سازی با VS Code و سایر ویرایشگرهای سازگار طراحی شده است (مستندات: [sascharo.github.io/gxtract](https://sascharo.github.io/gxtract)). این سرور مجموعه‌ای از ابزارها را برای تعامل با پلتفرم GroundX فراهم می‌کند و به شما امکان می‌دهد از قابلیت‌های قدرتمند درک اسناد آن مستقیماً در محیط توسعه خود استفاده کنید.
- [scrapeless-ai/scrapeless-mcp-server](https://github.com/scrapeless-ai/scrapeless-mcp-server) 🐍 ☁️ - سرویس Scrapeless Model Context Protocol به عنوان یک اتصال‌دهنده سرور MCP به Google SERP API عمل می‌کند و جستجوی وب را در اکوسیستم MCP بدون خروج از آن امکان‌پذیر می‌کند.
- [searchcraft-inc/searchcraft-mcp-server](https://github.com/searchcraft-inc/searchcraft-mcp-server) 🎖️ 📇 ☁️ - سرور MCP رسمی برای مدیریت کلاسترهای Searchcraft، ایجاد یک شاخص جستجو، تولید یک شاخص به صورت پویا با توجه به یک فایل داده و برای وارد کردن آسان داده‌ها به یک شاخص جستجو با توجه به یک فید یا فایل json محلی.
- [SecretiveShell/MCP-searxng](https://github.com/SecretiveShell/MCP-searxng) 🐍 🏠 - یک سرور MCP برای اتصال به نمونه‌های searXNG
- [serkan-ozal/driflyte-mcp-server](https://github.com/serkan-ozal/driflyte-mcp-server) 🎖️ 📇 ☁️ 🏠 - سرور Driflyte MCP ابزارهایی را در معرض دید قرار می‌دهد که به دستیاران هوش مصنوعی امکان کوئری و بازیابی دانش خاص موضوع را از صفحات وب خزیده و نمایه‌سازی شده به صورت بازگشتی می‌دهد.
- [shopsavvy/shopsavvy-mcp-server](https://github.com/shopsavvy/shopsavvy-mcp-server) 🎖️ 📇 ☁️ - راه حل کامل داده‌های محصول و قیمت‌گذاری برای دستیاران هوش مصنوعی. جستجوی محصولات بر اساس بارکد/ASIN/URL، دسترسی به متادیتای دقیق محصول، دسترسی به داده‌های جامع قیمت‌گذاری از هزاران خرده‌فروش، مشاهده و ردیابی تاریخچه قیمت و موارد دیگر.
- [takashiishida/arxiv-latex-mcp](https://github.com/takashiishida/arxiv-latex-mcp) 🐍 ☁️ - دریافت منبع LaTeX مقالات arXiv برای مدیریت محتوای ریاضی و معادلات
- [the0807/GeekNews-MCP-Server](https://github.com/the0807/GeekNews-MCP-Server) 🐍 ☁️ - یک سرور MCP که داده‌های خبری را از سایت GeekNews بازیابی و پردازش می‌کند.
- [tianqitang1/enrichr-mcp-server](https://github.com/tianqitang1/enrichr-mcp-server) 📇 ☁️ - یک سرور MCP که تحلیل غنی‌سازی مجموعه ژن را با استفاده از Enrichr API فراهم می‌کند
- [tinyfish-io/agentql-mcp](https://github.com/tinyfish-io/agentql-mcp) 🎖️ 📇 ☁️ - سرور MCP که قابلیت‌های استخراج داده [AgentQL](https://agentql.com) را فراهم می‌کند.
- [Tomatio13/mcp-server-tavily](https://github.com/Tomatio13/mcp-server-tavily) ☁️ 🐍 – Tavily AI search API
- [vectorize-io/vectorize-mcp-server](https://github.com/vectorize-io/vectorize-mcp-server/) ☁️ 📇 - سرور MCP [Vectorize](https://vectorize.io) برای بازیابی پیشرفته، تحقیق عمیق خصوصی، استخراج فایل Anything-to-Markdown و chunk کردن متن.
- [vitorpavinato/ncbi-mcp-server](https://github.com/vitorpavinato/ncbi-mcp-server) 🐍 ☁️ 🏠 - سرور جامع جستجوی ادبیات NCBI/PubMed با تحلیل‌های پیشرفته، کشینگ، یکپارچه‌سازی با MeSH، کشف مقالات مرتبط و پردازش دسته‌ای برای تمام علوم زیستی و تحقیقات زیست‌پزشکی.
- [kimdonghwi94/Web-Analyzer-MCP](https://github.com/kimdonghwi94/web-analyzer-mcp) 🐍 🏠 🍎 🪟 🐧 - محتوای وب تمیز را برای RAG استخراج می‌کند و پرسش و پاسخ در مورد صفحات وب را فراهم می‌کند.
- [webscraping-ai/webscraping-ai-mcp-server](https://github.com/webscraping-ai/webscraping-ai-mcp-server) 🎖️ 📇 ☁️ - با [WebScraping.ai](https://webscraping.ai) برای استخراج و خراشیدن داده‌های وب تعامل داشته باشید.
- [yamanoku/baseline-mcp-server](https://github.com/yamanoku/baseline-mcp-server) 📇 🏠 - سرور MCP که وضعیت Baseline را با استفاده از Web Platform API جستجو می‌کند
- [zhsama/duckduckgo-mcp-server](https://github.com/zhsama/duckduckgo-mpc-server/) 📇 🏠 ☁️ - این یک سرور MCP مبتنی بر TypeScript است که عملکرد جستجوی DuckDuckGo را فراهم می‌کند.
- [zoomeye-ai/mcp_zoomeye](https://github.com/zoomeye-ai/mcp_zoomeye) 📇 ☁️ - کوئری اطلاعات دارایی شبکه توسط سرور MCP ZoomEye
- [Pearch-ai/mcp_pearch](https://github.com/Pearch-ai/mcp_pearch) 🎖️ 🐍 ☁️ - بهترین موتور جستجوی افراد که زمان صرف شده برای کشف استعداد را کاهش می‌دهد
- [imprvhub/mcp-domain-availability](https://github.com/imprvhub/mcp-domain-availability) 🐍 ☁️ - یک سرور Model Context Protocol (MCP) که به Claude Desktop امکان بررسی در دسترس بودن دامنه را در بیش از ۵۰ TLD می‌دهد. دارای تأیید DNS/WHOIS، بررسی دسته‌ای و پیشنهادات هوشمند است. نصب بدون-کلون از طریق uvx.
- [imprvhub/mcp-claude-hackernews](https://github.com/imprvhub/mcp-claude-hackernews) 📇 🏠 ☁️ - یکپارچه‌سازی که به Claude Desktop امکان تعامل با Hacker News را با استفاده از Model Context Protocol (MCP) می‌دهد.
- [imprvhub/mcp-rss-aggregator](https://github.com/imprvhub/mcp-rss-aggregator) 📇 ☁️ 🏠 - سرور Model Context Protocol برای جمع‌آوری فیدهای RSS در Claude Desktop.

### 🔒 <a name="security"></a>امنیت

- [mariocandela/beelzebub](https://github.com/mariocandela/beelzebub) ☁️ - Beelzebub یک چارچوب honeypot است که به شما امکان می‌دهد ابزارهای honeypot را با استفاده از MCP بسازید. هدف آن شناسایی تزریق پرامپت یا رفتار عامل مخرب است. ایده اصلی این است که به عامل ابزارهایی بدهید که در کار عادی خود هرگز از آنها استفاده نمی‌کند.
- [13bm/GhidraMCP](https://github.com/13bm/GhidraMCP) 🐍 ☕ 🏠 - سرور MCP برای یکپارچه‌سازی Ghidra با دستیاران هوش مصنوعی. این پلاگین تحلیل باینری را امکان‌پذیر می‌کند و ابزارهایی برای بازرسی تابع، دکامپایل، کاوش حافظه و تحلیل import/export از طریق Model Context Protocol فراهم می‌کند.
- [AIM-Intelligence/AIM-Guard-MCP](https://github.com/AIM-Intelligence/AIM-MCP) 📇 🏠 🍎 🪟 🐧 - سرور MCP متمرکز بر امنیت که دستورالعمل‌های ایمنی و تحلیل محتوا را برای عامل‌های هوش مصنوعی فراهم می‌کند.
- [atomicchonk/roadrecon_mcp_server](https://github.com/atomicchonk/roadrecon_mcp_server) 🐍 🪟 🏠 سرور MCP برای تحلیل نتایج جمع‌آوری ROADrecon از شمارش tenant Azure
- [BurtTheCoder/mcp-dnstwist](https://github.com/BurtTheCoder/mcp-dnstwist) 📇 🪟 ☁️ - سرور MCP برای dnstwist، یک ابزار قدرتمند DNS fuzzing که به شناسایی typosquatting، فیشینگ و جاسوسی شرکتی کمک می‌کند.
- [BurtTheCoder/mcp-maigret](https://github.com/BurtTheCoder/mcp-maigret) 📇 🪟 ☁️ - سرور MCP برای maigret، یک ابزار قدرتمند OSINT که اطلاعات حساب کاربری را از منابع عمومی مختلف جمع‌آوری می‌کند. این سرور ابزارهایی برای جستجوی نام‌های کاربری در شبکه‌های اجتماعی و تحلیل URLها فراهم می‌کند.
- [BurtTheCoder/mcp-shodan](https://github.com/BurtTheCoder/mcp-shodan) 📇 🪟 ☁️ - سرور MCP برای کوئری Shodan API و Shodan CVEDB. این سرور ابزارهایی برای جستجوی IP، جستجوی دستگاه، جستجوی DNS، کوئری آسیب‌پذیری، جستجوی CPE و موارد دیگر فراهم می‌کند.
- [BurtTheCoder/mcp-virustotal](https://github.com/BurtTheCoder/mcp-virustotal) 📇 🪟 ☁️ - سرور MCP برای کوئری VirusTotal API. این سرور ابزارهایی برای اسکن URLها، تحلیل هش‌های فایل و بازیابی گزارش‌های آدرس IP فراهم می‌کند.
- [co-browser/attestable-mcp-server](https://github.com/co-browser/attestable-mcp-server) 🐍 🏠 ☁️ 🐧 - یک سرور MCP که در یک محیط اجرای مورد اعتماد (TEE) از طریق Gramine اجرا می‌شود و گواهی از راه دور را با استفاده از [RA-TLS](https://gramine.readthedocs.io/en/stable/attestation.html) به نمایش می‌گذارد. این به یک کلاینت MCP اجازه می‌دهد سرور را قبل از اتصال تأیید کند.
- [dkvdm/onepassword-mcp-server](https://github.com/dkvdm/onepassword-mcp-server) - یک سرور MCP که بازیابی امن اعتبارنامه‌ها را از 1Password برای استفاده توسط هوش مصنوعی عامل‌محور امکان‌پذیر می‌کند.
- [firstorderai/authenticator_mcp](https://github.com/firstorderai/authenticator_mcp) 📇 🏠 🍎 🪟 🐧 – یک سرور MCP (Model Context Protocol) امن که به عامل‌های هوش مصنوعی امکان تعامل با برنامه Authenticator را می‌دهد.
- [fosdickio/binary_ninja_mcp](https://github.com/fosdickio/binary_ninja_mcp) 🐍 🏠 🍎 🪟 🐧 - یک پلاگین Binary Ninja، سرور MCP و پل که [Binary Ninja](https://binary.ninja) را به طور یکپارچه با کلاینت MCP مورد علاقه شما یکپارچه می‌کند. این به شما امکان می‌دهد فرآیند انجام تحلیل باینری و مهندسی معکوس را خودکار کنید.
- [fr0gger/MCP_Security](https://github.com/fr0gger/MCP_Security) 📇 ☁️ - سرور MCP برای کوئری ORKL API. این سرور ابزارهایی برای دریافت گزارش‌های تهدید، تحلیل عوامل تهدید و بازیابی منابع اطلاعاتی فراهم می‌کند.
- [Gaffx/volatility-mcp](https://github.com/Gaffx/volatility-mcp) - سرور MCP برای Volatility 3.x، که به شما امکان می‌دهد تحلیل پزشکی قانونی حافظه را با دستیار هوش مصنوعی انجام دهید. پزشکی قانونی حافظه را بدون موانع تجربه کنید زیرا پلاگین‌هایی مانند pslist و netscan از طریق APIهای REST تمیز و LLMها قابل دسترس می‌شوند.
- [gbrigandi/mcp-server-cortex](https://github.com/gbrigandi/mcp-server-cortex) 🦀 🏠 🚨 🍎 🪟 🐧 - یک سرور MCP مبتنی بر Rust برای یکپارچه‌سازی Cortex، که تحلیل قابل مشاهده و پاسخ‌های امنیتی خودکار را از طریق هوش مصنوعی امکان‌پذیر می‌کند.
- [gbrigandi/mcp-server-thehive](https://github.com/gbrigandi/mcp-server-thehive) 🦀 🏠 🚨 🍎 🪟 🐧 - یک سرور MCP مبتنی بر Rust برای یکپارچه‌سازی TheHive، که پاسخ به حوادث امنیتی و مدیریت پرونده را به صورت همکاری از طریق هوش مصنوعی تسهیل می‌کند.
- [gbrigandi/mcp-server-wazuh](https://github.com/gbrigandi/mcp-server-wazuh) 🦀 🏠 🚨 🍎 🪟 🐧 - یک سرور MCP مبتنی بر Rust که Wazuh SIEM را به دستیاران هوش مصنوعی متصل می‌کند و هشدارهای امنیتی بی‌درنگ و داده‌های رویداد را برای درک متنی پیشرفته فراهم می‌کند.
- [hieutran/entraid-mcp-server](https://github.com/hieuttmmo/entraid-mcp-server) 🐍 ☁️ - یک سرور MCP برای دایرکتوری Microsoft Entra ID (Azure AD)، کاربر، گروه، دستگاه، ورود به سیستم و عملیات امنیتی از طریق Microsoft Graph Python SDK.
- [intruder-io/intruder-mcp](https://github.com/intruder-io/intruder-mcp) 🐍 ☁️ - سرور MCP برای دسترسی به [Intruder](https://www.intruder.io/)، که به شما در شناسایی، درک و رفع آسیب‌پذیری‌های امنیتی در زیرساخت خود کمک می‌کند.
- [jtang613/GhidrAssistMCP](https://github.com/jtang613/GhidrAssistMCP) ☕ 🏠 - یک سرور Model Context Protocol بومی برای Ghidra. شامل پیکربندی و لاگ‌گیری GUI، ۳۱ ابزار قدرتمند و بدون وابستگی خارجی است.
- [jyjune/mcp_vms](https://github.com/jyjune/mcp_vms) 🐍 🏠 🪟 - یک سرور Model Context Protocol (MCP) که برای اتصال به یک برنامه ضبط CCTV (VMS) برای بازیابی جریان‌های ویدیویی ضبط شده و زنده طراحی شده است. همچنین ابزارهایی برای کنترل نرم‌افزار VMS فراهم می‌کند، مانند نمایش دیالوگ‌های زنده یا پخش برای کانال‌های خاص در زمان‌های مشخص.
- [LaurieWired/GhidraMCP](https://github.com/LaurieWired/GhidraMCP) ☕ 🏠 - یک سرور Model Context Protocol برای Ghidra که به LLMها امکان مهندسی معکوس خودکار برنامه‌ها را می‌دهد. ابزارهایی برای دکامپایل باینری‌ها، تغییر نام متدها و داده‌ها و لیست کردن متدها، کلاس‌ها، importها و exportها فراهم می‌کند.
- [mobb-dev/mobb-vibe-shield-mcp](https://github.com/mobb-dev/bugsy?tab=readme-ov-file#model-context-protocol-mcp-server) 🎖️ 📇 ☁️ 🍎 🪟 🐧 - [Mobb Vibe Shield](https://vibe.mobb.ai/) آسیب‌پذیری‌ها را در کد نوشته شده توسط انسان و هوش مصنوعی شناسایی و اصلاح می‌کند و اطمینان می‌دهد که برنامه‌های شما امن باقی می‌مانند بدون اینکه توسعه را کند کند.
- [mrexodia/ida-pro-mcp](https://github.com/mrexodia/ida-pro-mcp) 🐍 🏠 - سرور MCP برای IDA Pro، که به شما امکان می‌دهد تحلیل باینری را با دستیاران هوش مصنوعی انجام دهید. این پلاگین دکامپایل، دیس‌اسمبلی را پیاده‌سازی می‌کند و به شما امکان می‌دهد گزارش‌های تحلیل بدافزار را به طور خودکار تولید کنید.
- [nickpending/mcp-recon](https://github.com/nickpending/mcp-recon) 🏎️ 🏠 - رابط شناسایی مکالمه‌ای و سرور MCP با قدرت httpx و asnmap. از سطوح مختلف شناسایی برای تحلیل دامنه، بازرسی هدر امنیتی، تحلیل گواهی و جستجوی ASN پشتیبانی می‌کند.
- [panther-labs/mcp-panther](https://github.com/panther-labs/mcp-panther) 🎖️ 🐍 ☁️ 🍎 - سرور MCP که به متخصصان امنیتی امکان تعامل با پلتفرم SIEM Panther را با استفاده از زبان طبیعی برای نوشتن تشخیص‌ها، کوئری لاگ‌ها و مدیریت هشدارها می‌دهد.
- [pullkitsan/mobsf-mcp-server](https://github.com/pullkitsan/mobsf-mcp-server) 🦀 🏠 🍎 🪟 🐧 - یک سرور MCP برای MobSF که می‌تواند برای تحلیل استاتیک و دینامیک برنامه‌های Android و iOS استفاده شود.
- [qianniuspace/mcp-security-audit](https://github.com/qianniuspace/mcp-security-audit) 📇 ☁️ یک سرور MCP (Model Context Protocol) قدرتمند که وابستگی‌های بسته npm را برای آسیب‌پذیری‌های امنیتی ممیزی می‌کند. ساخته شده با یکپارچه‌سازی رجیستری npm راه دور برای بررسی‌های امنیتی بی‌درنگ.
- [rad-security/mcp-server](https://github.com/rad-security/mcp-server) 📇 ☁️ - سرور MCP برای RAD Security، که بینش‌های امنیتی مبتنی بر هوش مصنوعی را برای محیط‌های Kubernetes و ابری فراهم می‌کند. این سرور ابزارهایی برای کوئری Rad Security API و بازیابی یافته‌های امنیتی، گزارش‌ها، داده‌های زمان اجرا و موارد دیگر فراهم می‌کند.
- [radareorg/r2mcp](https://github.com/radareorg/radare2-mcp) 🍎🪟🐧🏠🌊 - سرور MCP برای دی‌اسمبلر Radare2. قابلیت دی‌اسمبل و بررسی باینری‌ها برای مهندسی معکوس را برای هوش مصنوعی فراهم می‌کند.
- [roadwy/cve-search_mcp](https://github.com/roadwy/cve-search_mcp) 🐍 🏠 - یک سرور Model Context Protocol (MCP) برای کوئری CVE-Search API. این سرور دسترسی جامعی به CVE-Search، مرور فروشنده و محصول، دریافت CVE بر اساس CVE-ID، دریافت آخرین CVEهای به‌روز شده را فراهم می‌کند.
- [safedep/vet](https://github.com/safedep/vet/blob/main/docs/mcp.md) 🎖️ 🏎️ ☁️ 🍎 🪟 🐧 - vet-mcp بسته‌های منبع باز—مانند آنهایی که توسط ابزارهای کدنویسی هوش مصنوعی پیشنهاد می‌شوند—را برای آسیب‌پذیری‌ها و کدهای مخرب بررسی می‌کند. از npm و PyPI پشتیبانی می‌کند و به صورت محلی از طریق Docker یا به عنوان یک باینری مستقل برای بررسی سریع و خودکار اجرا می‌شود.
- [sanyambassi/ciphertrust-manager-mcp-server](https://github.com/sanyambassi/ciphertrust-manager-mcp-server) 🐍 ☁️ 🏠 🐧 🪟 - سرور MCP برای یکپارچه‌سازی با Thales CipherTrust Manager، که مدیریت کلید امن، عملیات رمزنگاری و نظارت بر انطباق را از طریق دستیاران هوش مصنوعی امکان‌پذیر می‌کند.
- [sanyambassi/thales-cdsp-cakm-mcp-server](https://github.com/sanyambassi/thales-cdsp-cakm-mcp-server) 🐍 ☁️ 🏠 🐧 🪟 - سرور MCP برای یکپارچه‌سازی با Thales CDSP CAKM، که مدیریت کلید امن، عملیات رمزنگاری و نظارت بر انطباق را از طریق دستیاران هوش مصنوعی برای پایگاه‌های داده Ms SQL و Oracle امکان‌پذیر می‌کند.
- [sanyambassi/thales-cdsp-crdp-mcp-server](https://github.com/sanyambassi/thales-cdsp-crdp-mcp-server) 📇 ☁️ 🏠 🐧 🪟 - سرور MCP برای سرویس حفاظت از داده RestFul Thales CipherTrust Manager.
- [securityfortech/secops-mcp](https://github.com/securityfortech/secops-mcp) 🐍 🏠 - جعبه ابزار تست امنیتی همه‌کاره که ابزارهای منبع باز محبوب را از طریق یک رابط MCP واحد گرد هم می‌آورد. با اتصال به یک عامل هوش مصنوعی، وظایفی مانند تست نفوذ، شکار باگ، شکار تهدید و موارد دیگر را امکان‌پذیر می‌کند.
- [semgrep/mcp](https://github.com/semgrep/mcp) 📇 ☁️ به عامل‌های هوش مصنوعی اجازه دهید کد را برای آسیب‌پذیری‌های امنیتی با استفاده از [Semgrep](https://semgrep.dev) اسکن کنند.
- [slouchd/cyberchef-api-mcp-server](https://github.com/slouchd/cyberchef-api-mcp-server) 🐍 ☁️ - سرور MCP برای تعامل با CyberChef server API که به یک کلاینت MCP اجازه می‌دهد از عملیات CyberChef استفاده کند.
- [StacklokLabs/osv-mcp](https://github.com/StacklokLabs/osv-mcp) 🏎️ ☁️ - به پایگاه داده OSV (Open Source Vulnerabilities) برای اطلاعات آسیب‌پذیری دسترسی پیدا کنید. آسیب‌پذیری‌ها را بر اساس نسخه بسته یا commit کوئری کنید، چندین بسته را به صورت دسته‌ای کوئری کنید و اطلاعات دقیق آسیب‌پذیری را بر اساس ID دریافت کنید.
- [vespo92/OPNSenseMCP](https://github.com/vespo92/OPNSenseMCP) 📇 🏠 - سرور MCP برای مدیریت و تعامل با Open Source NGFW OPNSense از طریق زبان طبیعی
- [adeptus-innovatio/solvitor-mcp](https://github.com/Adeptus-Innovatio/solvitor-mcp) 🦀 🏠 - سرور Solvitor MCP ابزارهایی برای دسترسی به ابزارهای مهندسی معکوس فراهم می‌کند که به توسعه‌دهندگان در استخراج فایل‌های IDL از قراردادهای هوشمند Solana منبع بسته و دکامپایل آنها کمک می‌کند.
- [zinja-coder/apktool-mcp-server](https://github.com/zinja-coder/apktool-mcp-server) 🐍 🏠 - APKTool MCP Server یک سرور MCP برای Apk Tool است تا اتوماسیون در مهندسی معکوس APKهای Android را فراهم کند.
- [zinja-coder/jadx-ai-mcp](https://github.com/zinja-coder/jadx-ai-mcp) ☕ 🏠 - JADX-AI-MCP یک پلاگین و سرور MCP برای decompiler JADX است که مستقیماً با Model Context Protocol (MCP) یکپارچه می‌شود تا پشتیبانی از مهندسی معکوس زنده را با LLMهایی مانند Claude فراهم کند.
- [HaroldFinchIFT/vuln-nist-mcp-server](https://github.com/HaroldFinchIFT/vuln-nist-mcp-server) 🐍 ☁️️ 🍎 🪟 🐧 - یک سرور Model Context Protocol (MCP) برای کوئری نقاط پایانی API پایگاه داده ملی آسیب‌پذیری NIST (NVD).

### 🌐 <a name="social-media"></a>رسانه‌های اجتماعی

یکپارچه‌سازی با پلتفرم‌های رسانه‌های اجتماعی برای امکان ارسال، تحلیل و مدیریت تعامل. اتوماسیون مبتنی بر هوش مصنوعی را برای حضور اجتماعی امکان‌پذیر می‌کند.

- [anwerj/youtube-uploader-mcp](https://github.com/anwerj/youtube-uploader-mcp) 🏎️ ☁️ - آپلودکننده YouTube مبتنی بر هوش مصنوعی—بدون CLI، بدون YouTube Studio. آپلود ویدیوها مستقیماً از کلاینت‌های MCP با تمام قابلیت‌های هوش مصنوعی.
- [gwbischof/bluesky-social-mcp](https://github.com/gwbischof/bluesky-social-mcp) 🐍 🏠 - یک سرور MCP برای تعامل با Bluesky از طریق کلاینت atproto.
- [HagaiHen/facebook-mcp-server](https://github.com/HagaiHen/facebook-mcp-server) 🐍 ☁️ - با صفحات فیس‌بوک یکپارچه می‌شود تا مدیریت مستقیم پست‌ها، نظرات و معیارهای تعامل را از طریق Graph API برای مدیریت ساده رسانه‌های اجتماعی امکان‌پذیر کند.
- [karanb192/reddit-buddy-mcp](https://github.com/karanb192/reddit-buddy-mcp) 📇 🏠 - مرور پست‌های Reddit، جستجوی محتوا و تحلیل فعالیت کاربران بدون کلید API. با Claude Desktop به صورت پیش‌فرض کار می‌کند.
- [kunallunia/twitter-mcp](https://github.com/LuniaKunal/mcp-twitter) 🐍 🏠 - راه حل مدیریت همه‌کاره توییتر که دسترسی به تایم‌لاین، بازیابی توییت‌های کاربر، نظارت بر هشتگ‌ها، تحلیل مکالمات، پیام مستقیم، تحلیل احساسات یک پست و کنترل کامل چرخه حیات پست را - همه از طریق یک API ساده - فراهم می‌کند.
- [macrocosm-os/macrocosmos-mcp](https://github.com/macrocosm-os/macrocosmos-mcp) - 🎖️ 🐍 ☁️ به داده‌های بی‌درنگ X/Reddit/YouTube مستقیماً در برنامه‌های LLM خود با عبارات جستجو، کاربران و فیلتر تاریخ دسترسی پیدا کنید.
- [sinanefeozler/reddit-summarizer-mcp](https://github.com/sinanefeozler/reddit-summarizer-mcp) 🐍 🏠 ☁️ - سرور MCP برای خلاصه‌سازی صفحه اصلی Reddit کاربران یا هر subreddit بر اساس پست‌ها و نظرات.

### 🏃 <a name="sports"></a>ورزش

ابزارهایی برای دسترسی به داده‌ها، نتایج و آمار مرتبط با ورزش.

- [guillochon/mlb-api-mcp](https://github.com/guillochon/mlb-api-mcp) 🐍 🏠 - سرور MCP که به عنوان یک پروکسی برای MLB API رایگان عمل می‌کند، که اطلاعات بازیکن، آمار و اطلاعات بازی را فراهم می‌کند.
- [mikechao/balldontlie-mcp](https://github.com/mikechao/balldontlie-mcp) 📇 - سرور MCP که balldontlie api را یکپارچه می‌کند تا اطلاعاتی در مورد بازیکنان، تیم‌ها و بازی‌های NBA، NFL و MLB فراهم کند
- [r-huijts/firstcycling-mcp](https://github.com/r-huijts/firstcycling-mcp) 📇 ☁️ - به داده‌های مسابقات دوچرخه‌سواری، نتایج و آمار از طریق زبان طبیعی دسترسی پیدا کنید. ویژگی‌ها شامل بازیابی لیست‌های شروع، نتایج مسابقه و اطلاعات دوچرخه‌سوار از firstcycling.com است.
- [r-huijts/strava-mcp](https://github.com/r-huijts/strava-mcp) 📇 ☁️ - یک سرور Model Context Protocol (MCP) که به Strava API متصل می‌شود و ابزارهایی برای دسترسی به داده‌های Strava از طریق LLMها فراهم می‌کند
- [RobSpectre/mvf1](https://github.com/RobSpectre/mvf1) 🐍 ☁️ - سرور MCP که [MultiViewer](https://multiviewer.app) را کنترل می‌کند، برنامه‌ای برای تماشای ورزش‌های موتوری مانند فرمول ۱، مسابقات قهرمانی استقامت جهانی، IndyCar و دیگران.
- [willvelida/mcp-afl-server](https://github.com/willvelida/mcp-afl-server) ☁️ - سرور MCP که با Squiggle API یکپارچه می‌شود تا اطلاعاتی در مورد تیم‌های لیگ فوتبال استرالیا، جدول رده‌بندی، نتایج، پیش‌بینی‌ها و رتبه‌بندی قدرت را فراهم کند.
- [cloudbet/sports-mcp-server](https://github.com/cloudbet/sports-mcp-server) 🏎️ ☁️ – به داده‌های ورزشی ساختاریافته از طریق Cloudbet API دسترسی پیدا کنید. رویدادهای آتی، شانس‌های زنده، محدودیت‌های شرط‌بندی و اطلاعات بازار را در فوتبال، بسکتبال، تنیس، ورزش‌های الکترونیکی و موارد دیگر کوئری کنید.


### 🎧 <a name="support-and-service-management"></a>پشتیبانی و مدیریت خدمات

ابزارهایی برای مدیریت پشتیبانی مشتری، مدیریت خدمات IT و عملیات helpdesk.

- [aikts/yandex-tracker-mcp](https://github.com/aikts/yandex-tracker-mcp) 🐍 ☁️ 🏠 - سرور MCP برای Yandex Tracker. ابزارهایی برای جستجو و بازیابی اطلاعات در مورد issueها، صف‌ها، کاربران فراهم می‌کند.
- [effytech/freshdesk-mcp](https://github.com/effytech/freshdesk_mcp) 🐍 ☁️ - سرور MCP که با Freshdesk یکپارچه می‌شود و به مدل‌های هوش مصنوعی امکان تعامل با ماژول‌های Freshdesk و انجام عملیات مختلف پشتیبانی را می‌دهد.
- [incentivai/quickchat-ai-mcp](https://github.com/incentivai/quickchat-ai-mcp) 🐍 🏠 ☁️ - عامل مکالمه‌ای Quickchat AI خود را به عنوان یک MCP راه‌اندازی کنید تا به برنامه‌های هوش مصنوعی دسترسی بی‌درنگ به پایگاه دانش و قابلیت‌های مکالمه‌ای آن بدهید.
- [nguyenvanduocit/jira-mcp](https://github.com/nguyenvanduocit/jira-mcp) 🏎️ ☁️ - یک اتصال‌دهنده MCP مبتنی بر Go برای Jira که به دستیاران هوش مصنوعی مانند Claude امکان تعامل با Atlassian Jira را می‌دهد. این ابزار یک رابط یکپارچه برای مدل‌های هوش مصنوعی برای انجام عملیات رایج Jira شامل مدیریت issue، برنامه‌ریزی sprint و انتقال گردش کار فراهم می‌کند.
- [sooperset/mcp-atlassian](https://github.com/sooperset/mcp-atlassian) 🐍 ☁️ - سرور MCP برای محصولات Atlassian (Confluence و Jira). از Confluence Cloud، Jira Cloud و Jira Server/Data Center پشتیبانی می‌کند. ابزارهای جامعی برای جستجو، خواندن، ایجاد و مدیریت محتوا در فضاهای کاری Atlassian فراهم می‌کند.
- [tom28881/mcp-jira-server](https://github.com/tom28881/mcp-jira-server) 📇 ☁️ 🏠 - سرور MCP TypeScript جامع برای Jira با بیش از ۲۰ ابزار که گردش کار کامل مدیریت پروژه را پوشش می‌دهد: CRUD issue، مدیریت sprint، نظرات/تاریخچه، پیوست‌ها، عملیات دسته‌ای.

### 🌎 <a name="translation-services"></a>خدمات ترجمه

ابزارها و خدمات ترجمه برای قادر ساختن دستیاران هوش مصنوعی به ترجمه محتوا بین زبان‌های مختلف.

- [mmntm/weblate-mcp](https://github.com/mmntm/weblate-mcp) 📇 ☁️ - سرور Model Context Protocol جامع برای مدیریت ترجمه Weblate، که به دستیاران هوش مصنوعی امکان انجام وظایف ترجمه، مدیریت پروژه و کشف محتوا را با تبدیل‌های فرمت هوشمند می‌دهد.
- [translated/lara-mcp](https://github.com/translated/lara-mcp) 🎖️ 📇 ☁️ - سرور MCP برای Lara Translate API، که قابلیت‌های ترجمه قدرتمند را با پشتیبانی از تشخیص زبان و ترجمه‌های آگاه از زمینه امکان‌پذیر می‌کند.

### 🎧 <a name="text-to-speech"></a>تبدیل متن به گفتار

ابزارهایی برای تبدیل متن به گفتار و بالعکس

- [daisys-ai/daisys-mcp](https://github.com/daisys-ai/daisys-mcp) 🐍 🏠 🍎 🪟 🐧 - تولید خروجی‌های تبدیل متن به گفتار و متن به صدا با کیفیت بالا با استفاده از پلتفرم [DAISYS](https://www.daisys.ai/) و امکان پخش و ذخیره صدای تولید شده.
- [mbailey/voice-mcp](https://github.com/mbailey/voice-mcp) 🐍 🏠 - سرور تعامل صوتی کامل که از تبدیل گفتار به متن، تبدیل متن به گفتار و مکالمات صوتی بی‌درنگ از طریق میکروفون محلی، APIهای سازگار با OpenAI و یکپارچه‌سازی LiveKit پشتیبانی می‌کند
- [mberg/kokoro-tts-mcp](https://github.com/mberg/kokoro-tts-mcp) 🐍 🏠 - سرور MCP که از مدل‌های Kokoro TTS با وزن باز برای تبدیل متن به گفتار استفاده می‌کند. می‌تواند متن را به MP3 در یک درایو محلی تبدیل کند یا به طور خودکار به یک سطل S3 آپلود کند.
- [transcribe-app/mcp-transcribe](https://github.com/transcribe-app/mcp-transcribe) 📇 🏠 - این سرویس رونویسی‌های سریع و قابل اعتمادی را برای فایل‌های صوتی/تصویری و یادداشت‌های صوتی فراهم می‌کند. این به LLMها امکان تعامل با محتوای متنی فایل‌های صوتی/تصویری را می‌دهد.

### 🚆 <a name="travel-and-transportation"></a>سفر و حمل و نقل

دسترسی به اطلاعات سفر و حمل و نقل. امکان کوئری برنامه‌ها، مسیرها و داده‌های سفر بی‌درنگ را فراهم می‌کند.

- [campertunity/mcp-server](https://github.com/campertunity/mcp-server) 🎖️ 📇 🏠 - جستجوی کمپینگ‌ها در سراسر جهان در campertunity، بررسی در دسترس بودن و ارائه لینک‌های رزرو
- [cobanov/teslamate-mcp](https://github.com/cobanov/teslamate-mcp) 🐍 🏠 - یک سرور Model Context Protocol (MCP) که دسترسی به پایگاه داده TeslaMate شما را فراهم می‌کند و به دستیاران هوش مصنوعی امکان کوئری داده‌ها و تحلیل‌های خودروی Tesla را می‌دهد.
- [KyrieTangSheng/mcp-server-nationalparks](https://github.com/KyrieTangSheng/mcp-server-nationalparks) 📇 ☁️ - یکپارچه‌سازی با National Park Service API که آخرین اطلاعات جزئیات پارک، هشدارها، مراکز بازدیدکنندگان، کمپینگ‌ها و رو[KyrieTangSheng/mcp-server-nationalparks](https://github.com/KyrieTangSheng/mcp-server-nationalparks) 📇 ☁️ - یکپارچه‌سازی با National Park Service API که آخرین اطلاعات جزئیات پارک، هشدارها، مراکز بازدیدکنندگان، کمپینگ‌ها و رویدادها را برای پارک‌های ملی ایالات متحده فراهم می‌کند
- [lucygoodchild/mcp-national-rail](https://github.com/lucygoodchild/mcp-national-rail) 📇 ☁️ - یک سرور MCP برای سرویس قطارهای ملی بریتانیا، که برنامه‌های زمانی قطار و اطلاعات سفر زنده را با یکپارچه‌سازی Realtime Trains API فراهم می‌کند
- [openbnb-org/mcp-server-airbnb](https://github.com/openbnb-org/mcp-server-airbnb) 📇 ☁️ - ابزارهایی برای جستجوی Airbnb و دریافت جزئیات لیستینگ فراهم می‌کند.
- [pab1it0/tripadvisor-mcp](https://github.com/pab1it0/tripadvisor-mcp) 📇 🐍 - یک سرور MCP که به LLMها امکان تعامل با Tripadvisor API را می‌دهد و از داده‌های مکان، نظرات و عکس‌ها از طریق رابط‌های استاندارد MCP پشتیبانی می‌کند
- [Pradumnasaraf/aviationstack-mcp](https://github.com/Pradumnasaraf/aviationstack-mcp) 🐍 ☁️ 🍎 🪟 🐧 - یک سرور MCP با استفاده از AviationStack API برای دریافت داده‌های پرواز بی‌درنگ شامل پروازهای خطوط هوایی، برنامه‌های فرودگاه، پروازهای آینده و انواع هواپیما.
- [r-huijts/ns-mcp-server](https://github.com/r-huijts/ns-mcp-server) 📇 ☁️ - دسترسی به اطلاعات سفر، برنامه‌های زمانی و به‌روزرسانی‌های بی‌درنگ راه‌آهن هلند (NS)
- [skedgo/tripgo-mcp-server](https://github.com/skedgo/tripgo-mcp-server) 📇 ☁️ - ابزارهایی از TripGo API برای برنامه‌ریزی سفر چندوجهی، مکان‌های حمل‌ونقل و حرکت‌های حمل‌ونقل عمومی، شامل اطلاعات بی‌درنگ، فراهم می‌کند.
- [helpful-AIs/triplyfy-mcp](https://github.com/helpful-AIs/triplyfy-mcp) 📇 ☁️ - یک سرور MCP که به LLMها امکان برنامه‌ریزی و مدیریت برنامه‌های سفر را با نقشه‌های تعاملی در Triplyfy می‌دهد؛ مدیریت برنامه‌های سفر، مکان‌ها و یادداشت‌ها و جستجو/ذخیره پروازها.
- [srinath1510/alltrails-mcp-server](https://github.com/srinath1510/alltrails-mcp-server) 🐍 ☁️ - یک سرور MCP که دسترسی به داده‌های AllTrails را فراهم می‌کند و به شما امکان می‌دهد مسیرهای پیاده‌روی را جستجو کرده و اطلاعات دقیق مسیر را دریافت کنید

### 🔄 <a name="version-control"></a>کنترل نسخه

تعامل با مخازن Git و پلتفرم‌های کنترل نسخه. امکان مدیریت مخزن، تحلیل کد، مدیریت pull request، ردیابی issue و سایر عملیات کنترل نسخه را از طریق APIهای استاندارد فراهم می‌کند.

- [adhikasp/mcp-git-ingest](https://github.com/adhikasp/mcp-git-ingest) 🐍 🏠 - خواندن و تحلیل مخازن GitHub با LLM شما
- [ddukbg/github-enterprise-mcp](https://github.com/ddukbg/github-enterprise-mcp) 📇 ☁️ 🏠 - سرور MCP برای یکپارچه‌سازی با GitHub Enterprise API
- [gitea/gitea-mcp](https://gitea.com/gitea/gitea-mcp) 🎖️ 🏎️ ☁️ 🏠 🍎 🪟 🐧 - تعامل با نمونه‌های Gitea با MCP.
- [github/github-mcp-server](https://github.com/github/github-mcp-server) 📇 ☁️ - سرور رسمی GitHub برای یکپارچه‌سازی با مدیریت مخزن، PRها، issueها و موارد دیگر.
- [kaiyuanxiaobing/atomgit-mcp-server](https://github.com/kaiyuanxiaobing/atomgit-mcp-server) 📇 ☁️ - سرور رسمی AtomGit برای یکپارچه‌سازی با مدیریت مخزن، PRها، issueها، شاخه‌ها، برچسب‌ها و موارد دیگر.
- [kopfrechner/gitlab-mr-mcp](https://github.com/kopfrechner/gitlab-mr-mcp) 📇 ☁️ - تعامل یکپارچه با issueها و merge requestهای پروژه‌های GitLab شما.
- [modelcontextprotocol/server-git](https://github.com/modelcontextprotocol/servers/tree/main/src/git) 🐍 🏠 - عملیات مستقیم مخزن Git شامل خواندن، جستجو و تحلیل مخازن محلی
- [modelcontextprotocol/server-gitlab](https://github.com/modelcontextprotocol/servers/tree/main/src/gitlab) 📇 ☁️ 🏠 - یکپارچه‌سازی با پلتفرم GitLab برای مدیریت پروژه و عملیات CI/CD
- [QuentinCody/github-graphql-mcp-server](https://github.com/QuentinCody/github-graphql-mcp-server) 🐍 ☁️ - سرور MCP غیر رسمی GitHub که دسترسی به GraphQL API GitHub را فراهم می‌کند و کوئری‌های قدرتمندتر و انعطاف‌پذیرتری برای داده‌های مخزن، issueها، pull requestها و سایر منابع GitHub امکان‌پذیر می‌کند.
- [Tiberriver256/mcp-server-azure-devops](https://github.com/Tiberriver256/mcp-server-azure-devops) 📇 ☁️ - یکپارچه‌سازی با Azure DevOps برای مدیریت مخزن، work itemها و pipelineها.
- [theonedev/tod](https://github.com/theonedev/tod/blob/main/mcp.md) 🏎️ 🏠 - یک سرور MCP برای OneDev برای ویرایش pipeline CI/CD، اتوماسیون گردش کار issue و بازبینی pull request

### 🏢 <a name="workplace-and-productivity"></a>محیط کار و بهره‌وری

- [bivex/kanboard-mcp](https://github.com/bivex/kanboard-mcp) 🏎️ ☁️ 🏠 - یک سرور Model Context Protocol (MCP) نوشته شده در Go که به عامل‌های هوش مصنوعی و مدل‌های زبان بزرگ (LLMها) قدرت می‌دهد تا به طور یکپارچه با Kanboard تعامل داشته باشند. این سرور دستورات زبان طبیعی را به فراخوانی‌های Kanboard API تبدیل می‌کند و اتوماسیون هوشمند مدیریت پروژه، وظیفه و کاربر را امکان‌پذیر می‌کند، گردش‌های کاری را ساده می‌کند و بهره‌وری را افزایش می‌دهد.
- [devroopsaha744/TexMCP](https://github.com/devroopsaha744/TexMCP) 🐍 🏠 - یک سرور MCP که LaTeX را به اسناد PDF با کیفیت بالا تبدیل می‌کند. ابزارهایی برای رندر ورودی LaTeX خام و قالب‌های قابل تنظیم فراهم می‌کند و مصنوعات قابل اشتراک‌گذاری و آماده برای تولید مانند گزارش‌ها، رزومه‌ها و مقالات تحقیقاتی را تولید می‌کند.
- [giuseppe-coco/Google-Workspace-MCP-Server](https://github.com/giuseppe-coco/Google-Workspace-MCP-Server) 🐍 ☁️ 🍎 🪟 🐧 - سرور MCP که به طور یکپارچه با Google Calendar، Gmail، Drive و غیره شما تعامل دارد.
- [MarkusPfundstein/mcp-gsuite](https://github.com/MarkusPfundstein/mcp-gsuite) 🐍 ☁️ - یکپارچه‌سازی با gmail و Google Calendar.
- [takumi0706/google-calendar-mcp](https://github.com/takumi0706/google-calendar-mcp) 📇 ☁️ - یک سرور MCP برای ارتباط با Google Calendar API. مبتنی بر TypeScript.
- [taylorwilsdon/google_workspace_mcp](https://github.com/taylorwilsdon/google_workspace_mcp) 🐍 ☁️ 🍎 🪟 🐧 - سرور MCP جامع Google Workspace با پشتیبانی کامل از Google Calendar، Drive، Gmail، و Docs، Forms، Chats، Slides و Sheets از طریق انتقال‌های stdio، Streamable HTTP و SSE.
- [teamwork/mcp](https://github.com/teamwork/mcp) 🎖️ 🏎️ ☁️ 🍎 🪟 🐧 - پلتفرم مدیریت پروژه و منابع که پروژه‌های مشتری شما را در مسیر نگه می‌دارد، مدیریت منابع را آسان می‌کند و سود شما را حفظ می‌کند.
- [tubasasakunn/context-apps-mcp](https://github.com/tubasasakunn/context-apps-mcp) 📇 🏠 🍎 🪟 🐧 - مجموعه بهره‌وری مبتنی بر هوش مصنوعی که برنامه‌های Todo، Idea، Journal و Timer را با Claude از طریق Model Context Protocol متصل می‌کند.
- [vakharwalad23/google-mcp](https://github.com/vakharwalad23/google-mcp) 📇 ☁️ - مجموعه‌ای از ابزارهای بومی Google (Gmail، Calendar، Drive، Tasks) برای MCP با مدیریت OAuth، تازه‌سازی خودکار توکن و قابلیت‌های احراز هویت مجدد خودکار.

### 🛠️ <a name="other-tools-and-integrations"></a>سایر ابزارها و یکپارچه‌سازی‌ها

- [2niuhe/plantuml_web](https://github.com/2niuhe/plantuml_web) 🐍 🏠 ☁️ 🍎 🪟 🐧 - یک frontend PlantUML مبتنی بر وب با یکپارچه‌سازی سرور MCP، که تولید تصویر plantuml و اعتبارسنجی سینتکس plantuml را امکان‌پذیر می‌کند.
- [2niuhe/qrcode_mcp](https://github.com/2niuhe/qrcode_mcp) 🐍 🏠 🍎 🪟 🐧 - یک سرور MCP تولید کد QR که هر متنی (شامل کاراکترهای چینی) را به کدهای QR با رنگ‌های قابل تنظیم و خروجی رمزگذاری شده base64 تبدیل می‌کند.
- [AbdelStark/bitcoin-mcp](https://github.com/AbdelStark/bitcoin-mcp) - ₿ یک سرور Model Context Protocol (MCP) که به مدل‌های هوش مصنوعی امکان تعامل با Bitcoin را می‌دهد و به آنها امکان تولید کلید، اعتبارسنجی آدرس‌ها، رمزگشایی تراکنش‌ها، کوئری بلاکچین و موارد دیگر را می‌دهد.
- [akseyh/bear-mcp-server](https://github.com/akseyh/bear-mcp-server) - به هوش مصنوعی اجازه می‌دهد از یادداشت‌های Bear شما بخواند (فقط macOS)
- [allenporter/mcp-server-home-assistant](https://github.com/allenporter/mcp-server-home-assistant) 🐍 🏠 - تمام intentهای صوتی Home Assistant را از طریق یک سرور Model Context Protocol در معرض دید قرار دهید و کنترل خانه را امکان‌پذیر کنید.
- [altinoren/utopia](https://github.com/altinoren/Utopia) #️⃣ 🏠 - MCP که مجموعه‌ای از دستگاه‌های خانه هوشمند و سبک زندگی را شبیه‌سازی می‌کند و به شما امکان می‌دهد قابلیت‌های استدلال و کشف عامل را تست کنید.
- [Amazon Bedrock Nova Canvas](https://github.com/zxkane/mcp-server-amazon-bedrock) 📇 ☁️ - از مدل Amazon Nova Canvas برای تولید تصویر استفاده کنید.
- [amidabuddha/unichat-mcp-server](https://github.com/amidabuddha/unichat-mcp-server) 🐍/📇 ☁️ - ارسال درخواست به OpenAI، MistralAI، Anthropic، xAI، Google AI یا DeepSeek با استفاده از پروتکل MCP از طریق ابزار یا پرامپت‌های از پیش تعریف شده. کلید API فروشنده مورد نیاز است
- [anaisbetts/mcp-installer](https://github.com/anaisbetts/mcp-installer) 🐍 🏠 -  یک سرور MCP که سرورهای MCP دیگر را برای شما نصب می‌کند.
- [anaisbetts/mcp-youtube](https://github.com/anaisbetts/mcp-youtube) 📇 ☁️ - دریافت زیرنویس‌های YouTube
- [andybrandt/mcp-simple-openai-assistant](https://github.com/andybrandt/mcp-simple-openai-assistant) - 🐍 ☁️  MCP برای صحبت با دستیاران OpenAI (Claude می‌تواند از هر مدل GPT به عنوان دستیار خود استفاده کند)
- [andybrandt/mcp-simple-timeserver](https://github.com/andybrandt/mcp-simple-timeserver) 🐍 🏠☁️ - یک سرور MCP که امکان بررسی زمان محلی در دستگاه کلاینت یا زمان UTC فعلی را از یک سرور NTP می‌دهد
- [apify/actors-mcp-server](https://github.com/apify/actors-mcp-server) 📇 ☁️ - از بیش از ۳۰۰۰ ابزار ابری از پیش ساخته شده، معروف به Actors، برای استخراج داده از وب‌سایت‌ها، تجارت الکترونیک، رسانه‌های اجتماعی، موتورهای جستجو، نقشه‌ها و موارد دیگر استفاده کنید
- [apinetwork/piapi-mcp-server](https://github.com/apinetwork/piapi-mcp-server) 📇 ☁️ سرور PiAPI MCP به کاربران امکان می‌دهد محتوای رسانه‌ای را با Midjourney/Flux/Kling/Hunyuan/Udio/Trellis مستقیماً از Claude یا هر برنامه سازگار با MCP دیگر تولید کنند.
- [awkoy/replicate-flux-mcp](https://github.com/awkoy/replicate-flux-mcp) 📇 ☁️ - قابلیت تولید تصاویر را از طریق Replicate's API فراهم می‌کند.
- [awwaiid/mcp-server-taskwarrior](https://github.com/awwaiid/mcp-server-taskwarrior) 🏠 📇 - یک سرور MCP برای استفاده پایه از taskwarrior محلی (اضافه کردن، به‌روزرسانی، حذف وظایف)
- [Azure/azure-mcp](https://github.com/Azure/azure-mcp) - سرور MCP رسمی مایکروسافت برای خدمات Azure شامل Storage، Cosmos DB و Azure Monitor.
- [Badhansen/notion-mcp](https://github.com/Badhansen/notion-mcp) 🐍 ☁️ - یک سرور Model Context Protocol (MCP) که با API Notion یکپارچه می‌شود تا لیست‌های todo شخصی را به طور کارآمد مدیریت کند.
- [ankitmalik84/notion-mcp-server](https://github.com/ankitmalik84/Agentic_Longterm_Memory/tree/main/src/notion_mcp_server) 🐍 ☁️ - یک سرور Model Context Protocol (MCP) جامع برای یکپارچه‌سازی با Notion با عملکرد پیشرفته، مدیریت خطای قوی، ویژگی آماده برای تولید.
- [bart6114/my-bear-mcp-server](https://github.com/bart6114/my-bear-mcp-server/) 📇 🏠 🍎 - امکان خواندن یادداشت‌ها و تگ‌ها را برای برنامه یادداشت‌برداری Bear، از طریق یکپارچه‌سازی مستقیم با sqlitedb Bear فراهم می‌کند.
- [billster45/mcp-chatgpt-responses](https://github.com/billster45/mcp-chatgpt-responses) 🐍 ☁️ - سرور MCP برای Claude برای صحبت با ChatGPT و استفاده از قابلیت جستجوی وب آن.
- [blurrah/mcp-graphql](https://github.com/blurrah/mcp-graphql) 📇 ☁️ - به هوش مصنوعی امکان کوئری سرورهای GraphQL را می‌دهد
- [boldsign/boldsign-mcp](https://github.com/boldsign/boldsign-mcp) 📇 ☁️ - جستجو، درخواست و مدیریت قراردادهای امضای الکترونیکی به راحتی با [BoldSign](https://boldsign.com/).
- [brianxiadong/ones-wiki-mcp-server](https://github.com/brianxiadong/ones-wiki-mcp-server) ☕ ☁️/🏠 - یک سرویس مبتنی بر Spring AI MCP برای بازیابی محتوای ONES Waiki و تبدیل آن به فرمت متنی سازگار با هوش مصنوعی.
- [calclavia/mcp-obsidian](https://github.com/calclavia/mcp-obsidian) 📇 🏠 - این یک اتصال‌دهنده است که به Claude Desktop (یا هر کلاینت MCP) اجازه می‌دهد هر دایرکتوری حاوی یادداشت‌های Markdown (مانند یک vault Obsidian) را بخواند و جستجو کند.
- [caol64/wenyan-mcp](https://github.com/caol64/wenyan-mcp) 📇 🏠 🍎 🪟 🐧 - سرور Wenyan MCP، که به هوش مصنوعی اجازه می‌دهد مقالات Markdown را به طور خودکار قالب‌بندی کرده و آنها را در WeChat GZH منتشر کند.
- [chrishayuk/mcp-cli](https://github.com/chrishayuk/mcp-cli) 🐍 🏠 - یک ابزار CLI دیگر برای تست سرورهای MCP
- [danhilse/notion_mcp](https://github.com/danhilse/notion_mcp) 🐍 ☁️ - با API Notion برای مدیریت لیست‌های todo شخصی یکپارچه می‌شود
- [danielkennedy1/pdf-tools-mcp](https://github.com/danielkennedy1/pdf-tools-mcp) 🐍 - ابزارهای دانلود، مشاهده و دستکاری PDF.
- [dotemacs/domain-lookup-mcp](https://github.com/dotemacs/domain-lookup-mcp) 🏎️ - سرویس جستجوی نام دامنه، ابتدا از طریق [RDAP](https://en.wikipedia.org/wiki/Registration_Data_Access_Protocol) و سپس به عنوان جایگزین از طریق [WHOIS](https://en.wikipedia.org/wiki/WHOIS)
- [ekkyarmandi/ticktick-mcp](https://github.com/ekkyarmandi/ticktick-mcp) 🐍 ☁️ - سرور MCP [TickTick](https://ticktick.com/) که با API TickTick برای مدیریت پروژه‌ها و وظایف todo شخصی یکپارچه می‌شود.
- [emicklei/mcp-log-proxy](https://github.com/emicklei/mcp-log-proxy) 🏎️ 🏠 - پروکسی سرور MCP که یک UI وب را برای کل جریان پیام ارائه می‌دهد
- [esignaturescom/mcp-server-esignatures](https://github.com/esignaturescom/mcp-server-esignatures) 🐍 ☁️️ - مدیریت قرارداد و قالب برای پیش‌نویس، بازبینی و ارسال قراردادهای الزام‌آور از طریق eSignatures API.
- [evalstate/mcp-hfspace](https://github.com/evalstate/mcp-hfspace) 📇 ☁️ - از HuggingFace Spaces مستقیماً از Claude استفاده کنید. از تولید تصویر منبع باز، چت، وظایف بینایی و موارد دیگر استفاده کنید. از آپلود/دانلود تصویر، صدا و متن پشتیبانی می‌کند.
- [evalstate/mcp-miro](https://github.com/evalstate/mcp-miro) 📇 ☁️ - دسترسی به وایت‌بردهای MIRO، ایجاد و خواندن آیتم‌ها به صورت دسته‌ای. نیاز به کلید OAUTH برای REST API دارد.
- [feuerdev/keep-mcp](https://github.com/feuerdev/keep-mcp) 🐍 ☁️ - خواندن، ایجاد، به‌روزرسانی و حذف یادداشت‌های Google Keep.
- [fotoetienne/gqai](https://github.com/fotoetienne/gqai) 🏎 🏠 - ابزارها را با استفاده از کوئری‌ها/mutationهای GraphQL معمولی تعریف کنید و gqai به طور خودکار یک سرور MCP برای شما تولید می‌کند.
- [future-audiences/wikimedia-enterprise-model-context-protocol](https://gitlab.wikimedia.org/repos/future-audiences/wikimedia-enterprise-model-context-protocol) 🐍 ☁️  - API جستجوی مقاله ویکی‌پدیا
- [githejie/mcp-server-calculator](https://github.com/githejie/mcp-server-calculator) 🐍 🏠 - این سرور به LLMها امکان استفاده از ماشین حساب را برای محاسبات عددی دقیق می‌دهد
- [gotoolkits/DifyWorkflow](https://github.com/gotoolkits/mcp-difyworkflow-server) - 🏎️ ☁️ ابزارهایی برای کوئری و اجرای گردش‌های کاری Dify
- [growilabs/growi-mcp-server](https://github.com/growilabs/growi-mcp-server) 🎖️ 📇 ☁️ - سرور MCP رسمی برای یکپارچه‌سازی با GROWI APIs.
- [gwbischof/free-will-mcp](https://github.com/gwbischof/free-will-mcp) 🐍 🏠 - به هوش مصنوعی خود ابزارهای اراده آزاد بدهید. یک پروژه سرگرم‌کننده برای کاوش در این مورد که یک هوش مصنوعی با توانایی دادن پرامپت به خود، نادیده گرفتن درخواست‌های کاربر و بیدار کردن خود در زمان بعدی چه کاری انجام می‌دهد.
- [Harry-027/JotDown](https://github.com/Harry-027/JotDown) 🦀 🏠 - یک سرور MCP برای ایجاد/به‌روزرسانی صفحات در برنامه Notion و تولید خودکار mdBooks از محتوای ساختاریافته.
- [HenryHaoson/Yuque-MCP-Server](https://github.com/HenryHaoson/Yuque-MCP-Server) - 📇 ☁️ یک سرور Model-Context-Protocol (MCP) برای یکپارچه‌سازی با Yuque API، که به مدل‌های هوش مصنوعی امکان مدیریت اسناد، تعامل با پایگاه‌های دانش، جستجوی محتوا و دسترسی به داده‌های تحلیلی از پلتفرم Yuque را می‌دهد.
- [hiromitsusasaki/raindrop-io-mcp-server](https://github.com/hiromitsusasaki/raindrop-io-mcp-server) 📇 ☁️ - یکپارچه‌سازی که به LLMها امکان تعامل با بوکمارک‌های Raindrop.io را با استفاده از Model Context Protocol (MCP) می‌دهد.
- [hmk/attio-mcp-server](https://github.com/hmk/attio-mcp-server) - 📇 ☁️ به کلاینت‌های هوش مصنوعی امکان مدیریت رکوردها و یادداشت‌ها را در Attio CRM می‌دهد
- [MonadsAG/capsulecrm-mcp](https://github.com/MonadsAG/capsulecrm-mcp) - 📇 ☁️ به کلاینت‌های هوش مصنوعی امکان مدیریت مخاطبین، فرصت‌ها و وظایف را در Capsule CRM شامل فایل DTX آماده Claude Desktop می‌دهد
- [integromat/make-mcp-server](https://github.com/integromat/make-mcp-server) 🎖️ 📇 🏠 - سناریوهای [Make](https://www.make.com/) خود را به ابزارهای قابل فراخوانی برای دستیاران هوش مصنوعی تبدیل کنید.
- [isaacwasserman/mcp-vegalite-server](https://github.com/isaacwasserman/mcp-vegalite-server) 🐍 🏠 - تولید تجسم‌ها از داده‌های دریافت شده با استفاده از فرمت و رندر کننده VegaLite.
- [ivnvxd/mcp-server-odoo](https://github.com/ivnvxd/mcp-server-odoo) 🐍 ☁️/🏠 - اتصال دستیاران هوش مصنوعی به سیستم‌های ERP Odoo برای دسترسی به داده‌های تجاری، مدیریت رکورد و اتوماسیون گردش کار.
- [ivo-toby/contentful-mcp](https://github.com/ivo-toby/contentful-mcp) 📇 🏠 - به‌روزرسانی، ایجاد، حذف محتوا، مدل‌های محتوا و دارایی‌ها در فضای Contentful شما
- [j3k0/speech.sh](https://github.com/j3k0/speech.sh/blob/main/MCP_README.md) 🏠 - به عامل اجازه دهید چیزها را با صدای بلند بگوید، وقتی کارش تمام شد با یک خلاصه سریع به شما اطلاع دهد
- [jagan-shanmugam/climatiq-mcp-server](https://github.com/jagan-shanmugam/climatiq-mcp-server) 🐍 🏠 - یک سرور Model Context Protocol (MCP) برای دسترسی به Climatiq API برای محاسبه انتشار کربن. این به دستیاران هوش مصنوعی امکان انجام محاسبات کربن بی‌درنگ و ارائه بینش‌های تأثیر آب و هوایی را می‌دهد.
- [jen6/ticktick-mcp](https://github.com/jen6/ticktick-mcp) 🐍 ☁️ - سرور MCP [TickTick](https://ticktick.com/). ساخته شده بر روی کتابخانه ticktick-py، قابلیت‌های فیلتر کردن به طور قابل توجهی بهبود یافته‌ای را ارائه می‌دهد.
- [jimfilippou/things-mcp](https://github.com/jimfilippou/things-mcp) 📇 🏠 🍎 - یک سرور Model Context Protocol (MCP) که یکپارچه‌سازی یکپارچه با برنامه بهره‌وری [Things](https://culturedcode.com/things/) را فراهم می‌کند. این سرور به دستیاران هوش مصنوعی امکان ایجاد، به‌روزرسانی و مدیریت todoها و پروژه‌های شما را در Things با استفاده از URL scheme جامع آن می‌دهد.
- [johannesbrandenburger/typst-mcp](https://github.com/johannesbrandenburger/typst-mcp) 🐍 🏠 - سرور MCP برای Typst، یک سیستم حروف‌چینی مبتنی بر markup. ابزارهایی برای تبدیل بین LaTeX و Typst، اعتبارسنجی سینتکس Typst و تولید تصاویر از کد Typst فراهم می‌کند.
- [joshuarileydev/mac-apps-launcher-mcp-server](https://github.com/JoshuaRileyDev/mac-apps-launcher) 📇 🏠 - یک سرور MCP برای لیست کردن و راه‌اندازی برنامه‌ها در MacOS
- [k-jarzyna/mcp-miro](https://github.com/k-jarzyna/mcp-miro) 📇 ☁️ - سرور MCP Miro، که تمام قابلیت‌های موجود در Miro SDK رسمی را در معرض دید قرار می‌دهد
- [kelvin6365/plane-mcp-server](https://github.com/kelvin6365/plane-mcp-server) - 🏎️ 🏠 این سرور MCP به شما کمک می‌کند تا پروژه‌ها و issueها را از طریق API [Plane](https://plane.so) مدیریت کنید
- [kenliao94/mcp-server-rabbitmq](https://github.com/kenliao94/mcp-server-rabbitmq) 🐍 🏠 - فعال کردن تعامل (عملیات ادمین، enqueue/dequeue پیام) با RabbitMQ
- [kimtth/mcp-remote-call-ping-pong](https://github.com/kimtth/mcp-remote-call-ping-pong) 🐍 🏠 - یک برنامه آزمایشی و آموزشی برای سرور Ping-pong که فراخوانی‌های MCP (Model Context Protocol) راه دور را نشان می‌دهد
- [kiwamizamurai/mcp-kibela-server](https://github.com/kiwamizamurai/mcp-kibela-server) - 📇 ☁️ تعامل قدرتمند با Kibela API.
- [kj455/mcp-kibela](https://github.com/kj455/mcp-kibela) - 📇 ☁️ به مدل‌های هوش مصنوعی امکان تعامل با [Kibela](https://kibe.la/) را می‌دهد
- [Klavis-AI/YouTube](https://github.com/Klavis-AI/klavis/tree/main/mcp_servers/youtube) 🐍 📇 - استخراج و تبدیل اطلاعات ویدیوی YouTube.
- [KS-GEN-AI/confluence-mcp-server](https://github.com/KS-GEN-AI/confluence-mcp-server) 📇 ☁️ 🍎 🪟 - دریافت داده‌های Confluence از طریق CQL و خواندن صفحات.
- [KS-GEN-AI/jira-mcp-server](https://github.com/KS-GEN-AI/jira-mcp-server) 📇 ☁️ 🍎 🪟 - خواندن داده‌های jira از طریق JQL و api و اجرای درخواست‌ها برای ایجاد و ویرایش تیکت‌ها.
- [kw510/strava-mcp](https://github.com/kw510/strava-mcp) 📇 ☁️ - یک سرور MCP برای Strava، برنامه‌ای برای ردیابی تمرینات بدنی
- [louiscklaw/hko-mcp](https://github.com/louiscklaw/hko-mcp) 📇 🏠 - سرور MCP با نمایش اولیه دریافت آب و هوا از رصدخانه هنگ کنگ
- [magarcia/mcp-server-giphy](https://github.com/magarcia/mcp-server-giphy) 📇 ☁️ - جستجو و بازیابی GIFها از کتابخانه وسیع Giphy از طریق Giphy API.
- [marcelmarais/Spotify](https://github.com/marcelmarais/spotify-mcp-server) - 📇 🏠 کنترل پخش Spotify و مدیریت لیست‌های پخش.
- [MarkusPfundstein/mcp-obsidian](https://github.com/MarkusPfundstein/mcp-obsidian) 🐍 ☁️ 🏠 - تعامل با Obsidian از طریق REST API
- [mediar-ai/screenpipe](https://github.com/mediar-ai/screenpipe) - 🎖️ 🦀 🏠 🍎 سیستم محلی-اول که صفحه/صدا را با نمایه‌سازی دارای برچسب زمانی، ذخیره‌سازی SQL/embedding، جستجوی معنایی، تحلیل تاریخچه مبتنی بر LLM و اقدامات راه‌اندازی شده توسط رویداد ضبط می‌کند - ساخت عامل‌های هوش مصنوعی آگاه از زمینه را از طریق یک اکوسیستم پلاگین NextJS امکان‌پذیر می‌کند.
- [modelcontextprotocol/server-everything](https://github.com/modelcontextprotocol/servers/tree/main/src/everything) 📇 🏠 - سرور MCP که تمام ویژگی‌های پروتکل MCP را تمرین می‌کند
- [mrjoshuak/godoc-mcp](https://github.com/mrjoshuak/godoc-mcp) 🏎️ 🏠 - سرور مستندات Go بهینه از نظر توکن که به دستیاران هوش مصنوعی دسترسی هوشمند به مستندات بسته و انواع را بدون خواندن کل فایل‌های منبع می‌دهد
- [Mtehabsim/ScreenPilot](https://github.com/Mtehabsim/ScreenPilot) 🐍 🏠 - به هوش مصنوعی امکان کنترل و دسترسی کامل به تعاملات GUI را با ارائه ابزارهایی برای ماوس و کیبورد می‌دهد، ایده‌آل برای اتوماسیون عمومی، آموزش و آزمایش.
- [mzxrai/mcp-openai](https://github.com/mzxrai/mcp-openai) 📇 ☁️ - چت با هوشمندترین مدل‌های OpenAI
- [NakaokaRei/swift-mcp-gui](https://github.com/NakaokaRei/swift-mcp-gui.git) 🏠 🍎 - سرور MCP که می‌تواند دستوراتی مانند ورودی کیبورد و حرکت ماوس را اجرا کند
- [nguyenvanduocit/all-in-one-model-context-protocol](https://github.com/nguyenvanduocit/all-in-one-model-context-protocol) 🏎️ 🏠 - برخی ابزارهای مفید برای توسعه‌دهنده، تقریباً هر چیزی که یک مهندس نیاز دارد: confluence، Jira، Youtube، اجرای اسکریپت، پایگاه دانش RAG، دریافت URL، مدیریت کانال یوتیوب، ایمیل‌ها، تقویم، gitlab
- [NON906/omniparser-autogui-mcp](https://github.com/NON906/omniparser-autogui-mcp) - 🐍 عملیات خودکار GUI روی صفحه.
- [offorte/offorte-mcp-server](https://github.com/offorte/offorte-mcp-server) 🎖️ 📇 ☁️ 🍎 🪟 🐧 - سرور MCP نرم‌افزار پیشنهاد Offorte ایجاد و ارسال پیشنهادهای تجاری را امکان‌پذیر می‌کند.
- [olalonde/mcp-human](https://github.com/olalonde/mcp-human) 📇 ☁️ - زمانی که LLM شما به کمک انسانی نیاز دارد (از طریق AWS Mechanical Turk)
- [orellazi/coda-mcp](https://github.com/orellazri/coda-mcp) 📇 ☁️ - سرور MCP برای [Coda](https://coda.io/)
- [osinmv/funciton-lookup-mcp](https://github.com/osinmv/function-lookup-mcp) 🐍 🏠 🍎 🐧 - سرور MCP برای جستجوی امضای توابع.
- [pierrebrunelle/mcp-server-openai](https://github.com/pierrebrunelle/mcp-server-openai) 🐍 ☁️ - کوئری مدل‌های OpenAI مستقیماً از Claude با استفاده از پروتکل MCP
- [pskill9/hn-server](https://github.com/pskill9/hn-server) - 📇 ☁️ محتوای HTML را از news.ycombinator.com (Hacker News) تجزیه می‌کند و داده‌های ساختاریافته را برای انواع مختلف داستان‌ها (برتر، جدید، بپرس، نشان بده، مشاغل) فراهم می‌کند.
- [PV-Bhat/vibe-check-mcp-server](https://github.com/PV-Bhat/vibe-check-mcp-server) 📇 ☁️ - یک سرور MCP که با فراخوانی یک عامل "Vibe-check" برای اطمینان از همسویی با کاربر، از خطاهای آبشاری و گسترش دامنه جلوگیری می‌کند.
- [pwh-pwh/cal-mcp](https://github.com/pwh-pwh/cal-mcp) - یک سرور MCP برای محاسبه عبارات ریاضی
- [pyroprompts/any-chat-completions-mcp](https://github.com/pyroprompts/any-chat-completions-mcp) - با هر API Chat Completions سازگار با OpenAI SDK، مانند Perplexity، Groq، xAI و موارد دیگر چت کنید
- [quarkiverse/mcp-server-jfx](https://github.com/quarkiverse/quarkus-mcp-servers/tree/main/jfx) ☕ 🏠 - روی بوم JavaFX نقاشی کنید.
- [QuentinCody/shopify-storefront-mcp-server](https://github.com/QuentinCody/shopify-storefront-mcp-server) 🐍 ☁️ - سرور MCP غیر رسمی که به عامل‌های هوش مصنوعی امکان کشف ویترین‌های Shopify و تعامل با آنها را برای دریافت محصولات، مجموعه‌ها و سایر داده‌های فروشگاه از طریق Storefront API می‌دهد.
- [r-huijts/ethics-check-mcp](https://github.com/r-huijts/ethics-check-mcp) 🐍 🏠 - سرور MCP برای تحلیل اخلاقی جامع مکالمات هوش مصنوعی، شناسایی سوگیری، محتوای مضر و ارائه ارزیابی‌های تفکر انتقادی با یادگیری الگوی خودکار
- [rae-api-com/rae-mcp](https://github.com/rae-api-com/rae-mcp) - 🏎️ ☁️ 🍎 🪟 🐧 سرور MPC برای اتصال مدل مورد علاقه شما به https://rae-api.com، فرهنگ لغت آکادمی سلطنتی اسپانیا
- [Rai220/think-mcp](https://github.com/Rai220/think-mcp) 🐍 🏠 - قابلیت‌های استدلال هر عاملی را با یکپارچه‌سازی think-tools، همانطور که در [مقاله Anthropic](https://www.anthropic.com/engineering/claude-think-tool) توضیح داده شده است، افزایش می‌دهد.
- [reeeeemo/ancestry-mcp](https://github.com/reeeeemo/ancestry-mcp) 🐍 🏠 - به هوش مصنوعی اجازه می‌دهد فایل‌های .ged و داده‌های ژنتیکی را بخواند
- [rember/rember-mcp](https://github.com/rember/rember-mcp) 📇 🏠 - فلش‌کارت‌های تکرار با فاصله در [Rember](https://rember.com) ایجاد کنید تا هر چیزی را که در چت‌های خود یاد می‌گیرید به خاطر بسپارید.
- [roychri/mcp-server-asana](https://github.com/roychri/mcp-server-asana) - 📇 ☁️ این پیاده‌سازی سرور Model Context Protocol از Asana به شما امکان می‌دهد با Asana API از کلاینت MCP مانند برنامه دسکتاپ Claude Anthropic و بسیاری دیگر صحبت کنید.
- [rusiaaman/wcgw](https://github.com/rusiaaman/wcgw/blob/main/src/wcgw/client/mcp_server/Readme.md) 🐍 🏠 - اجرای shell خودکار، کنترل کامپیوتر و عامل کدنویسی. (Mac)
- [inkbytefo/screenmonitormcp](https://github.com/inkbytefo/screenmonitormcp) 🐍 🏠 🍎 🪟 🐧 - سرور MCP تحلیل بی‌درنگ صفحه، ضبط آگاه از زمینه و نظارت بر UI. از بینایی هوش مصنوعی، هوک‌های رویداد و گردش‌های کاری عامل چندوجهی پشتیبانی می‌کند.
- [SecretiveShell/MCP-wolfram-alpha](https://github.com/SecretiveShell/MCP-wolfram-alpha) 🐍 ☁️ - یک سرور MCP برای کوئری wolfram alpha API.
- [Seym0n/tiktok-mcp](https://github.com/Seym0n/tiktok-mcp) 📇 ☁️ - تعامل با ویدیوهای TikTok
- [Shopify/dev-mcp](https://github.com/Shopify/dev-mcp) 📇 ☁️ - سرور Model Context Protocol (MCP) که با Shopify Dev تعامل دارد.
- [sirmews/apple-notes-mcp](https://github.com/sirmews/apple-notes-mcp) 🐍 🏠 - به هوش مصنوعی اجازه می‌دهد از پایگاه داده محلی Apple Notes شما بخواند (فقط macOS)
- [sooperset/mcp-atlassian](https://github.com/sooperset/mcp-atlassian) 🐍 ☁️ - سرور MCP برای محصولات Atlassian (Confluence و Jira). از Confluence Cloud، Jira Cloud و Jira Server/Data Center پشتیبانی می‌کند. ابزارهای جامعی برای جستجو، خواندن، ایجاد و مدیریت محتوا در فضاهای کاری Atlassian فراهم می‌کند.
- [suekou/mcp-notion-server](https://github.com/suekou/mcp-notion-server) 📇 🏠 - تعامل با Notion API
- [tacticlaunch/mcp-linear](https://github.com/tacticlaunch/mcp-linear) 📇 ☁️ 🍎 🪟 🐧 - با سیستم مدیریت پروژه Linear یکپارچه می‌شود
- [tanigami/mcp-server-perplexity](https://github.com/tanigami/mcp-server-perplexity) 🐍 ☁️ - تعامل با Perplexity API.
- [tevonsb/homeassistant-mcp](https://github.com/tevonsb/homeassistant-mcp) 📇 🏠 - دسترسی به داده‌های Home Assistant و کنترل دستگاه‌ها (چراغ‌ها، سوئیچ‌ها، ترموستات‌ها و غیره).
- [TheoBrigitte/mcp-time](https://github.com/TheoBrigitte/mcp-time) 🏎️ 🏠 🍎 🪟 🐧 - سرور MCP که ابزارهایی برای کار با زمان و تاریخ‌ها، با زبان طبیعی، فرمت‌های متعدد و قابلیت‌های تبدیل منطقه زمانی فراهم می‌کند.
- [Tommertom/plugwise-mcp](https://github.com/Tommertom/plugwise-mcp) 📇 🏠 🍎 🪟 🐧 - سرور اتوماسیون خانه هوشمند مبتنی بر TypeScript برای دستگاه‌های Plugwise با کشف خودکار شبکه. دارای کنترل جامع دستگاه برای ترموستات‌ها، سوئیچ‌ها، پریزهای هوشمند، نظارت بر انرژی، مدیریت چند-هاب و ردیابی بی‌درنگ آب و هوا/مصرف برق از طریق یکپارچه‌سازی شبکه محلی است.
- [tomekkorbak/oura-mcp-server](https://github.com/tomekkorbak/oura-mcp-server) 🐍 ☁️ - یک سرور MCP برای Oura، برنامه‌ای برای ردیابی خواب
- [tqiqbal/mcp-confluence-server](https://github.com/tqiqbal/mcp-confluence-server) 🐍 - یک سرور Model Context Protocol (MCP) برای تعامل با Confluence Data Center از طریق REST API.
- [ttommyth/interactive-mcp](https://github.com/ttommyth/interactive-mcp) 📇 🏠 🍎 🪟 🐧 - گردش‌های کاری LLM تعاملی را با اضافه کردن پرامپت‌های کاربر محلی و قابلیت‌های چت مستقیماً به حلقه MCP امکان‌پذیر می‌کند.
- [tumf/web3-mcp](https://github.com/tumf/web3-mcp) 🐍 ☁️ - یک پیاده‌سازی سرور MCP که Ankr Advanced API را پوشش می‌دهد. دسترسی به داده‌های NFT، توکن و بلاکچین در چندین زنجیره شامل Ethereum، BSC، Polygon، Avalanche و موارد دیگر.
- [ujisati/anki-mcp](https://github.com/ujisati/anki-mcp) 🐍 🏠 - مجموعه Anki خود را با AnkiConnect و MCP مدیریت کنید
- [UnitVectorY-Labs/mcp-graphql-forge](https://github.com/UnitVectorY-Labs/mcp-graphql-forge) 🏎️ ☁️ 🍎 🪟 🐧 - یک سرور MCP سبک و مبتنی بر پیکربندی که کوئری‌های GraphQL منتخب را به عنوان ابزارهای ماژولار در معرض دید قرار می‌دهد و تعاملات API عمدی را از عامل‌های شما امکان‌پذیر می‌کند.
- [wanaku-ai/wanaku](https://github.com/wanaku-ai/wanaku) - ☁️ 🏠 Wanaku MCP Router یک سرور MCP مبتنی بر SSE است که یک موتور مسیریابی قابل توسعه را فراهم می‌کند که به شما امکان می‌دهد سیستم‌های سازمانی خود را با عامل‌های هوش مصنوعی یکپارچه کنید.
- [wong2/mcp-cli](https://github.com/wong2/mcp-cli) 📇 🏠 - ابزار CLI برای تست سرورهای MCP
- [ws-mcp](https://github.com/nick1udwig/ws-mcp) - سرورهای MCP را با یک WebSocket بپوشانید (برای استفاده با [kitbitz](https://github.com/nick1udwig/kibitz))
- [yuna0x0/hackmd-mcp](https://github.com/yuna0x0/hackmd-mcp) 📇 ☁️ - به مدل‌های هوش مصنوعی امکان تعامل با [HackMD](https://hackmd.io) را می‌دهد
- [ZeparHyfar/mcp-datetime](https://github.com/ZeparHyfar/mcp-datetime) - سرور MCP که توابع تاریخ و زمان را در فرمت‌های مختلف فراهم می‌کند
- [zueai/mcp-manager](https://github.com/zueai/mcp-manager) 📇 ☁️ - UI وب ساده برای نصب و مدیریت سرورهای MCP برای برنامه دسکتاپ Claude.
- [imprvhub/mcp-claude-spotify](https://github.com/imprvhub/mcp-claude-spotify) 📇 ☁️ 🏠 - یکپارچه‌سازی که به Claude Desktop امکان تعامل با Spotify را با استفاده از Model Context Protocol (MCP) می‌دهد.
- [nanana-app/mcp-server-nano-banana](https://github.com/nanana-app/mcp-server-nano-banana) 🐍 🏠 🍎 🪟 🐧 - تولید تصویر هوش مصنوعی با استفاده از مدل nano banana گوگل Gemini.
- [kiarash-portfolio-mcp](https://kiarash-adl.pages.dev/.well-known/mcp.llmfeed.json) – پورتفولیو فعال شده با WebMCP با کشف امضا شده Ed25519. عامل‌های هوش مصنوعی می‌توانند پروژه‌ها و مهارت‌ها را کوئری کنند و دستورات ترمینال را اجرا کنند. ساخته شده بر روی Cloudflare Pages Functions.

## چارچوب‌ها

> [!NOTE]
> چارچوب‌ها، ابزارها و سایر ابزارهای توسعه‌دهنده بیشتر در https://github.com/punkpeye/awesome-mcp-devtools در دسترس هستند

- [FastMCP](https://github.com/jlowin/fastmcp) 🐍 - یک چارچوب سطح بالا برای ساخت سرورهای MCP در Python
- [FastMCP](https://github.com/punkpeye/fastmcp) 📇 - یک چارچوب سطح بالا برای ساخت سرورهای MCP در TypeScript

## نکات و ترفندها

### پرامپت رسمی برای اطلاع‌رسانی به LLMها در مورد نحوه استفاده از MCP

می‌خواهید از Claude در مورد Model Context Protocol بپرسید؟

یک پروژه ایجاد کنید، سپس این فایل را به آن اضافه کنید:

https://modelcontextprotocol.io/llms-full.txt

اکنون Claude می‌تواند به سؤالات مربوط به نوشتن سرورهای MCP و نحوه کار آنها پاسخ دهد

- https://www.reddit.com/r/ClaudeAI/comments/1h3g01r/want_to_ask_claude_about_model_context_protocol/

## تاریخچه ستاره‌ها

<a href="https://star-history.com/#punkpeye/awesome-mcp-servers&Date">
 <picture>
   <source media="(prefers-color-scheme: dark)" srcset="https://api.star-history.com/svg?repos=punkpeye/awesome-mcp-servers&type=Date&theme=dark" />
   <source media="(prefers-color-scheme: light)" srcset="https://api.star-history.com/svg?repos=punkpeye/awesome-mcp-servers&type=Date" />
   <img alt="Star History Chart" src="https://api.star-history.com/svg?repos=punkpeye/awesome-mcp-servers&type=Date" />
 </picture>
</a>
